@setlocal 
@echo off
rem Version mqe_java/source/resources/Windows/CreateGatewayQM.bat, MQe, la200, la200-L030324.1 1.4
rem -------------------------------------------------------------------------
rem MQSeries Everyplace for Multiplatforms                
rem                                                                          
rem Licensed Materials - Property of IBM                                     
rem                                                                          
rem 5765-E63                                                                 
rem                                                                          
rem (C) Copyright IBM Corp. 2001                                             
rem 
rem -------------------------------------------------------------------------
rem 
rem A batch file to create a queue manager on a gateway machine.
rem 
rem Syntax: CreateGatewayQM.bat
rem 
rem Note: The JavaEnv and MQE_BASE_DIR enviroment variables must be set.
rem 
rem -------------------------------------------------------------------------

rem Check that the java command is set.
if .%JavaCmd%.==..                     goto no_java_cmd      

rem Check that the MQE_BASE_DIR environment variable is set.
if .%MQE_BASE_DIR%.==..                goto no_mqe_base_dir

rem Collect the details about the gateway queue manager.      
call GatewayQMDetails.bat

rem Check that the user has filled-in the correct details.
if .%GATEWAY_QMGR_ADDR%.==..           goto no_gateway_qmgr_addr
if .%GATEWAY_QMGR_PORT%.==..           goto no_gateway_qmgr_port

rem Collect the details about the central (MQSeries) queue manager...
call CentralQMDetails.bat

rem Check to make sure the details were filled-in.
if .%CENTRAL_QMGR_NAME%.==..           goto no_central_qmgr_name
if .%CENTRAL_QMGR_LISTENING_PORT%.==.. goto no_central_qmgr_listening_port
if .%CENTRAL_QMGR_HOSTNAME%.==..       goto no_central_qmgr_hostname
if .%TARGET_MQ_Q%.==..                 goto no_target_mq_q

rem A symbolic for the name of the queue manager.                 
set QMGR_NAME=%GATEWAY_QMGR_NAME%

rem Where is the queue manager being created ?
set QMGR_DIR=%MQE_BASE_DIR%\%QMGR_NAME%

rem The ini file describing the queue manager..
set INI_FILE_NAME=%QMGR_DIR%\%QMGR_NAME%.ini

rem Decide on the names of some MQSeries bridge object.
set BRIDGE_NAME=%GATEWAY_QMGR_NAME%.MQBridgeV100
set PROXY_NAME=%CENTRAL_QMGR_NAME%
set TRANSFORMER_NAME=com.ibm.mqe.mqbridge.MQeBaseTransformer
set CONNECTION_NAME=FOR.%GATEWAY_QMGR_NAME%
set SYNC_Q_NAME=SYNC.Q.%GATEWAY_QMGR_NAME%
set MQ_XMIT_Q_NAME=TO.%GATEWAY_QMGR_NAME%

rem Short symbolics to make script easier to read.
set BASE_PACKAGE=examples.administration.commandline
set BRIDGE_PACKAGE=examples.mqbridge.administration.commandline

rem The security attributes used on queues.
set COMPRESSOR=null
rem set CRYPTOR=com.ibm.mqe.attributes.MQeDESCryptor
set CRYPTOR=null
set AUTHENTICATOR=null

rem The pin and password required for the queue manager to access its registry.                  
set PIN=123456789
set KEYRINGPASSWORD=mySecret

rem The queue manager rule for the store queue manager...
set QMGR_RULE=examples.rules.ExampleQueueManagerRules

rem The MQe storage adapter used to save messages to disk.                                                 
set STORAGE_ADAPTER=com.ibm.mqe.adapters.MQeDiskFieldsAdapter
rem And the base directory name where a queue's information is stored
set STORAGE_LOCATION=%STORAGE_ADAPTER%:%QMGR_DIR%

rem Delete the queue manager if it already exists...
if exist %QMGR_DIR% del /S /Q %QMGR_DIR%\*.*
if exist %QMGR_DIR% rmdir /S /Q %QMGR_DIR%                                                             
                                                            
rem Create the directory for the queue manager to live in...             
mkdir %QMGR_DIR%  

rem Create the branch device .ini file for use when creating the queue manager...              
%JavaCmd% %BASE_PACKAGE%.IniFileCreator %INI_FILE_NAME% %QMGR_NAME% %QMGR_DIR%\Registry\ Gateway ^
%GATEWAY_QMGR_PORT% %PIN% %KEYRINGPASSWORD% default FileRegistry %GATEWAY_LISTENING_ADAPTER%
if .%ERRORLEVEL%.==.0. goto ini_file_created
echo Failed to create the .ini file %INI_FILE_NAME% 
goto ending
:ini_file_created
echo ini file %INI_FILE_NAME% created ok. 

rem Create the queue manager using the .ini file...
%JavaCmd% examples.install.SimpleCreateQM %INI_FILE_NAME% %QMGR_DIR%\Queues\
if .%ERRORLEVEL%.==.0. goto qmgr_created
echo Failed to create the queue manager from the %INI_FILE_NAME% file
goto ending
:qmgr_created
echo Created the queue manager from %INI_FILE_NAME% ok.
              
rem Create a connection from the gateway queue manager to the MQSeries queue manager...                         
rem Syntax is : ConnectionCreator <connection_name> <qmgr> <adapter> <channel> <ini_file>
%JavaCmd% %BASE_PACKAGE%.ConnectionCreator  %CENTRAL_QMGR_NAME% %GATEWAY_QMGR_NAME% null null %INI_FILE_NAME%
if .%ERRORLEVEL%.==.0. goto con_central_created
echo Failed to create the connection to %CENTRAL_QMGR_NAME%
goto ending
:con_central_created
echo Created the connection to %CENTRAL_QMGR_NAME% ok.

rem Set the device queue manager rule to a rule class which triggers transmission every 5 minutes.
rem Syntax: java QueueManagerUpdater rule qmgr iniFile
%JavaCmd% %BASE_PACKAGE%.QueueManagerUpdater %QMGR_RULE% %QMGR_NAME% %INI_FILE_NAME%                                               
if .%ERRORLEVEL%.==.0. goto qmgr_rule_updated
echo Failed to update the queue manager rules.
goto ending
:qmgr_rule_updated
echo Updated the queue manager rules ok.

rem Configure a bridge on the gateway queue manager.
rem Syntax: Syntax: java MQBridgeCreator bridgeName transformer qMgr iniFile
%JavaCmd% %BRIDGE_PACKAGE%.MQBridgeCreator %BRIDGE_NAME% %TRANSFORMER_NAME% %GATEWAY_QMGR_NAME% %INI_FILE_NAME%
if .%ERRORLEVEL%.==.0. goto bridge_created
echo Failed to create the MQSeries bridge %BRIDGE_NAME%.
goto ending
:bridge_created
echo Created the bridge %BRIDGE_NAME%.

rem Create an MQ queue manager proxy
rem Syntax: java MQQMgrProxyCreator bridgeName proxyName hostName qMgr iniFile
%JavaCmd% %BRIDGE_PACKAGE%.MQQMgrProxyCreator %BRIDGE_NAME% %PROXY_NAME% %CENTRAL_QMGR_HOSTNAME% ^
%GATEWAY_QMGR_NAME% %INI_FILE_NAME%
if .%ERRORLEVEL%.==.0. goto proxy_created
echo Failed to create the MQSeries queue manager proxy object %PROXY_NAME% on the bridge.
goto ending
:proxy_created
echo Created the MQSeries queue manager proxy object %PROXY_NAME% on the bridge. 

rem Create a client connection object for the gateway
rem Syntax: java MQConnectionCreator bridgeName proxyName connectionName port syncQName qMgr iniFile
%JavaCmd% %BRIDGE_PACKAGE%.MQConnectionCreator %BRIDGE_NAME% %PROXY_NAME% %CONNECTION_NAME% ^
%CENTRAL_QMGR_LISTENING_PORT% %SYNC_Q_NAME% %GATEWAY_QMGR_NAME% %INI_FILE_NAME%
if .%ERRORLEVEL%.==.0. goto mq_conn_created
echo Failed to create the client connection pool %CONNECTION_NAME% on the bridge.
goto ending
:mq_conn_created
echo Created the client connection pool %CONNECTION_NAME% on the bridge.

rem Create a bridge queue which refers to a queue on the MQSeries queue manager...
rem Syntax: java MQBridgeQueueCreator bridgeName proxyName connectionName qName transformerClass qMgr iniFile
%JavaCmd% %BRIDGE_PACKAGE%.MQBridgeQueueCreator %BRIDGE_NAME% %PROXY_NAME% %CONNECTION_NAME% %TARGET_MQ_Q% ^
null %COMPRESSOR% %CRYPTOR% %AUTHENTICATOR% %GATEWAY_QMGR_NAME% %INI_FILE_NAME%
if .%ERRORLEVEL%.==.0. goto mq_q_created
echo Failed to create the MQ bridge queue to %TARGET_MQ_Q%.
goto ending
:mq_q_created
echo Created the bridge queue %TARGET_MQ_Q%.

rem Create an MQ transmission queue listener... to receive messages from the MQ system
%JavaCmd% %BRIDGE_PACKAGE%.MQListenerCreator %BRIDGE_NAME% %PROXY_NAME% %CONNECTION_NAME% %MQ_XMIT_Q_NAME% ^
null %GATEWAY_QMGR_NAME% %INI_FILE_NAME%
if .%ERRORLEVEL%.==.0. goto mq_listener
echo Failed to create the MQ transmission queue listener  %MQ_XMIT_Q_NAME%.
goto ending
:mq_listener
echo Created the MQ transmission queue listener  %MQ_XMIT_Q_NAME%

rem Create a store-and-forward queue to hold data which is bound for the branches...
%JavaCmd% %BASE_PACKAGE%.StoreAndForwardQueueCreator %GATEWAY_S_F_Q% %GATEWAY_QMGR_NAME% Asynchronous ^
null null null %GATEWAY_QMGR_NAME% %INI_FILE_NAME% %STORAGE_LOCATION%
if .%ERRORLEVEL%.==.0. goto s_f_q_created
echo Failed to create the store-and-forward queue %GATEWAY_S_F_Q%.
goto ending
:s_f_q_created
echo Created the store-and-forward queue %GATEWAY_S_F_Q%. 

rem Add the name of all branches to the store-and-forward queue... 
rem so it collects messages which are bound for them.
%JavaCmd% %BASE_PACKAGE%.StoreAndForwardQueueQMgrAdder %GATEWAY_S_F_Q% %GATEWAY_QMGR_NAME% ^
BRANCH000QM %GATEWAY_QMGR_NAME% %INI_FILE_NAME%
if .%ERRORLEVEL%.==.0. goto branch000_added
echo Failed to add BRANCH000QM to the store-and-forward queue %GATEWAY_S_F_Q%.
goto ending
:branch000_added
echo Added BRANCH000QM to the store-and-forward queue %GATEWAY_S_F_Q%.

%JavaCmd% %BASE_PACKAGE%.StoreAndForwardQueueQMgrAdder %GATEWAY_S_F_Q% %GATEWAY_QMGR_NAME% ^
BRANCH001QM %GATEWAY_QMGR_NAME% %INI_FILE_NAME% 
if .%ERRORLEVEL%.==.0. goto branch001_added
echo Failed to add BRANCH001QM to the store-and-forward queue %GATEWAY_S_F_Q%.
goto ending
:branch001_added
echo Added BRANCH001QM to the store-and-forward queue %GATEWAY_S_F_Q%.

%JavaCmd% %BASE_PACKAGE%.StoreAndForwardQueueQMgrAdder %GATEWAY_S_F_Q% %GATEWAY_QMGR_NAME% ^
BRANCH002QM %GATEWAY_QMGR_NAME% %INI_FILE_NAME%
if .%ERRORLEVEL%.==.0. goto branch002_added
echo Failed to add BRANCH002QM to the store-and-forward queue %GATEWAY_S_F_Q%.
goto ending
:branch002_added
echo Added BRANCH002QM to the store-and-forward queue %GATEWAY_S_F_Q%.

rem Send a test message to the MQSeries queue manager.
rem Note we use the BRIDGE_PACKAGE version of the tool here...                                                               
%JavaCmd% %BRIDGE_PACKAGE%.SendTestMessage %TARGET_MQ_Q% %CENTRAL_QMGR_NAME% %INI_FILE_NAME% 
if .%ERRORLEVEL%.==.0. goto test_msg_sent
echo Failed to send the test message to queue %TARGET_MQ_Q% on %CENTRAL_QMGR_NAME%.
goto ending
:test_msg_sent

rem kick-off the server program to keep the server running.
rem for now, we'll use the bridge example server...
%JavaCmd% examples.mqbridge.awt.AwtMQBridgeServer %INI_FILE_NAME%

rem We're done, so jump to the end of the script.
goto ending        

rem -------------------------------------------------------------------------
rem 
rem Error processing code.
rem 
rem -------------------------------------------------------------------------

:no_java_cmd
echo No JavaCmd environment variable set up.
echo Please update and run the JavaEnv.bat file, then retry.
goto ending

:no_mqe_base_dir
echo No MQE_BASE_DIR enviroment variable set up.
echo Please update and run the JavaEnv.bat file, then retry.
goto ending

:no_gateway_qmgr_addr
echo The GATEWAY_QMGR_ADDR variable not set. 
echo Edit the GatewayQMDetails.bat file. 
goto ending

:no_gateway_qmgr_port
echo The GATEWAY_QMGR_PORT variable not set. 
echo Edit the GatewayQMDetails.bat file. 
goto ending

:no_central_qmgr_name
echo The CENTRAL_QMGR_NAME variable not set. 
echo Edit the CentralQMDetails.bat file
goto ending

:no_central_qmgr_listening_port
echo The CENTRAL_QMGR_LISTENING_PORT variable not set. 
echo Edit the CentralQMDetails.bat file
goto ending

:no_central_qmgr_hostname
echo The CENTRAL_QMGR_HOSTNAME variable not set. 
echo Edit the CentralQMDetails.bat file
goto ending

:no_target_mq_q
echo The TARGET_MQ_Q variable not set. 
echo Edit the CentralQMDetails.bat file
goto ending


rem -------------------------------------------------------------------------
rem 
rem The end of the script. Exit.
rem 
rem -------------------------------------------------------------------------
:ending        
        
@endlocal 
