//Version mqe_java/source/examples/administration/commandline/RemoteQueueCreator.java, MQe, la200, la200-L030414.1 1.10

/*------------------------------------------------------------------------------*/

/*                   WebSphere MQ Everyplace for Multiplatforms                 */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 2001                                                 */

/*                                                                              */

/*------------------------------------------------------------------------------*/
package examples.administration.commandline; 


import com.ibm.mqe.*; 
import com.ibm.mqe.administration.*; 

import examples.queuemanager.*;
 
                           
/**
 * To start a queue manager and add a remote queue definition to its configuration.
 * 
 * <P><B>Syntax</B></P>
 * <P><TT>
 * java examples.administration.commandline.RemoteQueueCreator 
 * &lt;queue_name&gt;
 * &lt;hosting_queue_manager&gt;
 * &lt;mode&gt;
 * &lt;compressor&gt; 
 * &lt;cryptor&gt; 
 * &lt;authenticator&gt; 
 * &lt;queue_manager_name&gt; 
 * &lt;ini_file&gt;
 * &lt;storage_adapter&gt;
 * </TT></P>
 * <P><B>Parameters</B></P>
 * <DL>
 * <DT>queue_name</DT>
 * <DD>is the name of the remote queue we are creating.</DD>
 * <DT>hosting_queue_manager</DT>
 * <DD>is the name of the queue manager on which the queue actually exists.</DD>
 * <DT>mode</DT>
 * <DD>Either "Synchronous" or "Asynchronous"</DD>
 * <DT>compressor</DT>
 * <DD>The name of the class (or alias which resolves into a class) indicating which
 * compressor the queue should use to store messages on the disk.
 * Use "null" if you don't want a compressor.</DD>
 * <DT>cryptor</DT>
 * <DD>The name of the class (or alias which resolves into a class) indicating which
 * cryptor the queue should use to store messages on the disk.
 * Use "null" if you don't want a cryptor.</DD>
 * <DT>authenticator</DT>
 * <DD>The name of the class (or alias which resolves into a class) indicating which
 * authenticator the queue should use to store messages on the disk.
 * Use "null" if you don't want an authenticator.</DD>
 * <DT>queue_manager_name</DT>
 * <DD>is the name of the queue manager on which the remote queue
 * definition is to be created on.</DD>
 * <DT>ini_file</DT>
 * <DD>Name of the ini file used to open a client queue manager, to
 * send the admin messages from.</DD>
 * <DT>storageLocation</DT>
 * <DD>A string, following the syntax <TT>&lt;adapter&gt:&lt;path&gt;</TT> 
 * Where the adapter is a class name without the .class extension,
 * and the path is the name of the directory in which the files containing 
 * queue messages are stored.
 * eg: com.ibm.mqe.adapers.MQeDiskFieldsAdapter:C:\ServerQMgr23\RemoteQ48
 * Specify "default" if you want to set this to the default value chosen by MQe.</DD>
 * </DL>
 */
public class RemoteQueueCreator extends examples.administration.commandline.MQeAbstractCmdLineAdminTool { 

    public static short[] version = { 2, 0, 0, 10 }; 
    static final String syntax = 
        "Syntax:\n"
        + "java ...RemoteQueueCreator <queue_name> <hosting_queue_manager mode>\n"
        + "<compressor> <cryptor> <authenticator> <queue_manager_name> <ini_file>\n"
        + "Parameters:\n"
        + "queue_name\n"
        + "     is the name of the remote queue we are creating.\n"
        + "hosting_queue_manager\n"
        + "     is the name of the queue manager on which the queue actually exists.\n"
        + "mode\n"
        + "     is either 'Synchronous' or 'Asynchronous'\n"
        + "compressor\n"
        + "     The class name used to compress data before sending\n"
        + "cryptor\n"
        + "     The class name used to encrypt data before sending\n"
        + "authenticator\n"
        + "     The authenticator to use when someone tries to put data onto this queue\n"
        + "queue_manager_name\n"
        + "     is the name of the queue manager on which the remote queue\n"
        + "     definition is to be created on.\n"
        + "ini_file\n"
        + "     Name of the ini file used to open a client queue manager, to\n"
        + "     send the admin messages from.\n"
        + "storageLocation\n"
        + "     A string, following the syntax <adapter>:<path>\n"
        + "     Where the adapter is a class name without the .class extension,\n"
        + "     and the path is the name of the directory in which the files containing\n"
        + "     queue messages are stored.\n"
        + "     eg: com.ibm.mqe.adapers.MQeDiskFieldsAdapter:C:\\ServerQMgr23\\RemoteQ48\n";

    public static final String SYNCHRONOUS_PARAM = "Synchronous";
    public static final String ASYNCHRONOUS_PARAM = "Asynchronous";

    /**
     * Entry point from the command line.
     */
    public static void main(String args[]) {
        int rc = 0; 
        RemoteQueueCreator me = new RemoteQueueCreator();

        try {
            me.activate(args);
        } catch (Exception e) {
            System.out.println("Error: activate() failed. " + e.toString());
            rc = 1;
        }
        System.exit(rc); // exit,killing the trace window by force if necessary.
    }

    /**
     * Does all the work.
     * @param args
     * @return void
     * @exception java.lang.Exception
     */
    public void activate(String args[]) throws Exception {

        String q = null;        // Name of the remote queue we are creating.
        String qmgr = null;     // Name of the queue manager on which the remote queue definition is
        // to be created on. (and to which the admin msg will be sent)
        String hostingQMgr = null;  // Name of the queue manager on which the queue actually exists.
        String iniFile = null;      // Name of the ini file used to open a client queue manager, to 
        // send the admin messages from.
        String syncMode = null;     // The mode of the remote quuee... is it synchronous or async ?

        String compressorClass = null;
        String cryptorClass = null;
        String authenticatorClass = null;
        String storageLocation = null;

        if (args.length < 9) {
            throw new Exception("Not enough parameters !" + syntax);
        } 
        if (args.length > 9) {
            throw new Exception("Too many parameters !" + syntax);
        } 

        q = args[0].trim();
        hostingQMgr = args[1].trim();
        syncMode = args[2].trim();
        compressorClass = args[3].trim();
        cryptorClass = args[4].trim();
        authenticatorClass = args[5].trim();
        qmgr = args[6].trim();
        iniFile = args[7].trim();
        storageLocation = args[8].trim();

        System.out.println("i: Attempting to define a " + syncMode + " remote queue definition " + q
            + " on queue manager " + qmgr
            + " using the " + iniFile + " ini file."
            + " which refers to queue " + q + " on queue manager " + hostingQMgr
            + " which uses storage location " + storageLocation
        );
        
        // Access the local MQe queue manager...
        MQeClient client = new MQeClient(iniFile, true // suppress any stdout information.
            );

        // Access the queue manager created by the MQeClient class...
        MQeQueueManager myQMgr = MQeClient.queueManager;

        try {
            // Create the queue...
            if (syncMode.equals(SYNCHRONOUS_PARAM)) {
                createRemoteQueue(q, qmgr, hostingQMgr, myQMgr, MQeQueueAdminMsg.Queue_Synchronous, compressorClass, cryptorClass, authenticatorClass, storageLocation
                );
            } else {
                createRemoteQueue(q, qmgr, hostingQMgr, myQMgr, MQeQueueAdminMsg.Queue_Asynchronous, compressorClass, cryptorClass, authenticatorClass, storageLocation
                );
            }

        } catch (Exception e) {
            System.out.println("Exception " + e.toString());
        }

        // Close down the MQeClient
        client.close();
    } 

    /**
     * Creates an admin message which will create a queue, and sends it
     * to the queue manager.
     * 
     * @param q      The name of the queue to be created.
     * @param qmgr   The queue manager on which the remote queue definition will be created.
     * @param hostingQMgr
     *               The queue manager to which the new remote queue definition referrs.
     * @param myQMgr A reference to an active MQe queue manager, which will be used to send and receive
     *               MQe administration messages and responses.
     * @param synchronousMode
     *               Whether the remote queue is to be created in "synchronous" or "asynchronous" mode.
     * @param compressorClass
     *               The name of the compression class to use (or alias which resolves to a class name)
     *               Should include the .class extension.
     *               Specify "null" if you don't want to use a compressor.
     * @param cryptorClass
     *               The name of the cryptor class to use (or alias which resolves to a class name)
     *               Should include the .class extension.
     *               Specify "null" if you don't want to use a cryptor.
     * @param authenticatorClass
     *               The name of the authenticator class to use (or alias which resolves to a class name)
     *               Should include the .class extension.
     *               Specify "null" if you don't want to use an authenticator
     * @param storageLocation
     *               A string, following the syntax <TT>&lt;adapter&gt:&lt;path&gt;</TT> 
     *               Where the adapter is a class name without the .class extension,
     *               and the path is the name of the directory in which the files containing 
     *               queue messages are stored.
     *               eg: com.ibm.mqe.adapers.MQeDiskFieldsAdapter:C:\ServerQMgr23\RemoteQ48
     *               Specify "default" if you want to set this to the default value chosen by MQe.
     *  
     * @return void
     * @exception Exception
     */
    static public void createRemoteQueue(String q, String qmgr, String hostingQMgr, MQeQueueManager myQMgr, byte synchronousMode, String compressorClass, String cryptorClass, String authenticatorClass, String storageLocation
    ) throws Exception {

        System.out.println("Building the admin message to create a remote queue " + q
            + " on queue manager " + qmgr + " which refers to queue " + q
            + "on queue manager " + hostingQMgr + " sitting on adapter "
            + storageLocation);

        // Construct the RemoteQueueAdminMsg...

        MQeRemoteQueueAdminMsg msg = new MQeRemoteQueueAdminMsg(hostingQMgr, q);              

        // Set q and qmgr parts of the name into the message, 
        // either on the RemoteQueueAdminMsg constructor, or using the setName(...) method.

        // Create a parameters MQeFields object...
        MQeFields params = new MQeFields();

        // Populate the parameters MQeFields object with any values you want 
        // the new Remote Queue to be created with...
        // ... using putXXXX( fieldName , fieldValue ) calls

        params.putByte(MQeQueueAdminMsg.Queue_Mode, synchronousMode);

        // Fill the params with any other information we need for our queue definition.
        if (!cryptorClass.equals("null")) {
            params.putAscii(MQeQueueAdminMsg.Queue_Cryptor, cryptorClass);
        }
        if (!authenticatorClass.equals("null")) {
            params.putAscii(MQeQueueAdminMsg.Queue_Authenticator, authenticatorClass);
        }
        if (!compressorClass.equals("null")) {
            params.putAscii(MQeQueueAdminMsg.Queue_Compressor, compressorClass);
        }

        if (storageLocation.equals("default")) {// If we don't set the field to anything explicitly, it gets implicitly set
            // to a sensible default.
        } else {       
            params.putAscii(MQeQueueAdminMsg.Queue_FileDesc, storageLocation);
        }

        // Say this admin message should create the queue...
        msg.create(params);

        System.out.println("Built the admin message.");

        // Send the message.
        MQeFields results = sendWaitMessage(myQMgr, qmgr, msg);

        System.out.println("Remote queue created successfully.");
    }   
} 

