//Version mqe_java/source/examples/administration/commandline/StoreAndForwardQueueQMgrAdder.java, MQe, la200, la200-L030414.1 1.8

/*------------------------------------------------------------------------------*/

/*                   WebSphere MQ Everyplace for Multiplatforms                 */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 2001                                                 */

/*                                                                              */

/*------------------------------------------------------------------------------*/
package examples.administration.commandline; 


import com.ibm.mqe.*;
import com.ibm.mqe.administration.*;
import examples.queuemanager.*;
                             

/**
 * To start a queue manager, and add a remote queue manager name
 * to a store and forward queue that already exists.
 * 
 * <P><B>Syntax</B></P>
 * <P><TT>java examples.administration.commandline.StoreAndForwardQueueQMgrAdder 
 * &lt;queue_name&gt;
 * &lt;hosting_queue_manager&gt;
 * &lt;accepting_for_queue_manager&gt; 
 * &lt;queue_manager_name&gt; 
 * &lt;Ini_file&gt;
 * </TT></P>
 * <P><B>Parameters</B></P>
 * <DL>
 * <DT>queue_name</DT>
 * <DD>is the name of the remote queue we are creating.</DD>
 * <DT>hosting_queue_manager</DT>
 * <DD>is the name of the queue manager on which the messages will be pushed to.
 * Specify the name of the queue manager on which the queue exists if you wish
 * this store-and-forward queue to just collect messages, and have them retrieved by
 * a home-server queue.</DD>
 * <DT>accepting_for_queue_manager</DT>
 * <DD>The name of the queue manager for which this store-and-forward queue will
 * accept messages.</DD>
 * <DT>queue_manager_name</DT>
 * <DD>is the name of the queue manager on which the remote queue
 * definition is to be created on.</DD>
 * <DT>ini_file</DT>
 * <DD>Name of the ini file used to open a client queue manager, to
 * send the admin messages from.</DD>
 * </DL>
 */
public class StoreAndForwardQueueQMgrAdder extends examples.administration.commandline.MQeAbstractCmdLineAdminTool { 

    public static short[] version = { 2, 0, 0, 10 }; 
    static final String syntax = 
        "Syntax:\n"
        + "java StoreAndForwardQueueQMgrAdder <queue_name> <hosting_queue_manager> "
        + "<accepting_for_queue_manager> <queue_manager_name> <ini_file>\n"
        + "Parameters:\n"
        + "queue_name\n"
        + "     is the name of the remote queue we are creating.\n"
        + "hosting_queue_manager\n"
        + "     is the name of the queue manager on which the queue actually exists.\n"
        + "accepting_for_queue_manager\n"
        + "     The name of the queue manager for which this store-and-forward queue\n"
        + "     will accept messages.\n"
        + "queue_manager_name\n"
        + "     is the name of the queue manager on which the remote queue\n"
        + "     definition is to be created on.\n"
        + "ini_file\n"
        + "     Name of the ini file used to open a client queue manager, to\n"
        + "     send the admin messages from.\n";

    /**
     * Entry point from the command line.
     */
    public static void main(String args[]) {
        int rc = 0; 
        StoreAndForwardQueueQMgrAdder me = new StoreAndForwardQueueQMgrAdder();

        try {
            me.activate(args);
        } catch (Exception e) {
            System.out.println("Error: activate() failed. " + e.toString());
            rc = 1;
        }
        System.exit(rc); // exit,killing the trace window by force if necessary.
    }

    /**
     * Does all the work.
     * @param args
     * @return void
     * @exception java.lang.Exception
     */
    public void activate(String args[]) throws Exception {

        String q = null;        // Name of the S&F queue we are creating.
        String qmgr = null;     // Name of the queue manager on which the S&F definition is
        // to be created on. (and to which the admin msg will be sent)
        String hostingQMgr = null;  // Name of the queue manager on which the queue pushes to.
        String iniFile = null;      // Name of the ini file used to open a client queue manager, to 
        // send the admin messages from.
        String acceptForQMgr = null; // The queue manager this s&f q will accept messages for.

        if (args.length < 5) {
            throw new Exception("Not enough parameters !" + syntax);
        } 
        if (args.length > 5) {
            throw new Exception("Too many parameters !" + syntax);
        } 

        q = args[0].trim();
        hostingQMgr = args[1].trim();
        acceptForQMgr = args[2].trim();
        qmgr = args[3].trim();
        iniFile = args[4].trim();

        System.out.println("i: Attempting to add " + acceptForQMgr + " to the list of queue managers "
            + " which the store-and-forward queue definition " + q
            + " on queue manager " + qmgr + " will accept messages for."
            + " ...Using the " + iniFile + " ini file."
        );
        
        // Access the local MQe queue manager...
        MQeClient client = new MQeClient(iniFile, true // Supress stdout information
            );

        // Access the queue manager created by the MQeClient class...
        MQeQueueManager myQMgr = MQeClient.queueManager;

        try {
            // Add the qmgr name to the queue...
            addTargetQMgrToStoreAndForwardQueue(q, qmgr, hostingQMgr, myQMgr, acceptForQMgr
            );

        } catch (Exception e) {
            System.out.println("Exception " + e.toString());
        }

        // Close down the MQeClient
        client.close();
    }

    /**
     * Creates an admin message which will add a queue manager name to the list of queue managers
     * for which a particular store-and-forward will accept messages. The admin message is sent
     * and the replies received using a specified queue manager.
     * 
     * @param q      The name of the queue to be modified.
     * 
     * @param qmgr   The queue manager on which the S&F queue definition will be modified
     * 
     * @param hostingQMgr
     *                   The queue manager to which the store-and-forward queue pushes messages.
     * 
     * @param myQMgr A reference to an active MQe queue manager, which will be used to send and receive
     *               MQe administration messages and responses.
     * 
     * @param acceptForQMgr The name of an MQe queue manager for which this store-and-forward queue will
     *                   accept messages.
     * @return void
     * @exception Exception
     */
    static public void addTargetQMgrToStoreAndForwardQueue(String q, String qmgr, String hostingQMgr, MQeQueueManager myQMgr, String acceptForQMgr
    ) throws Exception {

        System.out.println("Building the admin message to create a store-and-forward queue " + q
            + " on queue manager " + qmgr + " which refers to queue " + q
            + "on queue manager " + hostingQMgr);

        // Construct the AdminMsg...
        MQeStoreAndForwardQueueAdminMsg msg = new MQeStoreAndForwardQueueAdminMsg(hostingQMgr, q);              
       
        // Indicate the fact that we want to add a queue manager to the S&F queue...
        msg.addQueueManager(acceptForQMgr);

        // Send the message.
        MQeFields results = sendWaitMessage(myQMgr, qmgr, msg);

        System.out.println("Add target was successful.");
    }  
} 
