// Version mqe_java/source/examples/administration/console/Admin.java, MQeExamples, la200, la200-L030324.1 1.19

/*------------------------------------------------------------------------------*
 *                    WebSphere MQ Everyplace for Multiplatforms                *
 *                                                                              *
 * Licensed Materials - Property of IBM                                         *
 *                                                                              *
 * 5765-E63                                                                     *
 *                                                                              *
 * (C) Copyright IBM Corp. 1999,2002                                            *
 *------------------------------------------------------------------------------*/
package examples.administration.console;


import com.ibm.mqe.*;
import examples.awt.*;
import examples.queuemanager.*;
import java.awt.*;


/****
 * <p>To provide a simple window interface for administering both local
 * and remote queue managers.
 *
 **/

public class Admin extends AwtFrame implements java.beans.PropertyChangeListener {

    /**
     * The version of the admin application.
     * Should be over-ridden by any subclass.
     * Displayed in the "about" dialog box.
     */
    public static short[] version = { 2, 0, 0, 10 }; 

    /**
     *  Some defaults
     */
    String defaultQM = "ExampleQM";
    String defaultReplyQ = MQe.Admin_Reply_Queue_Name;

    public boolean active = false;// Active ?
    boolean exitAtClose = true;     // Do a system.exit when app finished ?

    /**
     *  Admin function implenented in the admin model object
     */
    AdminModel  adminModel = null;

    /**
     * A panel to hold various buttons related to setup
     */
    Panel   setupActionP = new Panel();

    /**
     * For "Server" admin consoles, the start/stop qm buttons
     * are disabled. This boolean tells us whether the
     * buttons have been disabled.
     */
    private boolean startStopDisabled = false;

    /**
     * Message to tell the user to start/connect to a QMgr
     */
    private static final String PLEASE_START_QM = "Please start and/or connect to a Queue Manager.";

    /**
     * Message to tell the user to select an object on the left.
     */
    private static final String PLEASE_SELECT_OBJECT =
        "Select an object type from the left panel to work with it on the right.";

    /**
     *  A subset of the GUI widgets
     */
    TextField   localQMTF;          // Local queue manager name
    TextField   replyToQMTF;        // reply to queue manager name
    TextField   replyToQTF;         // reply to queue name
    TextField   manageQMTF;         // manage queue manager name
    TextField   statusTF;           // status field

    Choice      modeChoice;         // manage local or remote queue manager

    Button      startBut;           // Start queue manager button
    Button      stopBut;            // Stop queue manager button
    Button      connBut;            // Connect to queue manager button
    Button      disconnBut;         // Disconnect from queue manager button
    Button      replyQBut;          // Browse reply queue button

    Component   highlightedButton = null;  // The button that is currently highlighted

    /**
     * The title of the admin application
     * Can be over-ridden by any subclass.
     */
    public static String    appTitle = "Example MQe Admin Console";

    /**
     * One AdminFrame is created per resource type managed
     * Frames array contains:
     * 1st dim - an adminframe which holds fields required for chosen action
     * 2nd dim - a panel which contains actions allowed for managed resource
     */
    protected Object[][]    frames;

    /**
     * This flag becomes true once the user has click on
     * "Browse Reply Q". It stops the nag messages displayed
     * in the message status bar.
     */
    private boolean browseAdminReplyQClicked = false;

    /**
     * selectedResource = index of resource type that user wishes
     * to manage ( index of last button selected in west panel)
     */
    protected int           selectedResource;

    /**
     * Admin default constructor.
     */
    public Admin() throws Exception {
        super(appTitle);

        // No parms passed in, so see if there is an
        // active queue manager we can use.
        try {
            MQeQueueManager qmDefault =
                MQeQueueManager.getDefaultQueueManager();

            defaultQM = qmDefault.getName();
        } catch (Exception e) {}
    }

    /**
     * Admin constructor comment.
     * @param title java.lang.String
     *
     * @exception java.lang.Exception
     */
    public Admin(String[] args) throws Exception {
        super(appTitle);

        /**
         * Process the input parameters
         * arg[0] = queue manager name
         * arg[1] = ini file with QM startup parms ....
         */
        if (args.length > 0)
            defaultQM = args[0];

        if (args.length > 1) {

            /**
             * Startup parameters ini file specified
             * - store the ini file name
             * - load the ini file into a fields object
             * - retrive QMgr name from the fields object
             */
            getAdminModel().setQMgrStartupIniFile(args[1]);
        }
    }

    /**
     * Display the "about" dialog.
     * @param none
     * @return void
     */
    public void about() {
        String version = "MQe version " + MQe.version[0] +
            "." + MQe.version[1] +
            "." + MQe.version[2];

        String example = appTitle + this.version[0] +
            "." + this.version[1] +
            "." + this.version[2];

        new AwtDialog("About Admin", AwtDialog.Show_None,
            new String[][][]
            { { { "L", version}
                },
                { { "L", example}
                },
                { { "L", "Licensed Materials - Property of IBM"}
                },
                { { "L", "product number 5765-E63"}
                },
                { { "L", "(C) Copyright IBM Corp. 1999 All Rights Reserved"}
                },
                { { "B", "OK"}
                }
            }
        ).dispose();
    }

    /**
     * <p>Process an MQe awt event.
     * <p>Should be over-ridden by any subclass, but the super.Action() should be called
     * so we get to process the base admin application events here.
     * @param e java.lang.Object
     * @param where An integer indicating the location
     * @param index An integer containing the type of resource to be managed
     * @param choice java.lang.String
     * @param state A Boolean
     * @return void
     */
    public void action(Object e, int where, int index, String  choice, boolean state) {

        /**
         *  Read any values from the centre panel
         */
        if (modeChoice.getSelectedIndex() == 0)
            getAdminModel().setMode(false);       // Local mode
        else
            getAdminModel().setMode(true);        // Remote mode

        getAdminModel().setManageViaQM(localQMTF.getText());  // local QMgr name
        getAdminModel().setManageQM(manageQMTF.getText()); // manage QMgr name
        getAdminModel().setReplyToQM(replyToQMTF.getText());// reply to QMgr name
        getAdminModel().setReplyToQ(replyToQTF.getText()); // reply yo Queue name

        try {
            switch (where) {                          // based on N, S, E, W, C, M
            case West:
                // Handle change in the type of resource to be managed
                selectedResource = index;

                // Do some funky highlighting
                toggleHighlight(highlightedButton);
                highlightedButton = (Component) e;
                toggleHighlight(highlightedButton);

                switch (index) {
                // Setup
                case 0:
                    displayActions(setupActionP, "Setup");
                    message("Use the setup menu to work with various Admin Console options.");
                    break;

                    // Otherwise display manage resource frame
                default:
                    displayActions((Panel) frames[index][1],
                        ((AdminFrame) frames[index][0]).getResourceTitle());
                    message(((AdminFrame) frames[selectedResource][0]).getMessageHelp());

                }
                break;

            case East:

                //  Handle a specific resource action
                if (getPanel(East) == setupActionP) {
                    // Admin setup
                    actionSetup(e, where, index, choice, state);
                } else {
                    // Resource specific action
                    if (!browseAdminReplyQClicked) {
                        message("Remember to click 'Setup' > 'Browse reply queue' if you wish to see the results of any admin request!");
                    }
                    ((AdminFrame) frames[selectedResource][0]).resourceAction(e, where, index, choice, state);
                }
                break;
            }
        } catch (Exception ex) {
            // Error occured display it in message line
            message(ex.toString());
        }
    }

    /**
     * Process a request to browse the administration log.
     * @param e java.lang.Object
     * @param where An integer indicating the location
     * @param index An integer containing the type of resource to be managed
     * @param choice java.lang.String
     * @param state A Boolean
     * @return void
     * @exception java.lang.Exception
     */
    public void actionBrowseAdminLog(Object e, int where, int index, String  choice, boolean state) throws Exception {
        // Get the reply to queue details
        if (getAdminModel().getReplyToQ() == null || getAdminModel().getReplyToQ().equals("") ||
            getAdminModel().getReplyToQM() == null || getAdminModel().getReplyToQM().equals("")) {
            // No queue manager / queue specified
            message("Must specify reply to queue / queue manager");
        } else {
            // Display the queue
            getAdminModel().displayQueue(null, null, "QueueBrowserAdmin", getAdminModel().getLogBrowser());
        }
    }

    /**
     * Process an administration setup request.
     * @param e java.lang.Object
     * @param where An integer indicating the location
     * @param index An integer containing the type of resource to be managed
     * @param choice java.lang.String
     * @param state A Boolean
     * @return void
     * @exception java.lang.Exception
     */
    public void actionSetup(Object e, int where, int index, String  choice, boolean state) throws Exception {
        // Decide on which action user selected ?
        switch (index) {
        case 0:

            /**
             * Apply
             * input fields to be read are checked.
             * connection state is checked incase QM state has changed
             */
            checkConnected();
            checkMode();
            break;

        case 1:

            /**
             * Start the local QMgr
             */
            getStartupIni();
            if (getAdminModel().getQMgrStartupIniFile() != null)
                getAdminModel().startLocalQM();
            break;

        case 2:

            /**
             * Connect to started QMgr
             */
            getAdminModel().connectLocalQM();
            message(PLEASE_SELECT_OBJECT);
            break;

        case 3:

            /**
             * Disconnect from QMgr
             */
            getAdminModel().disconnectLocalQM();
            break;

        case 4:

            /**
             * Stop the local queue manager
             */
            getAdminModel().stopLocalQM();
            break;

            // Admin Log
        case 5:

            /**
             * browse the reply to queue
             */

            actionBrowseAdminLog(e, where, index, choice, state);
            browseAdminReplyQClicked = true;
            break;

        case 6:

            /**
             * Turn trace on.
             */
            AwtMQeTrace.open();
            break;

        case 7:

            /**
             * About
             */
            about();
            break;

        case 8:

            /**
             * Close
             */
            closeFrame();
            break;
        }
    }

    /**
     * Initialisation code.
     * @param none
     * @return void
     * @exception java.lang.Exception
     *
     */
    public void activate() throws Exception {
        if (!active) {

            /**
             * One off initialisation code
             */
            setWindowAliases();

            // Listen for changes to local queue manager administration
            // characteristics
            addPropertyChangeListener();

            // Setup the west panel with one button per managed resource
            // Setup a set of east panels, where each panel contains a
            // set of buttons, one for each action supported by the
            // managed resource.
            String[] resourceClasses = getResourceClasses();

            int noFrames = resourceClasses.length + 1;

            frames = new Object[noFrames][2];
            String[][][] westBut = new String[noFrames][1][2];

            // First west button is not a managed resource but
            // a setup button
            westBut[0][0][0] = "B";
            westBut[0][0][1] = "Setup";

            AwtFormat setupActionF = setupSetupPanel();

            // Initial action panel to display - the setup actions panel
            displayActions(setupActionP, "Setup");

            // Loop through all managed resource and setup east and
            // west panels.
            for (int i = 1; i < noFrames; i++) {
                AdminFrame frame = (AdminFrame) MQe.loadObject(resourceClasses[i - 1]);

                frame.setAdminModel(getAdminModel());
                frames[i][0] = frame;
                frames[i][1] = frame.getActionsPanel(this);

                frame.addAlias();
                westBut[i][0][0] = "B";
                westBut[i][0][1] = frame.getResourceTitle();
            }

            // Setup the master action buttons in west panel
            format(West, westBut);

            // Setup center panel to display administration characteristics
            format(Center, getCenterNLSLabels());

            // Setup the message line in the south panel
            format(South, getSouthNLSLabels());

            // Set up some global references to commonly-used widgets.
            setupWidgetReferences();

            // Highlight the setup menu...
            highlightedButton = (java.awt.Button) getObject('W', 0);
            toggleHighlight(highlightedButton);

            // Cause an action to ensure that everything is setup correctly
            // (simulate the apply button being pressed)
            action(setupActionF.getObject(0), East, 0, "", true);

            // Don't do a system.exit at shutdown if the QMgr is already started
            if (getAdminModel().isQMgrStarted())
                exitAtClose = false;

            // Initialised
            active = true;
        }

        // Show the window ...
        visible(true);
    }

    /*************************************************************************
     *
     * Sets up the admin frame as a property change listener.
     * This causes the events to be funnelled to our propertyChange() method.
     * @param none
     * @return void
     *************************************************************************/
    public void addPropertyChangeListener() {
        getAdminModel().addPropertyChangeListener(this);
    }

    /**
     * Setup based on state of the connection to the local queue manager.
     * @param none
     * @return void
     */
    public void checkConnected() {
        // Connected ?
        boolean con = getAdminModel().getConnected();

        // Only change the "stop qm" button if
        // we're not running as a server
        if (!startStopDisabled) {
            stopBut.setEnabled(con);
        }
        disconnBut.setEnabled(con);
        replyQBut.setEnabled(con);

        localQMTF.setEnabled(!con);

        // enable/disable any buttons on the west panel...
        setWestButtonStatus(con);

        if (con) {
            // Does the connected state match reality ? ( QM may
            // no longer be available !
            if (con != getAdminModel().isQMgrStarted())
                getAdminModel().setConnected(false);
            else {
                // we're connected
                // Only change the "start qm" button if
                // we're not running as a server.
                if (!startStopDisabled) {
                    startBut.setEnabled(!con);
                }

                connBut.setEnabled(!con);

                try {
                    // Queue manager name displayed will not match the
                    // the actual queue manager name in the case of
                    // the default queue manager. So get the real queue
                    // manager name
                    if (getAdminModel().getQM().getName() !=
                        getAdminModel().getManageViaQM()) {
                        getAdminModel().setManageViaQM(
                            getAdminModel().getQM().getName());
                    }
                } catch (Exception e) {}
            }
        } else {
            // not connected
            boolean avail = getAdminModel().isQMgrStarted();

            // Only change the "start qm" button if
            // we're not running as a server.
            if (!startStopDisabled) {
                startBut.setEnabled(!avail);
            }
            connBut.setEnabled(avail);
        }
    }

    /**
     * Setup based on state of the connection to the queue manager.
     * @param none
     * @return void
     */
    public void checkMode() {
        boolean rmode = getAdminModel().getMode();

        manageQMTF.setEnabled(rmode);
        replyToQMTF.setEnabled(rmode);

        if (!rmode) {
            // Local mode so ensure that local queue manager
            // and queue manager to be administered are the same
            manageQMTF.setText(localQMTF.getText());
            replyToQMTF.setText(localQMTF.getText());
        }
    }

    /**
     * Close window.
     * @param none
     * @return void
     */
    public void close() {
        closeFrame();
    }

    /**
     * Handel window closing event.
     * @param none
     * @return void
     */
    protected void closeFrame() {
        // Close any admin frames owned by this app
        for (int i = 1; i < frames.length; i++) {
            if (frames[i][0] != null)
                ((AdminFrame) frames[i][0]).closeFrame();
            frames[i][0] = null;
            frames[i][1] = null;
        }

        getAdminModel().closeMsgDisplay();      // Close any msg windows we opened
        getAdminModel().closeQueueDisplay();    // Close any queue browser windows.
        getAdminModel().disconnectLocalQM();    // disconnect from local queue manager.

        dispose();                             // finished with the window

        active = false;                         // Admin is no longer active

        // If exit at close then close the queue manager and trace cleanly
        // before exiting
        if (exitAtClose) {
            getAdminModel().stopLocalQM();      // Stop client queue manager
            AwtMQeTrace.close();
            System.exit(0);                     // Exit the JVM
        }
    }

    /**
     * Set the east panel to panel p and makes visible.
     * @param p Panel
     * @param title java.lang.String
     * @return void
     */
    public void displayActions(Panel p, String title) {
        // Hide east panel if it exists
        if (getPanel(East) != null) {
            visible(East, false);
        }

        // Display new east panel
        setPanel(East, p);
        visible(East, true);
        setTitle(appTitle + ": " + title);
    }

    /**
     * Return an admin model.
     * @param none
     * @return AdminModel
     */
    public AdminModel getAdminModel() {
        // If there is no admin model instantiate one
        if (adminModel == null) {
            adminModel = new AdminModel();
        };
        return adminModel;
    }

    /*************************************************************************
     *
     * Create a list of the labels which appear at the center of the admin
     * panel.
     * @param none
     * @return An array of java.lang.String array.
     *************************************************************************/
    public String[][][] getCenterNLSLabels() {
        String[][][] result = new String[][][]
            { { { "L", "Mode"},                     // 0
                    { "D", "Local", "Remote"}
                },        // 1
                { { "L", "Local Queue Manager"},      // 2
                    { "TK", defaultQM}
                },               // 3
                { { "L", "Manage Queue Manager"},     // 4
                    { "T", ""}
                },                       // 5
                { { "L", "Reply To Queue Manager"},   // 6
                    { "T", ""}
                },                       // 7
                { { "L", "Reply To Queue"},          // 8
                    { "T", defaultReplyQ}
                },            // 9
            };

        return result;
    }

    /**
     * Returns the set of AdminFrames for resources to be managed.
     * @param none
     * @return java.lang.String[]
     */
    public String[] getResourceClasses() {
        return  new String[] {  "examples.administration.console.AdminQueueManager",
                "examples.administration.console.AdminConnection",
                "examples.administration.console.AdminQueue",
                "examples.administration.console.AdminRemoteQueue",
                "examples.administration.console.AdminAdminQueue",
                "examples.administration.console.AdminStoreAndForwardQueue",
                "examples.administration.console.AdminHomeServerQueue",
                "examples.administration.console.AdminCommsListener"
            };
    }

    /*************************************************************************
     *
     * Gets a list of the label fields to use at the southern end of the Admin
     * panel.
     * @param none
     * @return An array of String Array.
     *************************************************************************/
    public String[][][] getSouthNLSLabels() {
        String[][][] result = new String[][][]
            { { { "TP", PLEASE_START_QM }
                }
            };

        return result;
    }

    /**
     * Get queue manager startup parms from ini file.
     * @param none
     * @return MQeFields Object
     * @exception java.lang.Exception
     */
    public MQeFields getStartupIni() throws Exception {
        MQeFields f;

        // Get the default ini file naem
        String iniFile = getAdminModel().getQMgrStartupIniFile();

        if (iniFile == null || iniFile.equals(""))
            iniFile = "*.ini";

        // Instantiate a file dialog
        FileDialog iniFD = new FileDialog(this, "Queue manager startup ini file", FileDialog.LOAD);

        iniFD.setFile(iniFile);
        iniFD.show();

        // Validate input
        if (iniFD.getFile() == null) {
            // dialog cancelled so do nothing
            f = null;
            getAdminModel().setQMgrStartupIniFile(null);
        } else {
            // now load the file and store details
            f = MQeQueueManagerUtils.loadConfigFile(iniFD.getDirectory() + iniFD.getFile());
            getAdminModel().setQMgrStartupIniFile(iniFD.getDirectory() + iniFD.getFile());
            getAdminModel().setManageViaQM(f.getFields(MQeQueueManager.QueueManager).getAscii(MQeQueueManager.Name));
        }

        return f;
    }

    /**
     * Main method.
     * standalone startup of Example administration gui.
     * @param args
     * @return void
     */
    public static void main(String[] args) {
        try {

            /**
             * Instantiate the application
             */
            new Admin(args).activate();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Display a message.
     * @param msg java.lang.String containing the message to be displayed.
     * @return void
     */
    public void message(String msg) {
        getAdminModel().setStatus(msg);
    }

    /**
     * Method to handle events for the PropertyChangeListener interface.
     * @param evt java.beans.PropertyChangeEvent
     * @return void
     */
    public void propertyChange(java.beans.PropertyChangeEvent evt) {
        if ((evt.getSource() == getAdminModel()) && (evt.getPropertyName().equals("manageViaQM"))) {
            // local queue manager has a key listener so each key pressed causes the queue manager name
            // to change. Hence the need to store and then restore the cursor position.
            int cur = localQMTF.getCaretPosition();

            localQMTF.setText(getAdminModel().getManageViaQM());
            localQMTF.setCaretPosition(cur);
            checkConnected();
        }

        if ((evt.getSource() == getAdminModel()) && (evt.getPropertyName().equals("manageQM"))) {
            // Queue manager name changed so display it
            manageQMTF.setText(getAdminModel().getManageQM());
        }

        if ((evt.getSource() == getAdminModel()) && (evt.getPropertyName().equals("replyToQM"))) {
            // Reply to queue manager name changed so display it
            replyToQMTF.setText(getAdminModel().getReplyToQM());
        }

        if ((evt.getSource() == getAdminModel()) && (evt.getPropertyName().equals("replyToQ"))) {
            // Reply to queue name changed so display it
            replyToQTF.setText(getAdminModel().getReplyToQ());
        }

        if ((evt.getSource() == getAdminModel()) && (evt.getPropertyName().equals("connected"))) {
            // Connection state changed - process it
            checkConnected();
        }

        if ((evt.getSource() == getAdminModel()) && (evt.getPropertyName().equals("status"))) {
            // new message so display it
            statusTF.setText(getAdminModel().getStatus());
        }

        if ((evt.getSource() == getAdminModel()) && (evt.getPropertyName().equals("mode"))) {
            // local / remote mode changed - process it
            checkMode();
        }

    }

    /*************************************************************************
     *
     * Set up some panels with the correct labels, putting references to the
     * panels in global data members, for future reference.
     * @param none
     * @return AwtFormat The format object for the initial panel layout.
     *
     *************************************************************************/
    public AwtFormat setupSetupPanel() {
        // The east panel shows actions in context with the master action
        // selected in the west panel
        // ..Queue manager setup actions
        AwtFormat setupActionF = new AwtFormat(this, East);

        setupActionP = setupActionF.panel(setupActionP, new String[][][]
                    { { { "B", "Apply"}
                        },               // 0
                        { { "B", "Start QM"}
                        },            // 1
                        { { "B", "Connect QM"}
                        },          // 2
                        { { "B", "Disconnect QM"}
                        },       // 3
                        { { "B", "Stop QM"}
                        },             // 4
                        { { "B", "Browse reply queue"}
                        },  // 5
                        { { "B", "Trace"}
                        },               // 6
                        { { "B", "About"}
                        },        // 7
                        { { "B", "Close"}
                        }         // 8

                    }
                );

        // Set up some global references to commonly used buttons...
        startBut = (java.awt.Button) setupActionF.getObject(1);
        connBut = (java.awt.Button) setupActionF.getObject(2);
        disconnBut = (java.awt.Button) setupActionF.getObject(3);
        stopBut = (java.awt.Button) setupActionF.getObject(4);
        replyQBut = (java.awt.Button) setupActionF.getObject(5);

        // Return the initial setup panel format...
        return setupActionF;
    }

    /*************************************************************************
     *
     * Sets up the global references to the widgets we will want to
     * obtain information from later on...
     * @param none
     * @return void
     *************************************************************************/
    public void setupWidgetReferences() {
        // Get references to some of the GUI widgets

        // Widgets from the central panel...
        modeChoice = (java.awt.Choice) getObject('C', 1);
        localQMTF = (java.awt.TextField) getObject('C', 3);
        manageQMTF = (java.awt.TextField) getObject('C', 5);
        replyToQMTF = (java.awt.TextField) getObject('C', 7);
        replyToQTF = (java.awt.TextField) getObject('C', 9);

        // South pabel text field...
        statusTF = (java.awt.TextField) getObject('S', 0);
    }

    /**
     * Enables/disables the buttons on the west panel depending on the value specified.
     * @param state boolean
     * @return void
     *
     **/
    public void setWestButtonStatus(boolean state) {
        // Enable the setup button
        ((java.awt.Button) getObject('W', 0)).setEnabled(true);

        // Disable all other buttons on the west panel.
        for (int i = 1; i < frames.length; i++) {
            ((java.awt.Button) getObject('W', i)).setEnabled(state);
        }
    }

    /*************************************************************************
     * Set up some aliases.
     * @param none
     * @return void
     * @exception java.lang.Exception
     *************************************************************************/
    void setWindowAliases() throws Exception {
        // ... queue browse windows
        MQe.alias("QueueBrowserDefault",
            "examples.administration.console.AdminQueueBrowser");
        MQe.alias("QueueBrowserAdmin",
            "examples.administration.console.AdminLogModel");
    }

    /**
     * Disables startqm/stopqm buttons in the setup panel.
     * This is because these buttons are not appropriate
     * for server qms (these buttons only start and stop *client* qms).
     * @param none
     * @return void
     */
    public void disableStartStopQMButtons() {
        startBut.setEnabled(false);
        stopBut.setEnabled(false);
        startStopDisabled = true;
    }

    /**
     * Sets the current component to inverse video.
     * @param e Component
     * @return void
     */
    private void toggleHighlight(Component e) {
        if (e != null) {
            Color fg = e.getForeground();
            Color bg = e.getBackground();

            e.setForeground(bg);
            e.setBackground(fg);
        }
    }

}
