// Version mqe_java/source/examples/administration/console/AdminAdminQueue.java, MQeExamples, la200, la200-L030324.1 1.6

/* -----------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/* -----------------------------------------------------------------------------*/
package examples.administration.console;


import com.ibm.mqe.*;
import com.ibm.mqe.administration.*;
import java.util.*;
import examples.awt.*;
import java.awt.*;


/**
 *                                                                              
 * <p>Specialisation of AdminFrame allowing for administration of the         
 * administration queue.                                                                        
 **/
public class AdminAdminQueue extends AdminQueue {
    public          static short version[] = { 2, 0, 0, 10 }; 

    /**
     * Warning displayed if the user tries to get a message from an AdminQ.
     */
    private static final String ADMINQ_GET_MESSAGE_NOT_ALLOWED =
        "It is not possible to get messages directly from Admin Queues.\n\n" +
        "The WebSphere MQ Everyplace Queue Manager retrieves all messages\n" +
        "placed on Admin Queues in order to service the requests that the\n" +
        "messages contain.\n";

    /**
     * Default constructor.
     */
    public AdminAdminQueue() {
        super();
    }

    /**
     * Main constructor.
     * @param msg An administration message to contain the parameters for the action. 
     * If it already contains any parameters then these are taken as defaults.
     * @param action  The action to be performed
     * @param adminModel The administration model which will send the message.
     * @exception java.lang.Exception
     */
    public AdminAdminQueue(MQeAdminMsg msg, int action, AdminModel adminModel) throws Exception {
        super(msg, action, adminModel);
    }

    /**
     * AdminQueue constructor.
     * @param title java.lang.String
     * @exception java.lang.Exception
     */
    public AdminAdminQueue(String title) throws Exception {
        super(title);
    }

    /**
     * Add any aliases related to this resource.
     * @param none
     * @return void
     * @exception java.lang.Exception
     */
    public void addAlias() throws Exception {
        MQe.alias("MQeAdminQueueAdminMsgGUI",
            "examples.administration.console.AdminAdminQueue");

    }

    /**
     * Configure the valid set of actions.
     * @param none
     * @return A String Array.
     */
    protected String[][] getAddCharacteristics() {
        String[][] addA = new String[][] {
                { MQeAdminQueueAdminMsg.Queue_QTimerInterval, "O"}
            };

        int addElems = addA.length;

        String[][] smallA = super.getAddCharacteristics();
        String[][] newA = new String[smallA.length + addElems][];

        System.arraycopy(smallA, 0, newA, 0, smallA.length);
        System.arraycopy(addA, 0, newA, smallA.length, addElems);

        return  newA;
    }

    /**
     * Return the name of resource being managed.
     * @param none
     * @return java.lang.String
     */
    public String getResourceTitle() {
        return "Admin Queue";
    }

    /**
     * Return an actions panel.
     * @param eventHandler An AwtEvent
     * @return A Panel
     */
    public Panel getActionsPanel(AwtEvent eventHandler) {
        String[][][] qActions = new String[][][]
            { { { "B", "Inquire"}
                },            // 0
                { { "B", "Create"}
                },           // 1
                { { "B", "Update"}
                },           // 2
                { { "B", "Delete"}
                },           // 3
                { { "B", "Add Alias"}
                },        // 4
                { { "B", "Remove Alias"}
                },     // 5
                { { "B", "Browse"}
                },           // 6
                { { "B", "Put Test Inquiry"}
                }, // 7
                { { "B", "(Get Message)"}
                },    // 8
            };

        // ..Queue actions
        AwtFormat actionF = new AwtFormat(eventHandler, East);

        return  actionF.panel(new Panel(), qActions);
    }

    /**
     * Configure the valid set of actions.
     * @param none
     * @return A String Array
     */
    protected String[][] getUpdateCharacteristics() {
        String[][] addA = new String[][] {
                { MQeAdminQueueAdminMsg.Queue_QTimerInterval, "O"}
            };

        int addElems = addA.length;

        String[][] smallA = super.getUpdateCharacteristics();
        String[][] newA = new String[smallA.length + addElems][];

        System.arraycopy(smallA, 0, newA, 0, smallA.length);
        System.arraycopy(addA, 0, newA, smallA.length, addElems);

        return  newA;
    }

    /**
     * Process a queue action request.
     * @param e java.lang.Object
     * @param where An integer indicating the location
     * @param index An integer containing the type of resource to be managed
     * @param choice java.lang.String
     * @param state A boolean
     * @return void
     * @exception java.lang.Exception
     */
    public void resourceAction(Object e, int where, int index, String  choice, boolean state) throws Exception {
        int act = -1;       // Unknown action

        boolean doAdmin = true;

        // Decide on which action user selected ?
        switch (index) {
        case 0:
            act = MQeQueueAdminMsg.Action_InquireAll;
            break;

        case 1:
            act = MQeQueueAdminMsg.Action_Create;
            break;

        case 2:
            act = MQeQueueAdminMsg.Action_Update;
            break;

        case 3:
            act = MQeQueueAdminMsg.Action_Delete;
            break;

        case 4:
            act = MQeQueueAdminMsg.Action_AddAlias;
            break;

        case 5:
            act = MQeQueueAdminMsg.Action_RemoveAlias;
            break;

        case 6:
            act = AdminQueue.Action_Browse;
            break;

        case 7:
            // Clicking the "Put test message to admin queue" button
            // is the same as clicking inquire.
            act = MQeQueueAdminMsg.Action_InquireAll;
            break;

        case 8:
            new AwtDialog("Error", AwtDialog.Show_OK, new String[][][] { { { "AP", ADMINQ_GET_MESSAGE_NOT_ALLOWED}
                    }
                }
            );
            doAdmin = false;

        }

        if (doAdmin) {
            // Display the message in a window
            activate(new MQeAdminQueueAdminMsg(adminModel.getManageQM(), MQe.Admin_Queue_Name),
                act, adminModel);
        }

    }

    /**
     * Configure the valid set of actions.
     * @param none
     * @return void
     */
    protected void setupActions() {
        super.setupActions();

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_Create),
            getAddCharacteristics());

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_Update),
            getUpdateCharacteristics());

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_InquireAll),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_Delete),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_AddAlias),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"},
                { AdminQueue.Queue_Alias, "M"}
            }
        );

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_RemoveAlias),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"},
                { AdminQueue.Queue_Alias, "M"}
            }
        );

        addAction(new String().valueOf(AdminQueue.Action_Browse),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

        addAction(new String().valueOf(AdminQueue.Action_PutTestMessage),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

        addAction(new String().valueOf(AdminQueue.Action_GetMessage),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

    }

    /**
     * <p>Setup the valid set of characteristics.
     * <p>The sequence is important as this is the sequence that the fields
     * will displayed.
     * @param none
     * @return void
     */
    protected void setupFields() {
        super.setupFields();

        addCharacteristic(MQeAdminQueueAdminMsg.Queue_QTimerInterval, "TF", null);
    }

    /**
     * Setup NLS names.
     * @param none
     * @return void
     */
    protected void setupNLS() {
        super.setupNLS();

        addNLSName(MQeAdminQueueAdminMsg.Queue_QTimerInterval, "Timer interval");

    }

    /**
     * Returns a string that provides information about the current frame.
     * This is displayed in the south panel of the main admin gui when a frame is selected.
     * @param none
     * @return String documenting the current frame.
     */
    public String getMessageHelp() {
        return "The Admin Queue holds messages that configure the MQe Queue Manager.";
    }
}
