// Version mqe_java/source/examples/administration/console/AdminQueueManager.java, MQeExamples, la200, la200-L030324.1 1.10

/* -----------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/* -----------------------------------------------------------------------------*/
package examples.administration.console;


import com.ibm.mqe.*;
import com.ibm.mqe.administration.*;
import examples.awt.*;
import java.awt.*;


/***
 *
 * Specialisation of AdminFrame allowing for administration of a
 * a queue manager.
 **/

public class AdminQueueManager extends AdminFrame {
    public static short[] version = { 2, 0, 0, 10 }; 

    /**
     * Default constructor.
     */
    public AdminQueueManager() {
        super("Queue Manager Administration");
    }

    /**
     * Main constructor.
     * @param msg An administration message to contain the parameters for the action.
     * If it already contains any parameters then these are taken as defaults.
     * @param action  The action to be performed
     * @param adminModel The administration model which will send the message.
     * @exception java.lang.Exception
     *
     */
    public AdminQueueManager(MQeAdminMsg msg, int action, AdminModel adminModel) throws Exception {
        super(msg, action, adminModel);
    }

    /**
     * AdminQueueManager constructor.
     * @param title java.lang.String
     * @exception java.lang.Exception
     */
    public AdminQueueManager(String title) throws Exception {
        super(title);
    }

    /**
     * Add any aliases related to this resource.
     * @param none
     * @return void
     * @exception java.lang.Exception
     */
    public void addAlias() throws Exception {
        MQe.alias("MQeQueueManagerAdminMsgGUI",
            "examples.administration.console.AdminQueueManager");

    }

    /**
     * Return an actions panel.
     * @param eventHandler An AwtEvent
     * @return A Panel
     */
    public Panel getActionsPanel(AwtEvent eventHandler) {
        AwtFormat actionF = new AwtFormat(eventHandler, East);

        // ..Queue manager actions
        return  actionF.panel(new Panel(), new String[][][]
                {
                    { { "B", "Inquire"}
                    },            // 0
                    { { "B", "Update"}
                    }              // 1
                }
            );
    }

    /**
     * Return the name of resource being managed.
     * @param none
     * @return java.lang.String
     */
    public String getResourceTitle() {
        return "Queue Manager";
    }

    /**
     * Process a queue manager action request.
     * @param e java.lang.Object
     * @param where An integer indicating the location
     * @param index An integer containing the type of resource to be managed
     * @param choice java.lang.String
     * @param state A boolean
     * @return void
     * @exception java.lang.Exception
     */
    public void resourceAction(Object e, int where, int index, String  choice, boolean state) throws Exception {
        int act = -1;       // Unknown action

        // Decide on which action user selected ?
        switch (index) {
        case 0:
            act = MQeQueueManagerAdminMsg.Action_InquireAll;
            break;

        case 1:
            act = MQeQueueManagerAdminMsg.Action_Update;
            break;
        }

        // Display the message in a window
        activate(new MQeQueueManagerAdminMsg(adminModel.getManageQM()),
            act, adminModel);
    }

    /**
     * Setup the admin message with the action to be performed and the
     * parameters required by the action.
     * @param parms MQeFields object
     * @return MQeAdminMsg
     * @exception java.lang.Exception
     */
    public MQeAdminMsg setupAction(MQeFields parms) throws Exception {
        switch (new Integer(action).intValue()) {
        case MQeQueueManagerAdminMsg.Action_InquireAll:
            // Inquire
            ((MQeQueueManagerAdminMsg) msg).inquireAll(parms);
            break;

        case MQeQueueManagerAdminMsg.Action_Update:
            // Update
            ((MQeQueueManagerAdminMsg) msg).update(parms);
            break;
        }
        return (MQeQueueManagerAdminMsg) msg;
    }

    /**
     * Configure the set of actions.
     * @param none
     * @return void
     */
    protected void setupActions() {
        super.setupActions();

        addAction(new String().valueOf(MQeQueueManagerAdminMsg.Action_Update),
            new String[][] {
                { MQeQueueManagerAdminMsg.Admin_Name, "M"},
                { MQeQueueManagerAdminMsg.QMgr_Description, "O"},
                { MQeQueueManagerAdminMsg.QMgr_Rules, "O"},
                { MQeQueueManagerAdminMsg.QMgr_ChnlAttrRules, "O"},
                { MQeQueueManagerAdminMsg.QMgr_ChnlTimeout, "O"},
                { MQeQueueManagerAdminMsg.QMgr_QueueStore, "O"},
                { MQeQueueManagerAdminMsg.QMgr_MaximumTransmissionThreads, "O"}
            }
        );

        addAction(new String().valueOf(MQeQueueManagerAdminMsg.Action_InquireAll),
            new String[][] {
                { MQeQueueManagerAdminMsg.Admin_Name, "M"}
            }
        );

    }

    /**
     * Setup the valid set of characteristics.
     * <p>The sequence is important as this is the sequence that the fields
     * will displayed.
     * @param none
     * @return void
     */
    protected void setupFields() {
        super.setupFields();

        addCharacteristic(MQeQueueManagerAdminMsg.Admin_Name, "TF", null);
        addCharacteristic(MQeQueueManagerAdminMsg.QMgr_Description, "TF", null);
        addCharacteristic(MQeQueueManagerAdminMsg.Admin_Class, "TF", null);
        addCharacteristic(MQeQueueManagerAdminMsg.QMgr_Rules, "TF", null);
        addCharacteristic(MQeQueueManagerAdminMsg.QMgr_ChnlTimeout, "TF", null);
        addCharacteristic(MQeQueueManagerAdminMsg.QMgr_ChnlAttrRules, "TF", null);
        addCharacteristic(MQeQueueManagerAdminMsg.QMgr_QueueStore, "TF", null);
        addCharacteristic(MQeQueueManagerAdminMsg.QMgr_Queues, "C", null);
        addCharacteristic(MQeQueueManagerAdminMsg.QMgr_Connections, "C", null);
        addCharacteristic(MQeQueueManagerAdminMsg.QMgr_CommsListeners, "C", null);
        addCharacteristic(MQeQueueManagerAdminMsg.QMgr_BridgeCapable, "TF", null);
        addCharacteristic(MQeQueueManagerAdminMsg.QMgr_MaximumTransmissionThreads, "TF", null);
    }

    /**
     * Setup NLS names.
     * @param none
     * @return void
     */
    protected void setupNLS() {
        super.setupNLS();

        addNLSName(MQeQueueManagerAdminMsg.Admin_Class, "Class *");
        addNLSName(MQeQueueManagerAdminMsg.Admin_Name, "Name");
        addNLSName(MQeQueueManagerAdminMsg.QMgr_Description, "Description");
        addNLSName(MQeQueueManagerAdminMsg.QMgr_QueueStore, "Default Queue Store *");
        addNLSName(MQeQueueManagerAdminMsg.QMgr_Queues, "Queues");
        addNLSName(MQeQueueManagerAdminMsg.QMgr_Connections, "Connections");
        addNLSName(MQeQueueManagerAdminMsg.QMgr_CommsListeners, "Comms Listeners");
        addNLSName(MQeQueueManagerAdminMsg.QMgr_Rules, "Rules *");
        addNLSName(MQeQueueManagerAdminMsg.QMgr_ChnlTimeout, "Channel Timeout *");
        addNLSName(MQeQueueManagerAdminMsg.QMgr_ChnlAttrRules, "Channel Attribute Rules *");
        addNLSName(MQeQueueManagerAdminMsg.QMgr_BridgeCapable, "Bridge capable");
        addNLSName(MQeQueueManagerAdminMsg.QMgr_MaximumTransmissionThreads, "Max Transmit Threads");
        addNLSName((new String()).valueOf(MQeQueueManagerAdminMsg.Action_InquireAll), "Inquire");
        addNLSName((new String()).valueOf(MQeQueueManagerAdminMsg.Action_Update), "Update");
        addNLSName("cancel", "Cancel");
    }

    /**
     * Returns a string that provides information about the current frame.
     * This is displayed in the south panel of the main admin gui when a frame is selected.
     * @param none
     * @return String documenting the current frame.
     */
    public String getMessageHelp() {
        return "The MQe Queue Manager maintains a set of Queues and Connections.";
    }
}
