// Version mqe_java/source/examples/administration/console/AdminRemoteQueue.java, MQeExamples, la000 1.8

/* -----------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/* -----------------------------------------------------------------------------*/
package examples.administration.console;


import com.ibm.mqe.*;
import com.ibm.mqe.administration.*;
import java.util.*;
import java.awt.*;
import examples.awt.*;


/**
 * Specialisation of AdminQueue allowing for administration of a           
 * a remote queue.                                                         
 *                                                                              
 **/
public class AdminRemoteQueue extends AdminQueue {
    public    static short  version[] = { 2, 0, 0, 10 }; 

    /**
     * Default constructor.
     */
    public AdminRemoteQueue() {
        super();
    }

    /**
     * Main constructor.
     * @param msg An administration message to contain the parameters for the action. 
     * If it already contains any parameters then these are taken as defaults.
     * @param action  The action to be performed
     * @param adminModel The administration model which will send the message.
     * @exception java.lang.Exception
     *
     */
    public AdminRemoteQueue(MQeAdminMsg msg, int action, AdminModel adminModel) throws Exception {
        super(msg, action, adminModel);
    }

    /**
     * AdminQueue constructor.
     * @param title java.lang.String
     * @exception java.lang.Exception
     */
    public AdminRemoteQueue(String title) throws Exception {
        super(title);
    }

    /**
     * Add any aliases related to this resource.
     * @param none
     * @return void
     * @exception java.lang.Exception
     */
    public void addAlias() throws Exception {
        MQe.alias("MQeRemoteQueueAdminMsgGUI",
            "examples.administration.console.AdminRemoteQueue");

    }

    /**
     * Configure the valid set of actions.
     * @param none
     * @return A String Array.
     */
    protected String[][] getAddCharacteristics() {
        String[][] addA = new String[][]
            {
                { MQeRemoteQueueAdminMsg.Queue_Transporter, "M"},
                { MQeRemoteQueueAdminMsg.Queue_TransporterXOR, "O"},
                { MQeRemoteQueueAdminMsg.Queue_CloseIdle, "O"}
            };

        int addElems = addA.length;

        String[][] smallA = super.getAddCharacteristics();
        String[][] newA = new String[smallA.length + addElems][];

        System.arraycopy(smallA, 0, newA, 0, smallA.length);
        System.arraycopy(addA, 0, newA, smallA.length, addElems);

        return  newA;
    }

    /**
     * Return the name of resource being managed.
     * @param none
     * @return java.lang.String
     */
    public String getResourceTitle() {
        return "Remote Queue";
    }

    /**
     * Configure the valid set of actions.
     * @param none
     * @return A String Array
     */
    protected String[][] getUpdateCharacteristics() {
        String[][] addA = new String[][]
            {
                { MQeRemoteQueueAdminMsg.Queue_Transporter, "M"},
                { MQeRemoteQueueAdminMsg.Queue_TransporterXOR, "O"},
                { MQeRemoteQueueAdminMsg.Queue_CloseIdle, "O"}
            };

        int addElems = addA.length;

        String[][] smallA = super.getAddCharacteristics();
        String[][] newA = new String[smallA.length + addElems][];

        System.arraycopy(smallA, 0, newA, 0, smallA.length);
        System.arraycopy(addA, 0, newA, smallA.length, addElems);

        return  newA;
    }

    /**
     * Process a queue action request.
     * @param e java.lang.Object
     * @param where An integer indicating the location
     * @param index An integer containing the type of resource to be managed
     * @param choice java.lang.String
     * @param state A boolean
     * @return void
     * @exception java.lang.Exception
     */
    public void resourceAction(Object e, int where, int index, String  choice, boolean state) throws Exception {
        int act = -1;       // Unknown action

        // Decide on which action user selected ?
        switch (index) {
        case 0:
            act = MQeQueueAdminMsg.Action_InquireAll;
            break;

        case 1:
            act = MQeQueueAdminMsg.Action_Create;
            break;

        case 2:
            act = MQeQueueAdminMsg.Action_Update;
            break;

        case 3:
            act = MQeQueueAdminMsg.Action_Delete;
            break;

        case 4:
            act = MQeQueueAdminMsg.Action_AddAlias;
            break;

        case 5:
            act = MQeQueueAdminMsg.Action_RemoveAlias;
            break;

        case 6:
            act = AdminQueue.Action_Browse;
            break;

        case 7:
            act = AdminQueue.Action_PutTestMessage;
            break;

        case 8:
            act = AdminQueue.Action_GetMessage;
            break;
        }

        // Display the message in a window
        activate(new MQeRemoteQueueAdminMsg(),
            act, adminModel);

    }

    /**
     * Configure the valid set of actions.
     * @param none
     * @return void
     */
    protected void setupActions() {
        super.setupActions();

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_Create),
            getAddCharacteristics());

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_Update),
            getUpdateCharacteristics());

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_InquireAll),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_Delete),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_AddAlias),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"},
                { AdminQueue.Queue_Alias, "M"}
            }
        );

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_RemoveAlias),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"},
                { AdminQueue.Queue_Alias, "M"}
            }
        );

        addAction(new String().valueOf(AdminQueue.Action_Browse),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

        addAction(new String().valueOf(AdminQueue.Action_PutTestMessage),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

        addAction(new String().valueOf(AdminQueue.Action_GetMessage),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

    }

    /**
     * <p>Setup the valid set of characteristics.
     * <p>The sequence is important as this is the sequence that the fields
     * will displayed.
     * @param none
     * @return void
     */
    protected void setupFields() {
        super.setupFields();

        addCharacteristic(MQeRemoteQueueAdminMsg.Queue_Transporter, "TF", null);
        addCharacteristic(MQeRemoteQueueAdminMsg.Queue_TransporterXOR, "TF", null);
        addCharacteristic(MQeRemoteQueueAdminMsg.Queue_CloseIdle, "TF", null);
    }

    /**
     * Setup NLS names.
     * @param none
     * @return void
     */
    protected void setupNLS() {
        super.setupNLS();

        addNLSName(MQeRemoteQueueAdminMsg.Queue_Transporter, "Transporter class *");
        addNLSName(MQeRemoteQueueAdminMsg.Queue_TransporterXOR, "Network compression? *");
        addNLSName(MQeRemoteQueueAdminMsg.Queue_CloseIdle, "Close when idle *");
    }

    /**
     * Returns a string that provides information about the current frame.
     * This is displayed in the south panel of the main admin gui when a frame is selected.
     * @param none
     * @return String documenting the current frame.
     */
    public String getMessageHelp() {
        return "Remote Queues are references to queues on other Queue Managers.";
    }
}
