// Version mqe_java/source/examples/administration/console/AdminStoreAndForwardQueue.java, MQeExamples, la200, la200-L030324.1 1.7

/* -----------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/* -----------------------------------------------------------------------------*/
package examples.administration.console;


import com.ibm.mqe.*;
import com.ibm.mqe.administration.*;
import java.util.*;
import examples.awt.*;
import java.awt.*;


/*
 * Specialisation of AdminFrame allowing for administration of a           
 * a queue.                                                                                              
 */
public class AdminStoreAndForwardQueue extends AdminQueue {
    public    static short  version[] = { 2, 0, 0, 10 }; 

    // Additional actions
    // ...

    // Additional fields that are not part of the admin message itself.

    // target queue manager name
    public final static String     Queue_TargetQMgr = "targetQMgr";

    /**
     * Warning displayed if the user tries to put a message to a SAFQ.
     */
    private static final String SAFQ_PUT_MESSAGE_NOT_ALLOWED =
        "It is not possible to put messages directly to Store and Forward Queues.\n\n" +
        "These queues collect messages for multiple remote queue\n" +
        "managers, and the Store and Forward queue holds these messages\n" +
        "until collected or pushed to their destinations.\n" +
        "In order to make use of a Store and Forward Queue, messages\n" +
        "should be addressed to the final destination queue/queue manager.\n" +
        "The Store and Forward Queue will collect the message as\n" +
        "long as a remote queue definition does not already exist.";

    /**
     * Warning displayed if the user tries to get a message from a SAFQ.
     */
    private static final String SAFQ_GET_MESSAGE_NOT_ALLOWED =
        "It is not possible to get messages directly from Store and Forward Queues.\n\n" +
        "These queues can collect messages for multiple remote queue\n" +
        "managers, and the Store and Forward queue may be configured\n" +
        "to push messages to these queue managers automatically.\n" +
        "Alternatively a Home Server Queue may exist on each remote\n" +
        "queue manager, which collects any messages waiting for it\n" +
        "from the Store and Forward Queue.";

    /**
     * Default constructor.
     */
    public AdminStoreAndForwardQueue() {
        super();
    }

    /**
     * Main constructor.
     * @param msg An administration message to contain the parameters for the action. 
     * If it already contains any parameters then these are taken as defaults.
     * @param action  The action to be performed
     * @param adminModel The administration model which will send the message.
     * @exception java.lang.Exception
     *
     */
    public AdminStoreAndForwardQueue(MQeAdminMsg msg, int action, AdminModel adminModel) throws Exception {
        super(msg, action, adminModel);
    }

    /**
     * AdminQueue constructor.
     * @param title java.lang.String
     * @exception java.lang.Exception
     */
    public AdminStoreAndForwardQueue(String title) throws Exception {
        super(title);
    }

    /**
     * Add any aliases related to this resource.
     * @param none
     * @return void
     * @exception java.lang.Exception
     */
    public void addAlias() throws Exception {
        MQe.alias("MQeStoreAndForwardQueueAdminMsgGUI",
            "examples.administration.console.AdminStoreAndForwardQueue");

    }

    /**
     * Return an actions panel.
     * @param eventHandler An AwtEvent
     * @return A Panel
     */
    public Panel getActionsPanel(AwtEvent eventHandler) {
        String[][][] qActions = new String[][][]
            {
                { { "B", "Inquire"}
                },             // 0
                { { "B", "Create"}
                },              // 1
                { { "B", "Update"}
                },              // 2
                { { "B", "Delete"}
                },              // 3
                { { "B", "Add Alias"}
                },           // 4
                { { "B", "Remove Alias"}
                },        // 5
                { { "B", "Add Queue Manager"}
                },   // 6
                { { "B", "Remove Queue Manager"}
                },// 7
                { { "B", "Browse"}
                },              // 8
                { { "B", "(Put Test Message)"}
                },    // 9
                { { "B", "(Get Message)"}
                },         // 10

            };

        // ..Queue actions
        AwtFormat actionF = new AwtFormat(eventHandler, East);

        return  actionF.panel(new Panel(), qActions);
    }

    /**
     * Get the set of characteristics for the managed object.
     * @param none
     * @return MQeFields object
     * @exception java.lang.Exception
     */
    public MQeFields getCharacteristics() throws Exception {
        MQeFields fields = super.getCharacteristics();

        fields.putAscii(Queue_TargetQMgr, null);

        return fields;
    }

    /**
     * Return the name of resource being managed.
     * @param none
     * @return java.lang.String
     */
    public String getResourceTitle() {
        return "Store and Forward Queue";
    }

    /**
     * Process a queue manager action request.
     * @param e java.lang.Object
     * @param where An integer indicating the location
     * @param index An integer containing the type of resource to be managed
     * @param choice java.lang.String
     * @param state A boolean
     * @return void
     * @exception java.lang.Exception
     */
    public void resourceAction(Object e, int where, int index, String  choice, boolean state) throws Exception {
        int act = -1;       // Unknown action

        boolean doAdmin = true;

        // Decide on which action user selected ?
        switch (index) {
        case 0:
            act = MQeQueueAdminMsg.Action_InquireAll;
            break;

        case 1:
            act = MQeQueueAdminMsg.Action_Create;
            break;

        case 2:
            act = MQeQueueAdminMsg.Action_Update;
            break;

        case 3:
            act = MQeQueueAdminMsg.Action_Delete;
            break;

        case 4:
            act = MQeQueueAdminMsg.Action_AddAlias;
            break;

        case 5:
            act = MQeQueueAdminMsg.Action_RemoveAlias;
            break;

        case 6:
            act = MQeStoreAndForwardQueueAdminMsg.Action_AddQueueManager;
            break;

        case 7:
            act = MQeStoreAndForwardQueueAdminMsg.Action_RemoveQueueManager;
            break;

        case 8:
            act = AdminQueue.Action_Browse;
            break;

        case 9:
            new AwtDialog("Error", AwtDialog.Show_OK, new String[][][] { { { "AP", SAFQ_PUT_MESSAGE_NOT_ALLOWED}
                    }
                }
            );
            doAdmin = false;
            break;

        case 10:
            new AwtDialog("Error", AwtDialog.Show_OK, new String[][][] { { { "AP", SAFQ_GET_MESSAGE_NOT_ALLOWED}
                    }
                }
            );
            doAdmin = false;
            break;
        }

        // Display the message in a window
        if (doAdmin) {
            activate(new MQeStoreAndForwardQueueAdminMsg(adminModel.getManageQM(), "qname"),
                act, adminModel);
        }

    }

    /**
     * Setup the admin message with the action to be performed and the
     * parameters required by the action.
     * @param msg MQeFields object
     * @return MQeAdminMsg object
     * @exception java.lang.Exception
     */
    public MQeAdminMsg setupAction(MQeFields parms) throws Exception {
        MQeStoreAndForwardQueueAdminMsg m = (MQeStoreAndForwardQueueAdminMsg) msg;

        switch (new Integer(action).intValue()) {
        case MQeStoreAndForwardQueueAdminMsg.Action_AddQueueManager:
            // Add an alias
            m.setName(parms.getAscii(MQeQueueAdminMsg.Admin_Name));
            m.addQueueManager(parms.getAscii(Queue_TargetQMgr));

            if (parms.contains(MQeQueueAdminMsg.Queue_QMgrName))
                m.getInputFields().putAscii(MQeQueueAdminMsg.Queue_QMgrName,
                    parms.getAscii(MQeQueueAdminMsg.Queue_QMgrName));
            break;

        case MQeStoreAndForwardQueueAdminMsg.Action_RemoveQueueManager:
            // Remove an alias
            m.setName(parms.getAscii(MQeQueueAdminMsg.Admin_Name));
            m.removeQueueManager(parms.getAscii(Queue_TargetQMgr));

            if (parms.contains(MQeQueueAdminMsg.Queue_QMgrName))
                m.getInputFields().putAscii(MQeQueueAdminMsg.Queue_QMgrName,
                    parms.getAscii(MQeQueueAdminMsg.Queue_QMgrName));
            break;

        default:
            // otherwise leave it to the super class
            super.setupAction(parms);
        }
        return (MQeQueueAdminMsg) msg;
    }

    /**
     * Configure the valid set of actions.
     * @param none
     * @return void
     */
    protected void setupActions() {
        super.setupActions();

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_Create),
            getAddCharacteristics());

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_Update),
            getUpdateCharacteristics());

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_InquireAll),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_Delete),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_AddAlias),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"},
                { AdminQueue.Queue_Alias, "M"}
            }
        );

        addAction(new String().valueOf(MQeQueueAdminMsg.Action_RemoveAlias),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"},
                { AdminQueue.Queue_Alias, "M"}
            }
        );

        addAction(new String().valueOf(AdminQueue.Action_Browse),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

        addAction(new String().valueOf(AdminQueue.Action_PutTestMessage),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

        addAction(new String().valueOf(AdminQueue.Action_GetMessage),
            new String[][] {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"}
            }
        );

        addAction(new String().valueOf(MQeStoreAndForwardQueueAdminMsg.Action_AddQueueManager),
            new String[][]
            {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"},
                { AdminStoreAndForwardQueue.Queue_TargetQMgr, "M"}
            }
        );

        addAction(new String().valueOf(MQeStoreAndForwardQueueAdminMsg.Action_RemoveQueueManager),
            new String[][]
            {
                { MQeQueueAdminMsg.Admin_Name, "M"},
                { MQeQueueAdminMsg.Queue_QMgrName, "O"},
                { AdminStoreAndForwardQueue.Queue_TargetQMgr, "M"}
            }
        );
    }

    /**
     * <p>Setup the valid set of characteristics.
     * <p>The sequence is important as this is the sequence that the fields
     * will displayed.
     * @param none
     * @return void
     */
    protected void setupFields() {
        super.setupFields();

        addCharacteristic(MQeStoreAndForwardQueueAdminMsg.Queue_QMgrNameList, "C", null);
        addCharacteristic(AdminStoreAndForwardQueue.Queue_TargetQMgr, "TF", null);
    }

    /**
     * Setup NLS names.
     * @param none
     * @return void
     */
    protected void setupNLS() {
        super.setupNLS();

        addNLSName(MQeStoreAndForwardQueueAdminMsg.Queue_QMgrNameList, "Target Queue Managers");
        addNLSName(AdminStoreAndForwardQueue.Queue_TargetQMgr, "Target Queue Manager");

        addNLSName((new String()).valueOf(MQeStoreAndForwardQueueAdminMsg.Action_AddQueueManager), "Add Queue Manager");
        addNLSName((new String()).valueOf(MQeStoreAndForwardQueueAdminMsg.Action_RemoveQueueManager), "Remove Queue Manager");

    }

    /**
     * Returns a string that provides information about the current frame.
     * This is displayed in the south panel of the main admin gui when a frame is selected.
     * @param none
     * @return String documenting the current frame.
     */
    public String getMessageHelp() {
        return "MQe may use Store and Forward Queues to hold messages destined for other Queue Managers.";
    }
}
