// Version mqe_java/source/examples/administration/console/AdminTextField.java, MQeExamples, la200, la200-L030324.1 1.4

/* -----------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/* -----------------------------------------------------------------------------*/
package examples.administration.console;


import java.awt.*;
import java.awt.event.*;


/**
 * <p>To provide a simple gui component providing a visual indication when    
 * a text field has changed. The indication is a check box which the user  
 * can manually update to force a text field to be marked as changed.      
 *                                                                              
 * <p>This is used in the admin code to provide the user a means to force     
 * a default value to be included in an admin message. By default, default 
 * values are not included in admin messages, keeping the message size to  
 * a minimum.                                                                                                   
 *                                                                              
 **/

public class AdminTextField extends java.awt.Panel {
    public    static short  version[] = { 2, 0, 0, 10 }; 

    public String      initialValue;   // The intial value of the field

    protected Checkbox    cb = null;      // Visual indicaiton of modified field
    protected TextField   tf = null;      // The text field

    // Event handler used to determine when a text value change event
    // has occured
    TFEventHandler eventH = new TFEventHandler();

    // Internal class invoked when a text value change event occurs.
    class TFEventHandler implements TextListener {
        public void textValueChanged(TextEvent e) {
            if (e.getSource() == AdminTextField.this.tf) {
                // If current value is different to original value then
                // set visual indication that field has chagned. If the field
                // value is the same then reset visual indication.
                if (initialValue == null || !initialValue.equals(tf.getText()))
                    cb.setState(true);
                else
                    cb.setState(false);
            }
        };
    };

    /**
     * AdminTextField default constructor.
     */
    public AdminTextField() {
        super();
        initialize();
    }

    /**
     * AdminTextField default constructor.
     * @param layout java.awt.LayoutManager
     */
    public AdminTextField(java.awt.LayoutManager layout) {
        super(layout);
        initialize();
    }

    /**
     * Constructor which takes the initial value to be displayed.
     * @param initValue Intial value to be displayed
     */
    public AdminTextField(String initValue) {
        super();
        initialValue = initValue;   // Remeber the initial value

        initialize();               // setup the gui widget
    }

    /**
     * Get the current value of text in the text field.
     * @param none
     * @return java.lang.String
     */
    public String getText() {
        return tf.getText();
    }

    /**
     * Build the GUI widget.
     * @param none
     * @return void
     */
    public void initialize() {
        cb = new Checkbox();                    // Visual indication widget
        tf = new TextField(initialValue);     // Textfield

        setLayout(new java.awt.BorderLayout()); // Use border layout
        add(tf, "Center");                      // Add textfield to center
        add(cb, "East");                        // and checkbox to east

        // Ensure we are notified when the text field is changed.
        tf.addTextListener(eventH);
    }

    /**
     * Determine if the text field value has changed from its original
     * value.
     * @param none
     * @return boolean
     */
    public boolean isChanged() {
        return cb.getState();
    }
}
