package examples.administration.simple;


// Version mqe_java/source/examples/administration/simple/Example1.java, MQeExamples, la200, la200-L030324.1 1.10
/*------------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 2002                                                 */

/*------------------------------------------------------------------------------*/

import com.ibm.mqe.*;
import com.ibm.mqe.administration.*;
import examples.application.*;


/***
 *  Creates and deletes a queue.
 *
 *  Example showing how to:
 * <pre>
 *  . start a queue manager
 *  . create a new queue
 *  . put a message to it
 *  . delete the queue (which will fail as a message exists)
 *  . get a message from it
 *  . delete the queue
 * </pre>
 *
 **/
public class Example1 extends ExampleAdminBase {
    public static short[] version = { 2, 0, 0, 10 }; 
    String  newQueue = "Xanadu";

    /**
     * Constructor that uses the default queue manager.
     * @exception java.lang.Exception
     */
    public Example1() throws Exception {
        super();
    }

    /**
     * Constructor that uses the queue manager passed in on the command line.
     * @param qmName java.lang.String
     * @exception java.lang.Exception
     */
    public Example1(String queueManagerName) throws Exception {
        super(queueManagerName);
    }

    /**
     * Constructor that starts a queue manager with paramters
     * from an ini file. This queue manager is then used as the
     * access point for interacting with the same or different
     * queue managers.
     * @param qMgrName java.lang.String, queue manager name.
     *        The name of the queue manager to interact with.
     *        The queue manager can be a local or a remote queue
     *        manager.
     * @param localQMIniFile java.lang.String, ini file which
     *        contains startup parameters for the local queue
     *        manager.
     *@exception java.lang.Exception
     */
    public Example1(String qMgrName, String localQMgrIniFile) throws Exception {
        super(qMgrName, localQMgrIniFile);
    }

    /**
     * Creates a new queue.
     * @param none
     * @return void
     * @exception java.lang.Exception
     */
    protected void createQueue() throws Exception {
        System.out.println("..Setup an admin message to create queue " + newQueue);

        /*
         * Create an empty queue admin message and parameters field
         */
        MQeQueueAdminMsg msg = new MQeQueueAdminMsg();
        MQeFields parms = new MQeFields();

        /*
         * Prime message with who to reply to and a unique identifier
         */
        MQeFields msgTest = primeAdminMsg(msg);

        /*
         * Set name of queue to manage
         */
        msg.setName(qMgrName, newQueue);

        /*
         * Add any characteristics of queue here, otherwise
         * charateristics will be left to default values.
         */
        parms.putUnicode(MQeQueueAdminMsg.Queue_Description, "Queue created by " + example);

        // set the directory where the queue will reside.
        parms.putAscii(MQeQueueAdminMsg.Queue_FileDesc, "MsgLog:.\\");

        /*
         * Set the admin action to create a new queue
         */
        msg.create(parms);

        /*
         *  Put the admin message to the admin queue
         */
        System.out.println("..Put admin message to QM/queue: " + qMgrName + "/" + MQe.Admin_Queue_Name);
        myQM.putMessage(qMgrName, MQe.Admin_Queue_Name, msg, null, 0);

        /*
         * Wait a while for the response message
         */
        MQeAdminMsg respMsg = waitForReply(msgTest);

        /*
         * Check that a good reply was received
         */
        checkReply(respMsg);

        System.out.println("..Queue creation Successful");
    }

    /**
     * Deletes a queue.
     * @param none
     * @return void
     * @exception java.lang.Exception
     */
    protected void deleteQueue() throws Exception {
        System.out.println("..Setup an admin message to delete queue " + newQueue);

        /*
         * Create an empty queue admin message and parameters field
         */
        MQeQueueAdminMsg msg = new MQeQueueAdminMsg();

        /*
         * Prime message with who to reply to and a unique identifier
         */
        MQeFields msgTest = primeAdminMsg(msg);

        /*
         * Set the parameters for the request
         */
        msg.setName(qMgrName, newQueue);

        /*
         * Set the admin action to create a new queue
         */
        msg.delete(new MQeFields());

        /*
         *  Put the admin message to the admin queue
         */
        System.out.println("..Put admin message to QM/queue: " + qMgrName + "/" + MQe.Admin_Queue_Name);
        myQM.putMessage(qMgrName, MQe.Admin_Queue_Name, msg, null, 0);

        /*
         * Wait a while for the response message
         */
        MQeAdminMsg respMsg = waitForReply(msgTest);

        /*
         * Check that a good reply was received
         */
        checkReply(respMsg);

        System.out.println("..Queue deletion Successful");
    }

    /**
     * All work is performed in this method.
     * @param none
     * @return void
     * @exception java.lang.Exception
     */
    public void doIt() throws Exception {
        try {

            /*
             * Create a queue
             */
            createQueue();

            /*
             * Create a msg with some data
             */
            System.out.println("..Create a message with data:" + msgData);
            MQeMsgObject msgObj1 = new MQeMsgObject();

            msgObj1.putAscii(msgField, msgData);

            /*
             * Put the msg to the new queue
             */
            System.out.println("..Put message to QM/queue: " + qMgrName + "/" + newQueue);
            myQM.putMessage(qMgrName, newQueue, msgObj1, null, 0);

            /*
             * Try to delete the queue - this should fail as there is a msg
             * on the queue
             */
            try {
                deleteQueue();
            } catch (Exception e) {
                System.out.println("..Queue deletion failed as expected!");
            }

            /*
             * Get the msg from the queue
             */
            MQeMsgObject msgObj = myQM.getMessage(qMgrName, newQueue, null, null, 0);

            System.out.println("..Message retrieved contains data " + msgObj.getAscii(msgField));

            /*
             * Delete the queue
             */
            deleteQueue();

            System.out.println(example + " Finished");
        } catch (Exception e) {
            e.printStackTrace();
            System.out.println(example + " Failed! " + e);
            throw e;
        } finally {

            /*
             * Clean up
             */
            close();
        }
    }

    /**
     * Starts the application.
     * @param param1  Queue Manager Name to interact with.
     * If queue manager name matches the local QM name then
     * all interactions are local otherwise the local QM acts
     * as a stub QM sending all messages to a remote QM.
     * @param param2 Local queue manager startup parameters ini file
     *
     * @return void
     * @exception java.lang.Exception
     */
    public static void main(String args[]) throws Exception {
        short rc = 0;

        try {
            if (args.length == 0)
                new Example1().doIt();
            else if (args.length == 1)
                new Example1(args[0]).doIt();
            else
                new Example1(args[0], args[1]).doIt();
        } catch (Exception ex) {
            System.out.println("Example failed: " + ex);
            ex.printStackTrace();
            rc = 99;
        }
        System.exit(rc);
    }

    /**
     * Over-ride default parameter settings.
     * @param none
     * @return void
     *
     */
    public void setParms() {
        super.setParms();
        example = "Example1";
        msgData = example + ": Mary Mary quite contrary";
    }
}
