package examples.administration.simple;


// Version mqe_java/source/examples/administration/simple/Example3.java, MQeExamples, la200, la200-L030324.1 1.10
/*------------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 2002                                                 */

/*------------------------------------------------------------------------------*/

import java.util.*;
import com.ibm.mqe.*;
import com.ibm.mqe.administration.*;
import examples.application.*;


/***
 * Inquires on the characteristics of MQe resources.
 *
 * Example showing how to:
 * <pre>
 *  . inquire on the characteristics of a queue manager
 *  . inquire on the characteristics of a queue
 * </pre>
 *
 **/
public class Example3 extends ExampleAdminBase {
    public static short[] version = { 2, 0, 0, 10 }; 
    MQeAdminMsg qMgrMsg = null;

    /**
     * Constructor that uses the default queue manager.
     * @exception java.lang.Exception
     */
    public Example3() throws Exception {
        super();
    }

    /**
     * Constructor that uses the queue manager passed in on the command line.
     * @param qmName java.lang.String
     * @exception java.lang.Exception
     */
    public Example3(String queueManagerName) throws Exception {
        super(queueManagerName);
    }

    /**
     * Constructor that starts a queue manager with paramters
     * from an ini file. This queue manager is then used as the
     * access point for interacting with the same or different
     * queue managers.
     * @param qMgrName java.lang.String, queue manager name
     *        The name of the queue manager to interact with.
     *        The queue manager can be a local or a remote queue
     *        manager.
     * @param localQMIniFile java.lang.String, ini file which
     *        contains startup parameters for the local queue
     *        manager.
     * @exception java.lang.Exception
     */
    public Example3(String qMgrName, String localQMgrIniFile) throws Exception {
        super(qMgrName, localQMgrIniFile);
    }

    /**
     * All work is performed in this method.
     * @param none
     * @return void
     * @exception java.lang.Exception
     */
    public void doIt() throws Exception {
        try {

            /*
             * Get the queue managers characteristics
             */
            inquireQMgr();

            /*
             * Now lets inquire on all of the queues owned by the queue manager
             */
            MQeFields[] queues = qMgrMsg.getOutputFields().getFieldsArray(MQeQueueManagerAdminMsg.QMgr_Queues);

            for (int i = 0; i < queues.length; i++) {
                if (queues[i] != null)
                    inquireQueue(queues[i].getAscii(MQeQueueManagerAdminMsg.QMgr_QueueQMgrName),
                        queues[i].getAscii(MQeQueueManagerAdminMsg.QMgr_QueueName));
            }

            System.out.println(example + " Finished");
        } catch (Exception e) {
            e.printStackTrace();
            System.out.println(example + " Failed! " + e);
            throw e;
        } finally {

            /*
             * Clean up
             */
            close();
        }
    }

    /**
     * All work is performed in this method.
     * @param none
     * @return void
     * @exception java.lang.Exception
     */
    public void inquireQMgr() throws Exception {
        System.out.println("..Setup an admin message to inquire on queue manager: " + qMgrName);

        /*
         * Create an empty queue manager admin message and parameters field
         */
        MQeQueueManagerAdminMsg msg = new MQeQueueManagerAdminMsg();

        /*
         * Prime message with who to reply to and a unique identifier
         */
        MQeFields msgTest = primeAdminMsg(msg);

        /*
         * Set name of queue manager
         */
        msg.setName(qMgrName);

        /*
         * Set the admin action to get all characteristics of queue manager.
         */
        msg.inquireAll(new MQeFields());

        /*
         *  Put the admin message to the admin queue
         */
        System.out.println("..Put admin message to QM/queue: " + qMgrName + "/" + MQe.Admin_Queue_Name);
        myQM.putMessage(qMgrName, MQe.Admin_Queue_Name, msg, null, 0);

        /*
         * Wait a while for the response message
         */
        qMgrMsg = waitForReply(msgTest);

        /*
         * Response message arrived.
         * Check it was successful   .
         */
        checkReply(qMgrMsg);

        /*
         * Dump the result to stdout
         */
        System.out.println(qMgrMsg.getOutputFields().dumpToString("QMgr Inquire result  #0\t#1\t=#2\r\n"));
    }

    /**
     * All work is performed in this method.
     * @param remQMgrName Name of the QMgr
     * @param remQName Name of the Queue.
     * @return void
     * @exception java.lang.Exception
     */
    public void inquireQueue(String remQMgrName, String remQName) throws Exception {
        System.out.println("..Setup an admin message to inquire on queue: " + remQMgrName + "/ " + remQName);
        System.out.println("..on queue manager: " + qMgrName);

        /*
         * Create an empty queue  admin message and parameters field
         */
        MQeQueueAdminMsg msg = new MQeQueueAdminMsg();

        /*
         * Prime message with who to reply to and a unique identifier
         */
        MQeFields msgTest = primeAdminMsg(msg);

        /*
         * Set name of queue manager
         */
        msg.setName(remQMgrName, remQName);

        /*
         * Set the admin action to get all characteristics of queue manager.
         */
        msg.inquireAll(new MQeFields());

        /*
         *  Put the admin message to the admin queue
         */
        System.out.println("..Put admin message to QM/queue: " + qMgrName + "/" + MQe.Admin_Queue_Name);
        myQM.putMessage(qMgrName, MQe.Admin_Queue_Name, msg, null, 0);

        /*
         * Wait a while for the response message
         */
        MQeAdminMsg respMsg = null;

        System.out.println("..Wait for a response to the request");
        respMsg = (MQeAdminMsg) myQM.waitForMessage(qMgrName, queueName, msgTest, null, 0, waitFor);

        /*
         * Response message arrived.
         * Check it was successful   .
         */
        checkReply(respMsg);

        /*
         * Dump the result to stdout
         */
        System.out.println(respMsg.getOutputFields().dumpToString("Inquire result  #0\t#1\t=#2\r\n"));
    }

    /**
     * Starts the application.
     * @param param1  Queue Manager Name to interact with.
     * If queue manager name matches the local QM name then
     * all interactions are local otherwise the local QM acts
     * as a stub QM sending all messages to a remote QM.
     * @param param2 Local queue manager startup parameters ini file
     *
     * @return void
     * @exception java.lang.Exception
     */
    public static void main(String args[]) throws Exception {
        short rc = 0;

        try {
            if (args.length == 0)
                new Example3().doIt();
            else if (args.length == 1)
                new Example3(args[0]).doIt();
            else
                new Example3(args[0], args[1]).doIt();
        } catch (Exception ex) {
            System.out.println("Example failed: " + ex);
            ex.printStackTrace();
            rc = 99;
        }
        System.exit(rc);
    }

    /**
     * Over-ride default parameter settings.
     * @param none
     * @return void
     */
    public void setParms() {
        super.setParms();
        example = "Example3";
        msgData = example + ": Mary Mary quite contrary";
    }
}
