package examples.administration.simple;


// Version mqe_java/source/examples/administration/simple/ExampleAdminBase.java, MQeExamples, la200, la200-L030324.1 1.11
/*------------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 2002                                                 */

/*------------------------------------------------------------------------------*/
import java.util.*;
import com.ibm.mqe.*;
import java.io.*;
import examples.application.*;


/***
 * To provide the base class/object for example administration
 * applications.
 *
 ***/

abstract public class ExampleAdminBase extends ExampleBase {
    public static short[] version = { 2, 0, 0, 10 }; 
    int     waitFor = 10000;      // How long to wait for reply message

    /**
     * Constructor that uses the default queue manager.
     * @exception java.lang.Exception
     */
    public ExampleAdminBase() throws Exception {
        super();
    }

    /**
     * Constructor that runs the example against a remote queue manager.
     * @exception java.lang.Exception
     * @param QMgrName java.lang.String - remote queue manager
     */
    public ExampleAdminBase(String queueManagerName) throws Exception {
        super(queueManagerName);
    }

    /**
     * Constructor that starts a queue manager with paramters
     * from an ini file. This queue manager is then used as the
     * access point for interacting with the same or different
     * queue managers.
     * @param qMgrName java.lang.String, queue manager name
     *        The name of the queue manager to interact with.
     *        The queue manager can be a local or a remote queue
     *        manager.
     * @param localQMIniFile java.lang.String, ini file which
     *        contains startup parameters for the local queue
     *        manager.
     * @exception java.lang.Exception
     */
    public ExampleAdminBase(String qMgrName, String localQMgrIniFile) throws Exception {
        super(qMgrName, localQMgrIniFile);
    }

    /**
     * Check to see if a good reply was required.
     * If not, detail the error(s) that occured.
     * @param replyMsg reply message to check
     * @return boolean  true if good
     * @exception java.lang.Exception
     */
    public boolean checkReply(MQeAdminMsg replyMsg) throws Exception {
        // Was a reply received ?
        if (replyMsg == null) {
            System.out.println("..No response received to the request");
            throw new MQeException("No response message received");
        }

        if (replyMsg.getRC() != MQeAdminMsg.RC_Success) {
            System.out.println("..Action Failed: " + replyMsg.getReason());

            // If mixed then list each error that occured
            if (replyMsg.getRC() == MQeAdminMsg.RC_Mixed) {
                MQeFields errors = replyMsg.getErrorFields();
                Enumeration en = errors.fields();

                // process each error
                while (en.hasMoreElements()) {
                    String value[];
                    String name = (String) en.nextElement();

                    if (errors.dataType(name) == MQeFields.TypeArrayElements)
                        value = errors.getAsciiArray(name);
                    else
                        value = new String[] { errors.getAscii(name) };

                    for (int j = 0; j < value.length; j++)
                        System.out.println("Field in error: " + name + "  " + value[j]);
                }
            }
            // Failed - throw exception
            throw new MQeException(replyMsg.getReason());
        }
        return true;    // All is OK
    }

    /**
     * Prime the admin message.
     * Set the admin message with who to reply to along with a unique
     * identifier.
     * @param msg  The admin message to prime
     * @return MQeFields, a unique identifier for this request
     * @exception java.lang.Exception
     */
    public MQeFields primeAdminMsg(MQeAdminMsg msg) throws Exception {

        /*
         * Set the target queue manager that will process this message
         */
        msg.setTargetQMgr(qMgrName);

        /*
         * Ask for a reply message
         */
        msg.putInt(MQe.Msg_Style, MQe.Msg_Style_Request);
        msg.putAscii(MQe.Msg_ReplyToQ, queueName);
        msg.putAscii(MQe.Msg_ReplyToQMgr, qMgrName);

        /*
         *  Setup the correl id so we can match the reply to the request
         */
        msg.putArrayOfByte(MQe.Msg_CorrelID, Long.toHexString(MQe.uniqueValue()).getBytes());

        /*
         * Ensure matching response message is retrieved
         */
        MQeFields msgTest = new MQeFields();

        msgTest.putArrayOfByte(MQe.Msg_CorrelID, msg.getArrayOfByte(MQe.Msg_CorrelID));

        /*
         * Return the unique filter for this message
         */
        return msgTest;
    }

    /**
     * Override any default variable settings here.
     * @param none
     * @return void
     */
    public void setParms() {
        queueName = MQe.Admin_Reply_Queue_Name;
    }

    /**
     * Wait a while for the response message.
     * @param  msgTest A filter for the reply message to wait for.
     * @return MQeAdminMsg object
     * @exception java.lang.Exception
     */
    public MQeAdminMsg waitForReply(MQeFields msgTest) throws Exception {
        MQeAdminMsg respMsg = null;

        System.out.println("..Wait for a response message");
        respMsg = (MQeAdminMsg) myQM.waitForMessage(qMgrName, queueName, msgTest, null, 0, waitFor);
        return respMsg;
    }
}
