package examples.application;


// Version mqe_java/source/examples/application/Example1.java, MQeExamples, la200, la200-L030324.1 1.8
/* -----------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/* -----------------------------------------------------------------------------*/
import com.ibm.mqe.*;


/**
 *
 * <p>Extends ExampleBase, Application example base.
 *
 * <p>Simple put message / get message example.
 *
 * <p>Example showing how to:
 * <pre>
 *  . start a queue manager (Example1QM)
 *  . put a message to its systems default queue
 *  . get that message.
 * </pre>
 * <p>The example relies on the queue containing no messages at the time
 *  when the example is run.
 *
 *
 **/

public class Example1 extends ExampleBase {
    public static short[] version = { 2, 0, 0, 10 }; 

    /**
     * Constructor that uses the default queue manager.
     * @exception java.lang.Exception
     */
    public Example1() throws Exception {
        super();
    }

    /**
     * Constructor that uses the queue manager passed in on the command line.
     * @param queueManagerName java.lang.String
     * @exception java.lang.Exception
     */
    public Example1(String queueManagerName) throws Exception {
        super(queueManagerName);
    }

    /**
     * <p>Constructor that starts a queue manager with paramters
     * from an ini file. This queue manager is then used as the
     * access point for interacting with the same or different
     * queue managers.
     * @param qMgrName java.lang.String, queue manager name.
     *        The name of the queue manager to interact with.
     *        The queue manager can be a local or a remote queue
     *        manager.
     * @param localQMIniFile java.lang.String, ini file which
     *        contains startup parameters for the local queue
     *        manager.
     * @exception java.lang.Exception
     */
    public Example1(String qMgrName, String localQMgrIniFile) throws Exception {
        super(qMgrName, localQMgrIniFile);
    }

    /**
     * All work is performed in this method.
     */
    public void doIt() throws Exception {
        try {

            /*
             * create a msg with some data
             */
            System.out.println("..Create a message and add data:" + msgData);
            MQeMsgObject msgObj1 = new MQeMsgObject();

            msgObj1.putAscii(msgField, msgData);

            /*
             * Put msg to queue
             */
            System.out.println("..Put the message to QM/queue: " + qMgrName + "/" + queueName);
            myQM.putMessage(qMgrName, queueName, msgObj1, null, 0);

            /*
             * Retrieve the first available message on the queue (and only msg!)
             */
            System.out.println("..Get a message from QM/queue: " + qMgrName + "/" + queueName);
            MQeMsgObject msgObj2 = myQM.getMessage(qMgrName, queueName, null, null, 0);

            System.out.println("..Message retrieved contains data " + msgObj2.getAscii(msgField));

            /*
             * Check if it contains the expected data
             */
            if (msgObj2.getAscii(msgField).equals(msgData))
                System.out.println(example + " Finished");
            else
                System.out.println(example + " Failed: message data does not match");
        } catch (Exception e) {
            e.printStackTrace();
            System.out.println(example + " Failed! " + e);
            throw e;
        } finally {

            /*
             * Clean up
             */
            close();
        }
    }

    /**
     * <p>Starts the application.
     * @param param1 Queue Manager Name to interact with.
     * If queue manager name matches the local QM name then
     * all interactions are local otherwise the local QM acts
     * as a stub QM sending all messages to a remote QM.
     * @param param2 Local queue manager startup parameters ini file.
     * @return void
     * @exception java.lang.Exception
     */
    public static void main(String args[]) throws Exception {
        short rc = 0;

        try {
            if (args.length == 0)
                new Example1().doIt();
            else if (args.length == 1)
                new Example1(args[0]).doIt();
            else
                new Example1(args[0], args[1]).doIt();
        } catch (Exception ex) {
            System.out.println("Example failed: " + ex);
            ex.printStackTrace();
            rc = 99;
        }
        System.exit(rc);
    }

    /**
     * Over-ride default parameter settings.
     */
    public void setParms() {
        example = "Example1";
        msgData = example + ":Humpty dumpty sat on a wall ...";
    }
}
