package examples.application;


// Version mqe_java/source/examples/application/Example3.java, MQeExamples, la200, la200-L030324.1 1.9
/* -----------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/* -----------------------------------------------------------------------------*/

import com.ibm.mqe.*;


/*
 * <p>Extends ExampleBase, Application example base.
 *
 * <p>Message listener example.
 *
 * <p>Example showing how to:
 * <pre>
 *  . start a queue manager
 *  . add a message listener for any message
 *  . add a message listener for a specific message
 *  . put 2 messages to its systems default queue
 *  . display any message arrived events that occur
 *  . remove the message listener
 *  . put another message (no event generated)
 *  . browse the queue to locate any remaining messages
 *  . remove any remaining messages.
 * </pre>
 *
 *
 */
public class Example3 extends ExampleBase implements MQeMessageListenerInterface {
    public static short[] version = { 2, 0, 0, 10 }; 
    String msgData1 = example + ": Little Bo Peep";
    String msgData2 = example + ": has lost her sheep";
    String msgData3 = example + ": and dosen't know where to find them";
    String id1 = "1";
    String id2 = "2";
    String id3 = "3";

    /**
     * Constructor that uses the default queue manager.
     * @exception java.lang.Exception
     */
    public Example3() throws Exception {
        super();
    }

    /**
     * Constructor that uses the queue manager passed in on the command line.
     * @param queueManagerName java.lang.String
     * @exception java.lang.Exception
     */
    public Example3(String queueManagerName) throws Exception {
        super(queueManagerName);
    }

    /**
     * Constructor that starts a queue manager with paramters
     * from an ini file. This queue manager is then used as the
     * access point for interacting with the same or different
     * queue managers.
     * @param qMgrName java.lang.String, queue manager name.
     *        The name of the queue manager to interact with.
     *        The queue manager can be a local or a remote queue
     *        manager.
     * @param localQMgrIniFile java.lang.String, ini file which
     *        contains startup parameters for the local queue
     *        manager.
     * @exception java.lang.Exception
     */
    public Example3(String qMgrName, String localQMgrIniFile) throws Exception {
        super(qMgrName, localQMgrIniFile);
    }

    /**
     * All work is performed in this method.
     * @return void
     * @exception java.lang.Exception
     */
    public void doIt() throws Exception {
        try {

            /*
             * Can only listener to local queues. Ensure we don't attempt
             * to listen on a remote queue manager
             */
            if (!qMgrName.equals(localQMgrName))
                throw new Exception("listeners on remote queue managers are not supported");

            /*
             * Add a message listener for any messages
             */
            System.out.println("..Add a listener for any new msgs");
            myQM.addMessageListener(this, queueName, (MQeFields) null);

            /*
             * Add a message listener to listen for message 2
             */
            System.out.println("..Add a listener for when msg 2 arrives");
            MQeFields match1 = new MQeFields();

            match1.putArrayOfByte(MQe.Msg_MsgID, asciiToByte(id2));
            myQM.addMessageListener(this, queueName, match1);

            System.out.println("..You should see 3 message arrived events");

            /*
             * Create a msg with some data and well known identifier
             */
            System.out.println("..Create a message with id: " + id1 + " and data:" + msgData1);
            MQeMsgObject msgObj1 = new MQeMsgObject();

            msgObj1.putAscii(msgField, msgData1);
            msgObj1.putArrayOfByte(MQe.Msg_MsgID, asciiToByte(id1));

            /*
             * Put the msg to a queue
             */
            System.out.println("..Put the message to QM/queue: " + qMgrName + "/" + queueName);
            myQM.putMessage(qMgrName, queueName, msgObj1, null, 0);

            /*
             * Create a msg with some data and well known identifier
             */
            System.out.println("..Create a message with id: " + id2 + " and data:" + msgData2);
            MQeMsgObject msgObj2 = new MQeMsgObject();

            msgObj2.putAscii(msgField, msgData2);
            msgObj2.putArrayOfByte(MQe.Msg_MsgID, asciiToByte(id2));

            /*
             * Put the msg to a queue
             */
            System.out.println("..Put the message to QM/queue: " + qMgrName + "/" + queueName);
            myQM.putMessage(qMgrName, queueName, msgObj2, null, 0);

            /*
             * finish listening for new messages
             */
            System.out.println("..Finish listening (no more events should be seen)");
            myQM.removeMessageListener(this, queueName, match1);
            myQM.removeMessageListener(this, queueName, null);

            /*
             * Create a msg with some data and well known identifier
             */
            System.out.println("..Create a message with id: " + id3 + " and data:" + msgData3);
            MQeMsgObject msgObj3 = new MQeMsgObject();

            msgObj3.putAscii(msgField, msgData3);
            msgObj3.putArrayOfByte(MQe.Msg_MsgID, asciiToByte(id3));

            /*
             * Put the msg to a queue
             */
            System.out.println("..Put the message to QM/queue: " + qMgrName + "/" + queueName);
            myQM.putMessage(qMgrName, queueName, msgObj3, null, 0);

            /*
             * Tidy up by removing any remaining messages
             */
            emptyQueue();

            System.out.println(example + " Finished");
        } catch (Exception e) {
            e.printStackTrace();
            System.out.println(example + " Failed!");
            throw e;
        } finally {

            /*
             * Clean up
             */
            close();
        }
    }

    /**
     * Starts the application.
     * @param param1  Queue Manager Name to interact with.
     *                      If queue manager name matches the local QM name then
     *                      all interactions are local otherwise the local QM acts
     *                      as a stub QM sending all messages to a remote QM.
     * @param param2 Local queue manager startup parameters ini file.
     * @return void
     * @exception java.lang.Exception
     */
    public static void main(String args[]) throws Exception {
        short rc = 0;

        try {
            if (args.length == 0)
                new Example3().doIt();
            else if (args.length == 1)
                new Example3(args[0]).doIt();
            else
                new Example3(args[0], args[1]).doIt();
        } catch (Exception ex) {
            System.out.println("Example failed: " + ex);
            ex.printStackTrace();
            rc = 99;
        }
        System.exit(rc);
    }

    /**
     * This method is called when a message arrives on a queue.
     * @param e com.ibm.mqe.MQeMessageEvent
     * @return void
     * @exception java.lang.Exception The exception description.
     */
    public void messageArrived(MQeMessageEvent e) throws Exception {
        String qName = e.getQueueName();

        /*
         * is this the queue we are interested in?
         */
        if (!qName.equals(queueName)) {
            System.out.println("..Expecting event from queue    " + queueName);
            System.out.println("..but received event from queue " + qName);
        }

        /*
         * The event contains a copy of the message, show the msg id.
         */
        MQeFields attribs = e.getMsgFields();
        byte[] msgID = attribs.getArrayOfByte(MQe.Msg_MsgID);

        System.out.println("==A message arrived on Queue " + queueName +
            " with ID = " + new String(msgID));
    }

    /**
     * Over-ride default parameter settings.
     */
    public void setParms() {
        example = "Example3";
    }
}
