package examples.application;


// Version mqe_java/source/examples/application/ExampleBase.java, MQeExamples, la200, la200-L030324.1 1.10
/* -----------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/* -----------------------------------------------------------------------------*/

import com.ibm.mqe.*;
import java.io.*;
import examples.queuemanager.*;


/***
 * <p>Extends MQe, MQe base class.
 *
 * <p>To provide the base class/object for example applications.
 *
 * <p>Provides a set variables which are initialised with defaults values.
 * The setParms method allows the values to be over-ridden.
 * The accessLocalQMgr method starts the local queue manager.  If the
 * queue manager does not exist, a default queue manager is created and
 * started. The meat of the example is placed in the doIt method.
 *
 * <p>The examples can run against queues on the local queue manager by
 * using the default constructor or can run against a remote queue
 * manager by using the constructor which takes a string parameter. To
 * run against a remote queue manager, a remote queue manager defintion
 * must be created on the local queue manager.
 *
 **/
abstract public class ExampleBase extends MQe {
    public static short[] version = { 2, 0, 0, 10 }; 
    protected String localQMgrName;           // Read from startup ini file
    protected String startupIni = "." + File.separator + "ExamplesMQeClient.ini";

    protected MQeQueueManager  myQM = null;

    protected MQeClient client = null;
    protected String qMgrName = null;
    protected String example = "Example";
    protected String queueName = "SYSTEM.DEFAULT.LOCAL.QUEUE";
    protected String msgField = "MsgData";
    protected String msgData = "some data";

    /**
     * Constructor that uses the default queue manager.
     * @exception java.lang.Exception
     */
    public ExampleBase() throws Exception {
        setParms();
        System.out.println(example + " Started");

        accessLocalQMgr();

        qMgrName = localQMgrName;
    }

    /**
     * Constructor that runs the example against a remote queue manager.
     * The queue manager can also be the local queue manager.
     * @param queueManagerName java.lang.String, remote queue manager name.
     * @exception java.lang.Exception
     */
    public ExampleBase(String queueManagerName) throws Exception {
        setParms();
        System.out.println(example + " Started");

        accessLocalQMgr();

        qMgrName = queueManagerName;
    }

    /**
     * Constructor that starts a queue manager with paramters
     * from an ini file. This queue manager is then used as the
     * access point for interacting with the same or different
     * queue managers.
     * @param remoteQMgrName java.lang.String , queue manager name
     *        The name of the queue manager to interact with.
     *        The queue manager can be either a local or a remote
     *        queue manager.
     * @param localQMgrIniFile java.lang.String, ini file which
     *        contains startup parameters for the local queue
     *        manager.
     * @exception java.lang.Exception
     */
    public ExampleBase(String remoteQMgrName, String localQMgrIniFile) throws Exception {
        // Set the name of of the ini file if is not null or empty
        // otherwise use the default.
        if (localQMgrIniFile != null &&
            localQMgrIniFile.length() != 0)
            startupIni = localQMgrIniFile;

        // Set any additional parms.
        setParms();
        System.out.println(example + " Started");

        // Start the local queue manager
        accessLocalQMgr();

        // Set the name of the queue manager to interact with.
        if (remoteQMgrName != null &&
            remoteQMgrName.length() != 0)
            qMgrName = remoteQMgrName;
        else
            qMgrName = localQMgrName;
    }

    /**
     * Start the local queue manager.
     * @param none
     * @return void
     * @exception java.lang.Exception
     */
    public void accessLocalQMgr() throws Exception {
        System.out.println("..Start a queue manager using ini file: " + startupIni);
        try {
            client = new examples.queuemanager.MQeClient(startupIni);
            myQM = client.queueManager;

            localQMgrName = myQM.getName();

            System.out.println("..Started queue manager: " + localQMgrName);
        } catch (Exception ex) {
            System.out.println("..Start of queue manager failed: " + ex);
            throw ex;
        }

    }

    /***
     * Closes the client.
     * @param none
     * @return void
     * @exception java.lang.Exception
     */
    public void close() throws Exception {
        client.close();                       /* Close the client                 */
    }

    /**
     * All work is performed in this method.
     */
    abstract public void doIt() throws Exception;

    /**
     * Remove any message from the queue used by the example.
     * @param none
     * @return void
     * @exception java.lang.Exception
     */
    public void emptyQueue() throws Exception {

        /*
         * Tidy up by removing the 2 remaining messages
         */
        System.out.println("..Tidy up: removing any remaining messages");

        /*
         * Browse all available messages on the queue
         */
        MQeEnumeration msgs = myQM.browseMessages(qMgrName, queueName, null, null, false);

        while (msgs.hasMoreElements()) {

            /*
             * Messages may been processed by another threadbetween the
             * browse and the delete.
             */
            try {

                /* Next message */
                MQeMsgObject msgObj = (MQeMsgObject) msgs.nextElement();

                /* Get its unique identifier */
                MQeFields match = msgObj.getMsgUIDFields();

                /*
                 * Delete the message. This may fail if the message has been processed by
                 * another thread between the browse and the delete.
                 */

                myQM.deleteMessage(qMgrName, queueName, match);
                System.out.println("..Delete message with data " + msgObj.getAscii(msgField));
            } catch (Exception e) {}
        }
    }

    /**
     * Override any default variable settings here
     */
    abstract public void setParms();
}
