package examples.attributes;


// Version mqe_java/source/examples/attributes/LogonAuthenticator.java, MQeExamples, la200, la200-L030324.1 1.13
/* -----------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/* -----------------------------------------------------------------------------*/

import com.ibm.mqe.MQe;
import com.ibm.mqe.MQeAuthenticator;
import com.ibm.mqe.MQeException;
import com.ibm.mqe.MQeFields;
import com.ibm.mqe.MQeTrace;


/**
 *  Provides base logon Authentication support.
 */
public class LogonAuthenticator extends MQeAuthenticator {

    public static short version[] = { 2, 0, 0, 10 }; 

    protected final static String Authentic_ID = "AID";
    private String authID = null;

    /**
     * Default Constructor.
     */
    public LogonAuthenticator() {}

    /**
     * Activate Master.
     * 
     * @param local boolean value
     * @return byte[] of MQeFields
     * @exception java.lang.Exception
     */
    public byte[] activateMaster(boolean local) throws Exception {
        MQeFields fields = new MQeFields();

        // Put up the dialog prompt
        this.prompt(fields);

        // Return ID
        return fields.dump();
    }

    /**
     * Activate Slave.
     * 
     * @param local boolean value
     * @param data[] The data to be worked on
     * @return Worked on data
     * @exception java.lang.Exception
     */
    public byte[] activateSlave(boolean local, byte data[]) throws Exception {
        MQeFields fields = new MQeFields(data);

        try {
            // get the auth ID value
            authID = this.validate(fields);
            setAuthenticatedID(authID);
            super.activateSlave(local, data);
            
            MQeTrace.trace(this, (short) 0, MQeTrace.GROUP_INFO, authID);
            MQeFields result = new MQeFields();

            result.putAscii(Authentic_ID, authID);
            return result.dump();
        } catch (Exception e) {
            authID = null;
            setAuthenticatedID(null);
            throw e;
        }
    }

    /**
     * Sets the Authenticated ID.
     * 
     * @param local boolean value
     * @param data[] The data to be worked on
     * @return void
     * @exception java.lang.Exception
     */
    public void slaveResponse(boolean local, byte data[]) throws Exception {
        super.slaveResponse(local, data);
        MQeFields fields = new MQeFields(data);

        setAuthenticatedID(fields.getAscii(Authentic_ID));
    }

    /**
     * closes the authenticator.
     * 
     * @param none
     * @return void
     */
    public void close() {
        if (authID != null) {
          
            MQeTrace.trace(this, (short) 0, MQeTrace.GROUP_INFO, authID);
            authID = null;
        }
        super.close();
    }

    /**
     * Prompt to enter data.
     * 
     * @param fields MQeFields object
     * @return void
     * @exception java.lang.Exception
     */
    protected void prompt(MQeFields fields) throws Exception {
        throw new MQeException(MQe.Except_NotSupported, "Not supported");
    }

    /**
     * Validate the data.
     * 
     * @param fields MQeFields object
     * @return String containing the validated data
     * @exception java.lang.Exception
     */
    protected String validate(MQeFields fields) throws Exception {
        throw new MQeException(MQe.Except_Authenticate, "Authenticate failed");
    }
}
