package examples.attributes;


// Version mqe_java/source/examples/attributes/UnixAuthenticator.java, MQeExamples, la200, la200-L030324.1 1.7
/* -----------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* AIX: 5765-E63, Solaris: 5639-M17                                             */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/* -----------------------------------------------------------------------------*/

import com.ibm.mqe.MQe;
import com.ibm.mqe.MQeException;
import com.ibm.mqe.MQeFields;
import examples.awt.AwtDialog;
import examples.nativecode.JavaUnix;


/**
 *  Provides Unix Authentication support.
 */
public class UnixAuthenticator extends LogonAuthenticator {
    public static short version[] = { 2, 0, 0, 10 }; 

    protected final static String UXU_Domain = "D";
    protected final static String UXU_UserId = "U";
    protected final static String UXU_Password = "P";

    protected static examples.nativecode.JavaUnix UnixLib = null;

    /**
     * Closes the authenticator.
     * 
     * @param none
     * @return void
     */
    public void close() {
        if (UnixLib != null) {
            UnixLib.logoffUser();
        }
        super.close();
    }

    /**
     * (Master) prompt to enter userid an password data.
     * 
     * @param fields MQeFields object
     * @return void
     * @exception java.lang.Exception
     */
    protected void prompt(MQeFields fields) throws Exception {
        String userid = "";
        String password = null;

        // display a Dialog - prompting for Userid and Password
        while (userid.equals("")) {

            // Dialog with implicit "OK" and "Cancel" buttons in South panel
            AwtDialog unixd =
                new AwtDialog(
                    "Unix Authenticate",
                    AwtDialog.Show_OK_Cancel,
                    new String[][][] { { { "L", "Userid" }, {
                                "T", userid }
                        }, {
                            {
                                "L", "Password" }, {
                                "T*", "" }
                        }
                    }
                );

            if (unixd.getActionIndex(unixd.South) != unixd.Button_OK) {
                throw new MQeException(Except_Stopped, "Canceled");
            }
            userid = mask(unixd.getText(AwtDialog.Center, 1));
            password = mask(unixd.getText(AwtDialog.Center, 3));
            unixd.dispose();
        }

        // add the Userid and Password data to the fields to be transmitted
        fields.putAscii(UXU_UserId, userid);
        fields.putAscii(UXU_Password, password);
    }

    /**
     * (Slave) Validate the userid and password.
     * 
     * @param fields MQeFields object
     * @return void
     * @exception java.lang.Exception
     */
    protected String validate(MQeFields fields) throws Exception {

        // extract the Userid and Password data from the received fields
        String userid = fields.getAscii(UXU_UserId);
        String password = fields.getAscii(UXU_Password);

        // make sure that the Unix interface library is loaded
        if (UnixLib == null) {
            UnixLib = new examples.nativecode.JavaUnix();
        }

        // try to logon using the recieved userid and password
        if (UnixLib.logonUser(mask(userid), mask(password))) {
            return mask(userid);
        }
        throw new MQeException(MQe.Except_Authenticate, "Authenticate failed");
    }

    /**
     * Mask a string.
     * 
     * @param data String to be masked
     * @return Masked string
     */
    public String mask(String data) {
        byte temp[] = MQe.asciiToByte(data);

        for (int i = temp.length - 1; i >= 0; i = i - 1) {
            temp[i] = (byte) (temp[i] ^ (i + 0x00A5));
        }
        return MQe.byteToAscii(temp);
    }
}
