// Version mqe_java/source/examples/awt/AwtFrame.java, MQeExamples, la200, la200-L030324.1 1.6

/* -----------------------------------------------------------------------------*/ 

/*                    WebSphere MQ Everyplace for Multiplatforms                */ 

/*                                                                              */ 

/* Licensed Materials - Property of IBM                                         */ 

/*                                                                              */ 

/* 5765-E63                                                                     */ 

/*                                                                              */ 

/* (C) Copyright IBM Corp. 1999                                                 */ 

/* -----------------------------------------------------------------------------*/ 
package examples.awt;


import  java.awt.*;
import  java.awt.event.*;


/*
 * <p>Display a Frame.                                                                       
 * <p>Notes:                                                                        
 *                                                                               
 *      Dependent on a subset of the function provided by the following          
 *      AWT components:                                                          
 *                                                                               
 *                BorderLayout                                                   
 *                Panel                                                          
 *                                                                                                                     
 *                                                                               
 **/ 
public class AwtFrame extends Frame implements AwtEvent {
    public static short      version[] = { 2, 0, 0, 10 }; 

    public final static char  Center = 'C';
    public final static char  East = 'E';
    public final static char  Menu = 'M';
    public final static char  North = 'N';
    public final static char  South = 'S';
    public final static char  West = 'W';

    protected BorderLayout    borderLayout1 = new BorderLayout();
    protected AwtFormat       format[] = new AwtFormat[6];
    protected Panel           panel[] = new Panel[5];

    protected static String   BorderWhere[] = { BorderLayout.CENTER,
            BorderLayout.NORTH,
            BorderLayout.SOUTH,
            BorderLayout.EAST,
            BorderLayout.WEST };

    /*
     * Constructor.                                                               
     *                                                                            
     * @param   Title The window title                                              
     **/
    public AwtFrame(String title) {                                           /*                              */
        super(title);                             /* not modal                    */
        enableEvents(AWTEvent.WINDOW_EVENT_MASK); /* get widow events             */
        this.setTitle(title);                     /* set window title             */
        this.setLayout(borderLayout1);            /* set layout                   */
        this.setBackground(Color.lightGray);      /* frame background colour      */
    }                                           /*                              */

    /*
     * <p>Called whenever an action occurs.                                           
     *                                                                            
     * <p>Override to provide "event handling".
     * @param e
     * @param where Integer indicating where
     * @param index Integer containing the  index value  
     * @param choice String containing the choice 
     * @param state  boolean  containing state  
     * @return void
     **/
    public void action(Object e, int where, int index, String choice, boolean state) {                                           /*                              */}                                           /*                              */

    /*
     * Handle a window event.
     * @return void                       
     */
    protected void closeFrame() {                                           /*                              */
        setVisible(false);                        /* hide the window              */
        dispose();                                 /* loose the window             */
        System.exit(0);                           /* kill                         */
    }                                           /*                              */

    /*
     * Format a menu or a panel.
     * @param where Integer indicating where
     * @param items The data for the components 
     * @return void
     */
    public void format(int where, String items[][][]) {                                           /*                              */
        if (items == null)                        /* any data ?                   */
            return;                                   /* ... no                       */
        format[index(where)] = new AwtFormat(this, where);      /* new element  */
        if (where == Menu)                        /* menu ?                       */
            this.setMenuBar(format[index(where)].menuBar(items));
        else                                        /* ... no                       */ {                                         /*                              */
            visible(where, true);                   /* make panel visible           */
            format[index(where)].panel(panel[index(where)], items);     /* panel*/
        }                                         /*                              */
        pack();                                    /* re-pack the window           */
    }                                           /*                              */

    /*
     * Find the index number for the requested panel.
     * @param where Integer indicating where
     * @return an index value.          
     **/
    protected static int index(int where) {                                           /*                              */
        int index = -1;                             /* no index set                 */

        switch (where)                            /* based on where               */ {                                         /*                              */
        case Center:
            index = 0;
            break;           /* place in Center panel        */

        case North:
            index = 1;
            break;           /* place in North  panel        */

        case South:
            index = 2;
            break;           /* place in South  panel        */

        case East:
            index = 3;
            break;           /* place in East   panel        */

        case West:
            index = 4;
            break;           /* place in West   panel        */

        case Menu:
            index = 5;
            break;           /* place in menu                */
        }                                         /*                              */
        return (index);                            /* return the index no.         */
    }                                           /*                              */

    /*
     * Get the Index number of the pressed button. 
     * @param where Integer indicating where
     * @return Index number of the selected button.                              
     **/
    public int getActionIndex(int where) {                                           /*                              */
        return (format[index(where)].getActionIndex()); /* find the index       */
    }                                           /*                              */

    /*
     * Get the String data from the pressed button a Index. 
     * @param where Integer indicating where
     * @return A String containing the selected action.                    
     **/
    public String getActionString(int where) {                                           /*                              */
        return (format[index(where)].getActionString());        /* get string   */
    }                                           /*                              */

    /*
     * Get the boolean state from the Checkbox at Index. 
     * @param where Integer indicating where
     * @param index Integer containing the  index value    
     * @return A boolean value to know whether the checkbox was checked or not.                         
     **/
    public boolean getCheckState(int where, int index) {                                           /*                              */
        return (format[index(where)].getCheckState(index));    /* get boolean  */
    }                                           /*                              */

    /*
     * Get the selected item from the Choice box at Index.
     * @param where Integer indicating where
     * @param index Integer containing the  index value    
     * @return A String containing the choice                       
     **/
    public String GetChoice(int Where, int Index) {                                           /*                              */
        return (format[index(Where)].getChoice(Index));        /* get string   */
    }                                           /*                              */

    /*
     * Get the object at the specified Index. 
     * @param where Integer indicating where
     * @param index Integer containing the  index value    
     * @return An object                                 
     **/
    public Object getObject(int where, int index) {                                           /*                              */
        return (format[index(where)].getObject(index));        /* get object   */
    }                                           /*                              */

    /*
     * Get the selected panel object. 
     * @param where Integer indicating where  
     * @return A Panel object                                        
     */
    public Panel getPanel(int where) {                                           /*                              */
        return (panel[index(where)]);            /* get panel object             */
    }                                           /*                              */

    /*
     * Get the String data from the TextField at Index.   
     * @param where Integer indicating where
     * @param index Integer containing the  index value    
     * @return A String containing the text.                  
     **/
    public String getText(int where, int index) {                                           /*                              */
        return (format[index(where)].getText(index));  /* get string           */
    }                                           /*                              */

    /*
     * Handle a window event.
     * @param e   WindowEvent
     * @return void                                                     
     **/
    protected void processWindowEvent(WindowEvent e) {                                           /*                              */
        if (e.getID() == WindowEvent.WINDOW_CLOSING)      /* loose window         */
            closeFrame();                            /* ... yes                      */
        else                                        /* ... no                       */
            super.processWindowEvent(e);            /* ancestor                     */
    }                                           /*                              */

    /*
     * set the selected panel object.
     * @param where Integer indicating where
     * @param thisPanel Panel to be set.
     * @return void
     **/
    public void setPanel(int where, Panel thisPanel) {                                           /*                              */
        panel[index(where)] = thisPanel;          /* set panel object             */
    }                                           /*                              */

    /*
     * Set text in to a Text area at the specified Index.
     * @param where Integer indicating where
     * @param index Integer containg the index value
     * @param text A String containg the text which should be set.
     * @return void                        
     **/
    public void setText(int Where, int Index, String Msg) {                                           /*                              */
        format[index(Where)].setText(Index, Msg);       /* change text          */
    }                                           /*                              */

    /*
     * Show or hide the frame. 
     * @param state boolean containing the state.
     * 
     * @return void                                                              
     **/
    public void visible(boolean state) {                                           /*                              */
        if (state)                                /* need to show it ?            */ {                                         /* ... yes                      */
            pack();                                   /* pack all controls            */
            Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
            Dimension frameSize = getSize();         /* set fame size                */

            setLocation((screenSize.width - frameSize.width) / 2,
                (screenSize.height - frameSize.height) / 2);
        }                                         /*                              */
        setVisible(state);                        /* make visible                 */
    }                                           /*                              */

    /*
     * add/remove a panel object.  
     * @param where An integer indicating where
     * @param state boolean  containing state                                              
     **/
    public void visible(int where, boolean state) {                                           /*                              */

        /* Note: 'M' - Index = 5, not supported                                     */
        int i = index(where);                     /* convert to index             */

        if ((i < 0) || (i >= panel.length))       /* allowed ?                    */
            return;                                   /* ... no                       */
        if (state)                                /* add or remove                */ {                                         /* ... add                      */
            if (panel[i] == null)                   /* panel exist ?                */
                panel[i] = new Panel();                /* ... no, new panel            */
            add(panel[i], BorderWhere[i]);          /* add to frame                 */
        }                                         /*                              */ else                                        /* remove                       */
            remove(panel[i]);                       /* remove the panel             */
        pack();                                     /* re-pack the window           */
    }                                           /*                              */

}

