// Version 1.20 mqe_java/source/examples/awt/AwtMQeServer.java, MQeExamples, la200, la200-L030408

/*------------------------------------------------------------------------------*
 *                    WebSphere MQ Everyplace for Multiplatforms                *
 *                                                                              *
 * Licensed Materials - Property of IBM                                         *
 *                                                                              *
 * 5765-E63                                                                     *
 *                                                                              *
 * (C) Copyright IBM Corp. 2002                                                 *
 *------------------------------------------------------------------------------*/
package examples.awt;


import  com.ibm.mqe.*;
import  examples.queuemanager.*;
import  examples.administration.console.*;
import  java.util.*;
import  java.io.*;
import java.awt.event.*;
import examples.mqbridge.administration.programming.*;
import java.awt.*;


/**
 * Provides a simple window interface to an MQe server.
 * 
 * <P>Syntax from the command line is: 
 * <P><TT>java examples.awt.AwtMQeServer &lt;iniFile&gt;</TT>
 * <p>The iniFile name is optional.
 */
public class AwtMQeServer extends java.awt.Frame 
    implements java.awt.event.ActionListener, java.awt.event.ItemListener {
    public static short[] version = { 2, 0, 0, 10 }; 
    protected final static String DEFAULT_INIFILE_NAME = "." 
        + File.separator 
        + "ExampleQM" 
        + File.separator 
        + "ExampleQM.ini";
  	
    protected String iniFile = DEFAULT_INIFILE_NAME;
    private static final String FRAME_TITLE = "Server: none";
  	
    private static final String MENU_LABEL_FILE = "File";
    private static final String MENU_ITEM_LABEL_NEW = "New...";
    private static final String MENU_ITEM_LABEL_OPEN = "Open...";
    private static final String MENU_ITEM_LABEL_CLOSE = "Close";
    private static final String MENU_ITEM_LABEL_QUIT = "Quit";
  	
    private static final String MENU_LABEL_VIEW = "View";
    private static final String MENU_ITEM_LABEL_ADMINISTRATION = "Administration";
    private static final String MENU_ITEM_LABEL_TRACE = "Trace";
    private static final String MENU_ITEM_LABEL_MONITOR_MEM_STDOUT = "Monitor resources to stdout";
    private static final int COMMAND_CODE_MONITOR_MEM_STDOUT = 1;
    private static final String MENU_ITEM_LABEL_MONITOR_MEM_SCREEN = "Monitor memory on screen";
    private static final int COMMAND_CODE_MONITOR_MEM_SCREEN = 2;
    private static final String MENU_ITEM_LABEL_MONITOR_THREADS_SCREEN = "Monitor threads on screen";
    private static final int COMMAND_CODE_MONITOR_THREADS_SCREEN = 3;
    private static final String MENU_ITEM_LABEL_MONITOR_MEM_TRACE = "Monitor resources to trace channel (user_1)";
    private static final int COMMAND_CODE_MONITOR_MEM_TRACE = 4;
    
    private static final String MENU_ITEM_LABEL_BRIDGE_WIZARD = "Connect local default MQ queue manager";
  	
    private static final String MENU_LABEL_HELP = "Help";
    private static final String MENU_ITEM_LABEL_ABOUT = "About...";	
 	
    // Resources which are used to construct the frame.
	
    private java.awt.MenuBar menuBar;
	
    private java.awt.Menu fileMenu;
    private java.awt.MenuItem newMenuItem;
    private java.awt.MenuItem openMenuItem;
    private java.awt.MenuItem closeMenuItem;
    private java.awt.MenuItem quitMenuItem;
	
    private java.awt.Menu viewMenu;
    private java.awt.MenuItem adminMenuItem;
    private java.awt.MenuItem traceMenuItem;
    private java.awt.CheckboxMenuItem monitorToStdoutMenuItem;
    private java.awt.CheckboxMenuItem monitorToScreenMenuItem;
    private java.awt.CheckboxMenuItem monitorThreadsToScreenMenuItem;    
    private java.awt.CheckboxMenuItem monitorToTraceMenuItem;
    private java.awt.MenuItem bridgeWizardMenuItem;

    private java.awt.Menu helpMenu;
    private java.awt.MenuItem aboutMenuItem;    
	
    private java.awt.TextArea panelContentTextArea;
    private AwtOutputStream panelContentStream;

    /**
     * Simple constructor.
     * @exception java.lang.Exception
     */
    public AwtMQeServer() throws Exception {
	                                  
        super(FRAME_TITLE);  
        
        // Put a text area in the middle of the panel.
        panelContentTextArea = new java.awt.TextArea(ROWS, COLUMNS);
        
        // Allow users to copy from the trace window into editors...etc
        panelContentTextArea.setEditable(true);
        
        panelContentStream = new AwtOutputStream(panelContentTextArea, 100, 5000);
        
        this.add(panelContentTextArea, java.awt.BorderLayout.CENTER);
        
        initialiseMonitors();
        
        // Create a menu bar.
        menuBar = new java.awt.MenuBar();
  		
        // Construct a File menu
        fileMenu = new java.awt.Menu(MENU_LABEL_FILE);
        newMenuItem = new java.awt.MenuItem(MENU_ITEM_LABEL_NEW);
        newMenuItem.addActionListener(this);
        openMenuItem = new java.awt.MenuItem(MENU_ITEM_LABEL_OPEN);
        openMenuItem.addActionListener(this);
        closeMenuItem = new java.awt.MenuItem(MENU_ITEM_LABEL_CLOSE);
        closeMenuItem.addActionListener(this);
        closeMenuItem.setEnabled(false);
        quitMenuItem = new java.awt.MenuItem(MENU_ITEM_LABEL_QUIT);
        quitMenuItem.addActionListener(this);
        fileMenu.add(newMenuItem);
        fileMenu.add(openMenuItem);
        fileMenu.add(closeMenuItem);
        fileMenu.add(quitMenuItem);
  		
        // Construct the view menu
        viewMenu = new java.awt.Menu(MENU_LABEL_VIEW);
        adminMenuItem = new java.awt.MenuItem(MENU_ITEM_LABEL_ADMINISTRATION);
        adminMenuItem.addActionListener(this);
        adminMenuItem.setEnabled(false);
        viewMenu.add(adminMenuItem);
  		
        traceMenuItem = new java.awt.MenuItem(MENU_ITEM_LABEL_TRACE);
        traceMenuItem.addActionListener(this);
        viewMenu.add(traceMenuItem);

        monitorToStdoutMenuItem = createCheckboxMenuItem(viewMenu, MENU_ITEM_LABEL_MONITOR_MEM_STDOUT, false, COMMAND_CODE_MONITOR_MEM_STDOUT, this);
        monitorToScreenMenuItem = createCheckboxMenuItem(viewMenu, MENU_ITEM_LABEL_MONITOR_MEM_SCREEN, false, COMMAND_CODE_MONITOR_MEM_SCREEN, this);
        monitorThreadsToScreenMenuItem = createCheckboxMenuItem(viewMenu, MENU_ITEM_LABEL_MONITOR_THREADS_SCREEN, false, COMMAND_CODE_MONITOR_THREADS_SCREEN, this);
        monitorToTraceMenuItem = createCheckboxMenuItem(viewMenu, MENU_ITEM_LABEL_MONITOR_MEM_TRACE, false, COMMAND_CODE_MONITOR_MEM_TRACE, this);
  	
        bridgeWizardMenuItem = new java.awt.MenuItem(MENU_ITEM_LABEL_BRIDGE_WIZARD);
        bridgeWizardMenuItem.addActionListener(this);
        bridgeWizardMenuItem.setEnabled(false);
        viewMenu.add(bridgeWizardMenuItem);
  	
        // Construct a help menu
        helpMenu = new java.awt.Menu(MENU_LABEL_HELP);
        aboutMenuItem = new java.awt.MenuItem(MENU_ITEM_LABEL_ABOUT);
        aboutMenuItem.addActionListener(this);
        helpMenu.add(aboutMenuItem);
  		
        // Add the menu items into the menu bar.
        menuBar.add(fileMenu);
        menuBar.add(viewMenu);
        menuBar.add(helpMenu);
  		 
        this.setMenuBar(menuBar);  		                                                       
		
        // Pack the components into the frame.
        pack();         
        // Collect window events.
        enableEvents(java.awt.AWTEvent.WINDOW_EVENT_MASK);
    			    
        // Allow people to see the window.    			                                               
        setVisible(true); 	
    }   
    
    /**
     * Creates a check box menu item, and assigns it a handler for selection events.
     * 
     * <p>When the Awt event is detected for this menu item, the specified
     * command handler will be passed the specified commandCode.
     * 
     * @param label The text displayed by this menu item.
     * @param shortCut The part of the label which is a shortcut.
     * @param commandCode The command code value passed on the call-back to the 
     * command handler when the menu item is selected.
     * @param handler The object which will be called-back when the menu item is 
     * selected.
     * 
     * @return The constructed menu item object.
     */
    CheckboxMenuItem createCheckboxMenuItem(
        Menu owningMenu,
        String label,
        boolean initialState,
        int commandCode,
        AwtMQeServer handler) {

        /**
         * A local class class to serve as an action listener.
         * Converting an Awt event into a "command".
         */
        class CheckboxMenuItemListener implements java.awt.event.ItemListener {

            /**
             * A local reference to the command handler we are to send the command to.
             */
            AwtMQeServer myCommandHandler;

            /**
             * The value of the command to pass back to the command handler when the 
             * menu item is used.
             */
            int myCommandCode;

            /**
             * Constructs a menu item listener.
             * @parma commandHandler A reference to the object which will process the commands.
             */
            CheckboxMenuItemListener(AwtMQeServer commandHandler, int commandCode) {
                this.myCommandHandler = commandHandler;
                this.myCommandCode = commandCode;
            }

            /**
             * Called by Awt when the menu item is used.
             * Causes a call-back to the command handler. 
             */
            public void itemStateChanged(ItemEvent e) {
                this.myCommandHandler.doCommand(this.myCommandCode);
            }
        }

        // Create the menu item.
        CheckboxMenuItem item = new CheckboxMenuItem(label, initialState);

        ItemListener selectionEventHandler =
            (ItemListener) new CheckboxMenuItemListener(handler, commandCode);

        // Allow capture of selection events.			
        item.addItemListener(selectionEventHandler);

        // Add the menu item to the owning menu.
        owningMenu.add(item);

        return item;
    }
        
    /**
     * Process events which cause check box menu items to change.
     */        
    void doCommand(int command) {
        switch (command) {
									
        case COMMAND_CODE_MONITOR_MEM_STDOUT:
            if (monitorToStdoutMenuItem.getState()) {
                monitorToStdout.start();
            } else {
                monitorToStdout.stop();
            }
            break;
        
        case COMMAND_CODE_MONITOR_MEM_SCREEN:
            if (monitorToScreenMenuItem.getState()) {
                monitorToScreen.setFormatReadableMemoryData(true);
                if (!monitorToScreen.isRunning()) {
                    monitorToScreen.start();
                }
            } else {
                monitorToScreen.setFormatReadableMemoryData(false);
                if (!monitorToScreen.isFormatReadableThreadData()) {
                    monitorToScreen.stop();
                }
            }
				
            break;
	        
        case COMMAND_CODE_MONITOR_THREADS_SCREEN:
            if (monitorThreadsToScreenMenuItem.getState()) {
                monitorToScreen.setFormatReadableThreadData(true);
                if (!monitorToScreen.isRunning()) {
                    monitorToScreen.start();
                }
            } else {
                monitorToScreen.setFormatReadableThreadData(false);

                if (!monitorToScreen.isFormatReadableMemoryData()) {
                    monitorToScreen.stop();
                }				
            }
            break;	        
	        
        case COMMAND_CODE_MONITOR_MEM_TRACE:
            if (monitorToTraceMenuItem.getState()) {
                monitorToTrace.start();	        
            } else {
                monitorToTrace.stop();
            }
            break;
	        
        }        	
    }
    
    private MQeResourceMonitor monitorToTrace;
    private MQeResourceMonitor monitorToScreen;
    private MQeResourceMonitor monitorToStdout;

    void initialiseMonitors() {
        monitorToStdout = new MQeResourceMonitor();
        monitorToStdout.setFormatCommaSeparatedFields(true);
        monitorToStdout.setFormatReadableMemoryData(true);
        monitorToStdout.setFormatReadableThreadData(true);
        monitorToStdout.setOutputStream(System.out);
        monitorToStdout.setMilliSecsBetweenReadings(500);// update every 1/2 sec
		
        monitorToScreen = new MQeResourceMonitor();
        monitorToScreen.setOutputStream(panelContentStream);
        monitorToScreen.setMilliSecsBetweenReadings(4000); // 4 seconds between updates.

        monitorToTrace = new MQeResourceMonitor();
        monitorToTrace.setOutputStream(null);
        monitorToTrace.setFormatToTrace(true);
        monitorToTrace.setMilliSecsBetweenReadings(500); // update every 1/2 sec
    }

    /**
     * Called when the user changes the state of a checkbox menu item.
     */
    public final void itemStateChanged(ItemEvent e) {
        System.out.println("item state change : " + e.toString());
        Object item = e.getItem();

        if (item instanceof java.lang.String) {
            String itemName = (String) item;
        }	
    }
  
    /**
     * Capture window events arriving at this frame.
     * 
     * <P>Process window closing events. Pass all others on to the super class.
     * @param e  WindowEvent
     * @return void
     */
    protected final void processWindowEvent(WindowEvent e) {
        int event = e.getID();

        switch (event) {
        case WindowEvent.WINDOW_CLOSING:
            // User has used the system menu events to close the window.
            this.setVisible(false);
            this.dispose();
            System.exit(0);
            break;

        default:	    		
            super.processWindowEvent(e);
            break;
        }
    }   
    
    /**
     * Invoked when an action is performed.
     * @param e  ActionEvent
     * @return void
     */
    public final void actionPerformed(ActionEvent e) {
    	
        // Find out which widget has the action to perform.
        String command = e.getActionCommand();
    	
        if (command.equals(MENU_ITEM_LABEL_QUIT)) {
            // User has used the "quit" menu to shut everything down.
            this.setVisible(false);
            this.dispose();
            System.exit(0);
        } else 
		
        if (command.equals(MENU_ITEM_LABEL_ABOUT)) {
            menuActionAbout();
        } else 
		
        if (command.equals(MENU_ITEM_LABEL_ADMINISTRATION)) {
            menuActionAdministration();
        } else 
		
        if (command.equals(MENU_ITEM_LABEL_CLOSE)) {
            menuActionClose();
        } else 
		
        if (command.equals(MENU_ITEM_LABEL_OPEN)) {
            menuActionOpen();
        } else 
		
        if (command.equals(MENU_ITEM_LABEL_TRACE)) {
            menuActionTrace();
        }
        
        if (command.equals(MENU_ITEM_LABEL_NEW)) {
            menuActionNew();
        }
        
        if (command.equals(MENU_ITEM_LABEL_BRIDGE_WIZARD)) {
            menuActionBridgeWizard();
        }

    }
	
    /**
     * The user has clicked the "new" menu item.
     */
    private final void menuActionNew() {
        new examples.install.DefineQueueManager(null, false);
    }

    /**
     * User has selected the "About" menu action.
     * @return void
     */
    private final void menuActionAbout() {
        MQeTrace.trace(this, (short) 0, MQeTrace.GROUP_USER_DEFINED_1, "About called.");
    	
        AboutDialog dialog = new AboutDialog(this, this.server);

        dialog.setVisible(true);
    }
    
    private static final String DIALOG_BUTTON_LABEL_OK = "OK";
    private static final String ABOUT_WINDOW_TITLE = "About";
    private static final int ROWS = 8;
    private static final int COLUMNS = 60;
    
    /**
     * An "About" dialog.
     */
    class AboutDialog extends java.awt.Dialog 
        implements java.awt.event.ActionListener {

        /**
         * A reference to an encapsulated dialog object, populated with information about the 
         * underlying MQe system.
         */
        java.awt.Dialog dialog;
    	
        /**
         * Constructs an "about" dialog, ready for use.
         */
        AboutDialog(java.awt.Frame owningFrame, MQeServer server) {
            super(owningFrame, ABOUT_WINDOW_TITLE, DIALOG_MODALITY_MODAL);
    		
            String aboutText = getAboutText(server);
    		
            java.awt.Button okButton = new java.awt.Button(DIALOG_BUTTON_LABEL_OK); 	

            okButton.addActionListener(this);
            this.add(okButton, java.awt.BorderLayout.SOUTH);
    		
            java.awt.TextArea textArea = new java.awt.TextArea(aboutText, ROWS, COLUMNS);

            this.add(textArea, java.awt.BorderLayout.CENTER);
    		
            // Collect window events.
            enableEvents(java.awt.AWTEvent.WINDOW_EVENT_MASK);   
	    	
            pack();		
        }
    	
        /**
         * Finds all the information to return in the "About" dialog.
         * @param server MQeServer
         * @return Information from the "About" dialog.
         */
        private final String getAboutText(MQeServer server) {
            MQe myMQe = new MQe();
    		
            String versionString = "";

            for (int i = 0; i < myMQe.version.length; i += 1) {
                if (i > 0) {
                    versionString += ".";
                }
                versionString += Integer.toString((int) myMQe.version[i]);
            }
            String results = "";
    		
            results += MQe.copyright + "\n";
            results += "MQe.class is at version " + versionString + "\n";
            return results;
        }
    	
        /**
         * Invoked when an action is performed.
         * @param e  ActionEvent
         * @return void
         */
        public final void actionPerformed(ActionEvent e) {
    			
            // Find out which widget has the action to perform.
            String command = e.getActionCommand();
    	
            if (command.equals(DIALOG_BUTTON_LABEL_OK)) {
                this.setVisible(false);
                this.dispose();
            }
        }
    	
        /**
         * Capture window events arriving at this frame.
         * 
         * <P>Process window closing events. Pass all others on to the super class.
         * @param e  WindowEvent
         * @return void
         */
        protected final void processWindowEvent(WindowEvent e) {
            int event = e.getID();

            switch (event) {
            case WindowEvent.WINDOW_CLOSING:
                // User has used the system menu events to close the window.
                this.setVisible(false);
                this.dispose();
                break;
					
            default:	    		
                super.processWindowEvent(e);
                break;
            }
        }   
    }
    
    /**
     * Symbolic constant used to make code which sets modality of a window more readable.
     */
    private static final boolean DIALOG_MODALITY_MODAL = true;
    
    /**
     * User has selected the "Administration" menu action.
     * @return void
     */
    private final void menuActionAdministration() {
        try {
            if ((adminGUI == null) || (!adminGUI.active)) {
                adminGUI = (examples.administration.console.Admin) MQe.loadObject("examples.mqbridge.administration.console.AdminGateway");
                adminGUI.activate();
                adminGUI.disableStartStopQMButtons();
            }
        } catch (Exception e) {
            if (adminGUI != null) {
                adminGUI.dispose();
            }
            adminGUI = null;
        }
    }
	
    /**
     * A reference to the Administration GUI used by this program.
     * Held here so we can close the Administration windows when the server is closed.
     */
    private examples.administration.console.Admin adminGUI;
	
    /**
     * A reference to the server manipulated by this graphical application.
     */
    private MQeServer server;
	
    /**
     * User has selected the "Open" menu action.
     * @return void
     */
    private final void menuActionOpen() {
		
        // Create and use the "open" file dialog.
        java.awt.FileDialog openDialog = new java.awt.FileDialog(this, "Open .ini file", java.awt.FileDialog.LOAD 
            );
																
        // Indicate that this is a modal dialog box.																
        openDialog.setModal(DIALOG_MODALITY_MODAL);																
        // Cause the dialog to be actioned by the user.
        openDialog.setVisible(true);
		
        // Gather the name of the selected .ini file...
        String fileName = openDialog.getFile();
        String directory = openDialog.getDirectory();
		
        // Discard the dialog.
        openDialog.setVisible(false);
        openDialog.dispose();
		
        // Open the ini file if the user found one..
        if ((null != fileName)
            && (null != directory)
        ) {
		
            // Open the ini file.
            openServer(directory + fileName);
        }
    }
	
    /**
     * Open the MQe server beneath this GUI layer.
     * @return void
     */
    public final void openServer(String iniFileName) {
        try {
            if (iniFileName != null) {
                MQeTrace.trace(this, (short) 0, MQeTrace.GROUP_USER_DEFINED_1, "opening server now.");
                server = new MQeServer(iniFileName, true);
                server.activate(true);
                MQeTrace.trace(this, (short) 0, MQeTrace.GROUP_USER_DEFINED_1, "server opened ok.");
                openMenuItem.setEnabled(false);
                adminMenuItem.setEnabled(true);
                closeMenuItem.setEnabled(true);
                bridgeWizardMenuItem.setEnabled(true);
                setTitle("Server: " + server.queueManager.getName());	
            }
        } catch (Exception e) {
            System.err.println("Failed to start the server.");
            e.printStackTrace();
        }
    }
	
    /**
     * Close the MQe server beneath this GUI layer.
     * @return void
     */
    private final void closeServer() {
        try {
            // Close any admin GUI if there is one.
            if (adminGUI != null) {
                adminGUI.close();
            }
            adminGUI = null;
			
            // Shut down the server.
            server.activate(false);
            server.close();
            server = null;
            closeMenuItem.setEnabled(false);
            openMenuItem.setEnabled(true);
            setTitle(FRAME_TITLE);
            adminMenuItem.setEnabled(false);
            bridgeWizardMenuItem.setEnabled(false);
			
        } catch (Exception e) {
            System.err.println("Failed to close the server. " + e.toString());
            e.printStackTrace();
        }
    }
	
    /**
     * User has selected the "Close" menu action.
     * @return void
     */
    private final void menuActionClose() {
        closeServer();
    }
	
    /**
     * User has selected the "Trace to stdout" menu action.
     * @return void
     */
    private final void menuActionTrace() {
        AwtMQeTrace.open();
    }  	
    
    /**
     * User has asked for the bridge wizard.
     */
    private final void menuActionBridgeWizard() {
        AwtAdminHelperConnectToMQ.ConnectToMQ();	    											
    }

    /**
     * Entry point when the program is called from the command line.
     * 
     * <P>Syntax from the command line is:
     * <TT>java examples.awt.AwtMQeServer &lt;iniFileName&gt;</TT>
     */
    public static void main(String[] args) {                 
        try {    
            AwtMQeServer server = new AwtMQeServer();
						                                     
            if (args.length > 0) {
                server.openServer(args[0]);             
            }
			
        } catch (Exception e) {                                        
            e.printStackTrace();                     
        }                                         
    }       		                            
}
