// Version mqe_java/source/examples/eventlog/LogToDiskFile.java, MQeExamples, la200, la200-L030324.1 1.6

/* -----------------------------------------------------------------------------*/ 

/*                    WebSphere MQ Everyplace for Multiplatforms                */ 

/*                                                                              */ 

/* Licensed Materials - Property of IBM                                         */ 

/*                                                                              */ 

/* 5765-E63                                                                     */ 

/*                                                                              */ 

/* (C) Copyright IBM Corp. 1999                                                 */ 

/* -----------------------------------------------------------------------------*/ 
package examples.eventlog;


import  com.ibm.mqe.*;
import  java.awt.*;
import  java.awt.event.*;
import  java.text.*;
import  java.util.*;
import  java.io.*;


/*
 * 
 * <p>To provide the basic Logging to disk.                                    
 * Create a record either formatted or unformatted base on the filetype.    
 *                                                                               
 *                                                                               
 * <p>If the filetype is not ".txt" the following format is used:  
 * <pre>            
 *                                                                               
 *           llllttttttttttttttttTTnnnnnnnnddddddd......dddd                     
 *                                                                               
 *      where :                                                                  
 *              llll             = 2 byte total length (inclusive)               
 *              tttttttttttttttt = time stamp (long)                             
 *              TT               = Log record type                               
 *              nnnnnnnn         = Log record number                             
 *              ddd....ddd       = the record data bytes  
 * </pre>  
 * <p>This class extends MQeEventLogInterface, the base MQe log interface class.                                                       
 */ 
public class LogToDiskFile implements MQeEventLogInterface {                                             /*                              */
    public    static short  version[] = { 2, 0, 0, 10 }; 
    protected static String logName = null;
    protected static BufferedOutputStream logFile = null;

    /*
     * Default Constructor.
     * @exception java.lang.Exception                                                              
     **/
    public LogToDiskFile() throws Exception {                                           /*                              */}                                           /*                              */

    /*
     * Constructor.                                                              
     *                       
     * @param logName The { { drive } Path } file name    
     * @exception java.lang.Exception         
     **/
    public LogToDiskFile(String logName) throws Exception {                                           /*                              */
        activate(logName);                        /* activate                     */
    }                                           /*                              */

    /*
     * Activate.                                                       
     *                       
     * @param logName The { { drive } Path } file name   
     * @return void 
     * @exception java.lang.Exception  
     */       
    public void activate(String logName) throws Exception {                                           /*                              */
        this.logName = logName;                     /* save for later               */
        if (logName == null)                      /* is there a log name ?        */ {                                         /* ... no                       */
            FileDialog fd = new FileDialog(new Frame(),
                    "Log to Disk File",
                    FileDialog.SAVE);
            String timeStamp = new SimpleDateFormat("ddMMyyyy").format(new Date());

            fd.setFile("MQeLog" + timeStamp + ".txt");
            fd.show();                               /* show the dialog              */

            /* try to write the data to disk                                          */
            if ((fd.getDirectory() != null) && (fd.getFile() != null))
                this.logName = fd.getDirectory() + fd.getFile();
        }
        MQe.setEventLogHandler(this);             /* allow MQe to use it          */
    }                                           /*                              */

    /*
     * write a record to the log file.  
     * @param logType A byte to indicate the type of log.
     * @param logNumber An integer
     * @param logItem An Object 
     * @return void
     **/
    public synchronized void logOutput(byte logType, int logNumber, Object logItem) {                                           /*                              */
        try                                         /* incase of error              */ {                                         /*                              */

            /* ensure the log file exists                                             */
            if ((logFile == null) && (logName != null))     /* file exist ?         */ {                                       /* ... no                       */
                logFile = new BufferedOutputStream(new FileOutputStream(
                                new File(logName)));
            }                                       /*                              */

            /* formatted record or binary record                                      */
            if (logName.endsWith(".txt"))         /* formatted ?                  */ {                                       /* ... yes                      */
                StringBuffer record = new StringBuffer();

                record.append(new SimpleDateFormat("dd/MM/yyyy-HH:mm:ss.SSS").format(new Date()));
                record.append(" T=");
                record.append(logType);
                record.append(" N=");
                record.append(logNumber);
                record.append("\tD=");
                if (logItem instanceof String)
                    record.append((String) logItem);
                else
                if (logItem instanceof String[])
                    record.append(MQe.pattern("[0]=#0 [1]=#1 [2]=#3",
                            '#',
                            (String[]) logItem));
                else
                    record.append(logItem.toString());
                record.append("\r\n");
                logFile.write(MQe.asciiToByte(record.toString()));
            }                                       /*                              */ else                                      /* ... no, Binary               */ {                                       /*                              */
                byte data[];                            /* work variable                */

                /*                                                                      */
                if (logItem instanceof String)        /* string data ?                */
                    data = MQe.asciiToByte((String) logItem);   /* ... yes              */
                else                                    /* ... no                       */
                
                /*                                                                      */
                if (logItem instanceof byte[])        /* byte array ?                 */
                    data = (byte[]) logItem;              /* ... yes                      */
                else                                    /* ... no                       */
                
                /*                                                                      */
                if (logItem instanceof MQeFields)     /* Fields object ?              */
                    data = ((MQeFields) logItem).dump(); /* ... yes                      */
                else                                    /* ... no                       */
                    
                    /* don't know what to do - just get object ref                          */
                    data = MQe.asciiToByte(logItem.toString()); /* object reference     */

                /* write 2 byte total length length to disk                             */
                short totalLength = (short) (data.length + 2 + 8 + 1 + 4);

                logFile.write(MQe.shortToByte(totalLength));        /* save length  */
                logFile.write(MQe.longToByte(System.currentTimeMillis()));
                logFile.write(logType);               /* save log record type         */
                logFile.write(MQe.longToByte(logNumber));   /* Log number           */
                logFile.write(data);                  /* write the record data        */
            }                                       /*                              */
        }                                         /*                              */ catch (Exception e)                       /* error occured                */ {                                         /*                              */
            e.printStackTrace();                      /* show the error               */
        }                                         /*                              */
    }                                           /*                              */

    /* 
     * Closes the log file.
     * @return void
     */
    public void close() {                                           /*                              */
        logName = null;                             /* clear the logfile name       */
        if (logFile != null)                      /* using disk file ?            */
            try                                       /* incase of error              */ {                                       /*                              */
                logFile.close();                        /* close the file               */
            }                                       /*                              */ catch (Exception e) {}                 /*                              */
        if (MQe.getEventLogHandler() == this)     /* same object                  */
            MQe.setEventLogHandler(null);           /* stop MQe to using it         */
    }                                           /*                              */

    /*
     * Ensure closure of the log file.
     * @return void                                                        
     **/
    public void finalize() {                                           /*                              */
        close();                                   /* ensure it's closed           */
    }                                           /*                              */

}

