// Version mqe_java/source/examples/eventlog/LogToNTEventLog.java, MQeExamples, la200, la200-L030324.1 1.5

/* -----------------------------------------------------------------------------*/ 

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */ 

/* Licensed Materials - Property of IBM                                         */ 

/*                                                                              */ 

/* 5765-E63                                                                     */ 

/*                                                                              */ 

/* (C) Copyright IBM Corp. 1999                                                 */ 

/* -----------------------------------------------------------------------------*/ 
package examples.eventlog;


import  examples.nativecode.*;
import  java.util.*;
import  com.ibm.mqe.*;


/*
 * <p>To define the MQe log interface.                                        
 *                                                                               
 **/ 
public class LogToNTEventLog implements MQeEventLogInterface {   /* start class                                                            */
    public       static short version[] = { 2, 0, 0, 10 }; 

    protected static JavaNT ntInterface = null;

    /*
     * Default Constructor.
     * @exception java.lang.Exception                                                              
     **/
    public LogToNTEventLog() throws Exception {                                           /*                              */}                                           /*                              */

    /*
     * Constructor.                                                              
     *                       
     * @param logName The { { drive } Path } file name    
     * @exception java.lang.Exception         
     **/
    public LogToNTEventLog(String logName) throws Exception {                                           /*                              */
        activate(logName);                        /* activate                     */
    }                                           /*                              */

    /*
     * Activate.                                                       
     *                       
     * @param logName The { { drive } Path } file name   
     * @return void 
     * @exception java.lang.Exception  
     */       
    public void activate(String logName) throws Exception {                                           /*                              */
        if (logName == null)                      /* name specified ?             */
            logName = "MQeLog";                       /* ... no set default           */
        ntInterface = new JavaNT(logName);        /* create the object            */
        MQe.setEventLogHandler(this);             /* allow MQe to use it          */
    }                                           /*                              */

    /*
     * <p>Log an event record.  
     * @param logType A byte to indicate the type of log.
     * @param logNumber An integer
     * @param logMsg An Object 
     * @return void
     **/
    public void logOutput(byte logType, int logNumber, Object logMsg) {                                           /*                              */

        /* single string insert                                                     */
        if (logMsg instanceof String)             /* string type ?                */
            ntInterface.record(logType, logNumber, (String) logMsg, null);
        else                                        /* ... no                       */
        
        /* aray of strings                                                          */
        if (logMsg instanceof String[])           /* string type ?                */
            ntInterface.record(logType, logNumber, (String[]) logMsg, null);
        else                                        /* ... no                       */
        
        /* byte array                                                               */
        if (logMsg instanceof byte[])             /* byte array type              */
            ntInterface.record(logType, logNumber, null, (byte[]) logMsg);
        else                                        /* ... no                       */
        
        /* MQeFields object                                                         */
        if (logMsg instanceof MQeFields)          /* fields objectpe              */
            try                                       /* ... yes, in case of error    */ {                                       /*                              */
                ntInterface.record(logType,
                    logNumber,
                    null,
                    ((MQeFields) logMsg).dump());
            }                                       /*                              */ catch (Exception e)                     /* error occured                */ {                                       /*                              */
                ntInterface.record(logType,
                    logNumber,
                    "<<dump of MQeFields object failed: " + e,
                    null);
            }                                       /*                              */
        else                                        /* ... no                       */
            
            /*                                                                          */
            ntInterface.record(logType,
                logNumber,
                "<<Invalid type>> " + logMsg.toString(),
                null);
    }                                           /*                              */

    /* 
     * Closes the interface.
     * @return void
     */
    public void close() {                                           /*                              */
        if (ntInterface != null)                  /* initialised ?                */ {                                         /* ... yes                      */
            MQe.setEventLogHandler(null);           /* stop using it                */
            ntInterface.close();                     /* close it down                */
            ntInterface = null;                       /* lose the object              */
        }                                         /*                              */
    }                                           /*                              */

    /*
     * De-register an NT event source.
     * @return void  
     **/
    public void finalize() {                                           /*                              */
        close();                                   /* ensure it's closed           */
    }                                      

}   
