// Version mqe_java/source/examples/install/DefineQueueManager.java, MQeExamples, la200, la200-L030324.1 1.21

/* -----------------------------------------------------------------------------*
 *                    WebSphere MQ Everyplace for Multiplatforms                *
 *                                                                              *
 * Licensed Materials - Property of IBM                                         *
 *                                                                              *
 * 5765-E63                                                                     *
 *                                                                              *
 * (C) Copyright IBM Corp. 1999,2002                                            *
 * -----------------------------------------------------------------------------*/
package examples.install;


import com.ibm.mqe.*;
import com.ibm.mqe.registry.*;
import com.ibm.mqe.administration.*;

import examples.queuemanager.MQeQueueManagerUtils;
import examples.awt.*;

import java.awt.*;
import java.io.*;
import java.util.*;


/**                                                                  
 * Provides a simple window interface for defining and                   
 * creating a basic queue manager - illustrates use of the                 
 * MQeQueueManagerConfigure class.                                         
 *                                                                              
 * <p>This class uses a GUI to interact with the user. It uses the            
 * information provided by the user to create a configuration              
 * file, and then uses the methods in the base class to create             
 * a queue manager from it.                                                
 *                                                                              
 * <p>If a Private Registry is specified, the user is asked whether           
 * they want to obtain credentials for the registry now or leave           
 * it till later.                                                  .       
 *                                                                                                                      
 **/
public class DefineQueueManager extends SimpleCreateQM {
    public       static short version[] = { 2, 0, 0, 10 }; 
    // Default values
    public String defRegDir = "Registry";
    public String defRegSeparator = "+";
    public String defQMName = "ExampleQM";

    // Generated aliases
    String[] aliasMsgLog = { "MsgLog", "com.ibm.mqe.adapters.MQeDiskFieldsAdapter" };
    String[] aliasNTRas = { "NTRas", "com.ibm.mqe.adapters.MQeNTRasAdapter" };
    // String[] aliasEvent        = { "EventLog", "examples.log.LogToDiskFile" };
    String[] aliasFileReg = { "FileRegistry", "com.ibm.mqe.registry.MQeFileSession" };
    String[] aliasPrivReg = { "PrivateRegistry", "com.ibm.mqe.registry.MQePrivateSession" };
    String[] aliasRegAdapter = { "RegistryAdapter", "com.ibm.mqe.adapters.MQeDiskFieldsAdapter" };

    /*
     * GUI variables
     */

    defineNameFrame nameF = null;
    defineQMFrame QMD = null;
    String indent = "        ";

    // title for frames, etc
    String titleStr;

    // Queue manager Name
    String    qmNameLblStr;
    TextField qmNameTF;
    String    qmNameValue = "";

    // Base directory for .ini file
    String    baseDirLblStr;
    TextField baseDirTF;
    String    baseDirValue;

    // Directory for the queues
    String    queueDirLblStr;
    TextField queueDirTF;
    String    queueDirValue;

    // Directory for the registry
    String    regDirLblStr;
    TextField regDirTF;
    String    regDirValue;

    // Registry Separator character
    String    regSepLblStr;
    TextField regSepTF;
    String    regSepValue = defRegSeparator;

    // Client configuration choicebox
    String    clientLblStr;
    Checkbox  clientCB;
    boolean   clientValue = true;

    // Server configuration choicebox
    String    serverLblStr;
    Checkbox  serverCB;
    boolean   serverValue = false;

    // Channel Listener port number
    Label     listenPortLabel;
    String    listenPortLblStr;
    TextField listenPortTF;
    String    listenPortValue = "8082";

    // Private Registry option
    String    privRegLblStr;
    Checkbox  privRegCB;
    boolean   privRegValue = false;

    // Private Registry PIN
    Label     prPinLabel;
    String    prPinLblStr;
    TextField prPinTF;
    String    prPinValue = "";

    // Confirm Private Registry PIN
    Label     prVPinLabel;
    String    prVPinLblStr;
    TextField prVPinTF;
    String    prVPinValue = "";

    // Key Ring Password
    Label     prKrpLabel;
    String    prKrpLblStr;
    TextField prKrpTF;
    String    prKrpValue = "";

    // Confirm Key Ring Password
    Label     prVKrpLabel;
    String    prVKrpLblStr;
    TextField prVKrpTF;
    String    prVKrpValue = "";
  
    // Registry adapter name
    Label     regAdapterLabel;
    String    regAdapterStr = aliasRegAdapter[0];
    TextField regAdapterTF;
    String    regAdapterValue = aliasRegAdapter[1];

    // OK and Cancel buttons
    Button okB;
    String okLabelStr;
    Button cancelB;
    String cancelLabelStr;

    // Derived variables
    String configFileId = "";

    boolean adminQ = false;
    boolean adminReplyQ = false;
    boolean defaultSysQ = false;
    boolean deadLetterQ = false;

    // Configuration Parameters
    MQeFields configFields;
    MQeFields regFields;

    // Process stage flags (for undo processing)
    boolean baseDirCreated = false;
    boolean queueDirCreated = false;
    boolean regDirCreated = false;
    boolean configFileCreated = false;

    // Do we exit the application when we close()
    boolean exitFlag = true;

    // Other Strings, for NLS
    String badKRPconfirmStr;
    String badPINconfirmStr;
    String clientStr;
    String configFileStr;
    String configStr;
    String confirmKrpStr;
    String confirmPRPINStr;
    String confirmQMStr;
    String createdStr;
    String defineErrorStr;
    String enterForListPortStr;
    String enterQMdetStr;
    String errorStr;
    String existsStr;
    String getCredStr;
    String invQMNameStr;
    String listenPortStr;
    String noBaseDirStr;
    String noKrpStr;
    String noListPortStr;
    String noPRPinStr;
    String noQMNameStr;
    String noQueueDirStr;
    String noRegDirStr;
    String notRequiredStr;
    String nowLaterStr;
    String privRegStr;
    String privRegWarnStr;
    String qMgrNameStr;
    String qMgrStr;
    String queueDirStr;
    String regDirStr;
    String regSep1Str;
    String requiredStr;
    String serverStr;
    String registryAdapterStr;
    String noRegAdapterStr;

    /**
     * DefineQueueManager constructor.
     * Construct the frame to collect the user input, and show it.
     *
     * @param qmName  Name of the Queue Manager to be defined; can be null
     **/
    public DefineQueueManager(String qmName) {
        // base class constructor; this calls initStrings()
        this(qmName, true);

    }
  
    /**
     * Constructor which indicates whether the program should exit using 
     * System.exit() when the user closes the last window or not.
     * 
     * @param shutDownOnClose True if the program should terminate when the 
     * last window is closed. False if the program should stay alive.
     * True is used when the program is invoked from the command line, false
     * when another windowing program causes it to launch.
     * 
     * @param qmName The name of the queue manager to be defined. If null, then 
     * the information is gathered from the user anyway.
     */
    public DefineQueueManager(String qmName, boolean shutDownOnClose) {
        // was a Queue Manager name specified ?
        if (qmName != null && qmName.length() > 0) {
            qmNameValue = qmName.trim();

            // display the main Queue Manager Frame - this does all the work
            displayQMFrame();
        } else {
            // display a frame to get the Queue Manager Name, this in turn
            // will create and display the main Queue Manager Frame
            nameF = buildNameFrame();

            // display it and let the GUI do the rest
            nameF.show();
        }
		
        this.shutDownOnClose = shutDownOnClose;
    }
  
    /**
     * Indicates whether System.exit() should be called to quit the program when 
     * the last window is closed, or whether the windows should simply be deleted.
     * 
     * <p>Set to true when the class is instantiated as a result of a command-line action, 
     * false when another windowing program causes it to be launched.
     */
    private boolean shutDownOnClose = true;

    /**
     * Build and display the main Queue Manager frame.
     **/
    public void displayQMFrame() {
        // set default values
        String cd = System.getProperty("user.dir");

        if (!cd.endsWith(File.separator))
            cd = cd + File.separator;
        baseDirValue = cd + qmNameValue + File.separator;
        queueDirValue = baseDirValue + defQueueDir + File.separator;
        regDirValue = baseDirValue + defRegDir;

        // build the main frame
        QMD = buildQMFrame();

        // display it and let the GUI do the rest
        QMD.show();
    }

    /**
     * buildNameFrame - build the GUI Frame to get a Queue Manager
     * Name and populate it.
     * This uses a defineNameFrame, which is an AwtFrame extended
     * with an Action rotine. It is defined in an inner class.
     *
     * @return    The built frame.
     **/
    public defineNameFrame buildNameFrame() {
        // Create the frame
        nameF = new defineNameFrame(titleStr);

        // and populate it
        nameF.format(AwtFrame.Center, new String[][][]
            {
                { {"L", enterQMdetStr + ": "}, {"L", ""}
                },               /* Index  0,  1 */
                { {"L", ""}, {"L", ""}
                },                                 /* Index  2,  3 */
                { {"L", qmNameLblStr}, {"T", defQMName }
                },             /* Index  4,  5 */
                { {"L", ""}, {"L", ""}
                },                                 /* Index  6,  7 */
            }
        );

        // add the OK button
        nameF.format(AwtFrame.South, new String[][][]
            { { {"L", "            "},   /* Index  0 */
                    {"B", okLabelStr},      /* Index  1 */
                    {"L", "           "},   /* Index  2 */
                }
            }
        );

        // Use the index numbers to locate the GUI components we need
        qmNameTF = (TextField) nameF.getObject(AwtFrame.Center, 5);

        // The button is in the South Panel
        okB = (Button) nameF.getObject(AwtFrame.South, 1);

        return nameF;
    }

    /**
     * buildQMFrame - build the GUI Frame to get the Queue Manager
     * details and populate it.
     * This uses a defineQMFrame, which is an AwtFrame extended
     * with an Action routine. It is defined in an inner class.
     *
     * @return    The built frame.
     **/
    public defineQMFrame buildQMFrame() {
        // Create the frame
        defineQMFrame QMD = new defineQMFrame(titleStr);

        // and populate it
        QMD.format(AwtFrame.Center, new String[][][]
            {
                { {"L", enterQMdetStr + ": "}, {"L", ""}
                },               /* Index  0,  1 */
                { {"L", ""}, {"L", ""}
                },                                 /* Index  2,  3 */
                { {"L", qmNameLblStr}, {"T", qmNameValue }
                },           /* Index  4,  5 */
                { {"L", baseDirLblStr}, {"T", baseDirValue}
                },           /* Index  6,  7 */
                { {"L", queueDirLblStr}, {"T", queueDirValue }
                },         /* Index  8,  9 */
                { {"L", regDirLblStr}, {"T", regDirValue}
                },            /* Index 10, 11 */
                { {"L", regSepLblStr}, {"T", regSepValue}
                },            /* Index 12, 13 */
                { {"L", regAdapterStr}, {"T", regAdapterValue}
                },        /* Index 14, 15 */
                { {(clientValue ? "C!" : "C"), clientLblStr},
                    {"L", ""}
                },     /* Index 16, 17 */
                { {(serverValue ? "C!" : "C"), serverLblStr},
                    {"L", ""}
                },     /* Index 18, 19 */
                { {"L", indent + listenPortLblStr},
                    {"T", listenPortValue}
                },     /* Index 20, 21 */

                { {"L", ""}, {"L", ""}
                },                                 /* Index 22, 23 */

                { {"L", ""}, {"L", ""}
                },                                 /* Index 24, 25 */
                { {(privRegValue ? "C!" : "C"), privRegLblStr},
                    {"L", ""}
                },     /* Index 26, 27 */
                { {"L", indent + prPinLblStr}, {"T*", prPinValue}
                },     /* Index 28, 29 */
                { {"L", indent + prVPinLblStr}, {"T*", prVPinValue}
                },    /* Index 30, 31 */
                { {"L", indent + prKrpLblStr}, {"T*", prKrpValue}
                },     /* Index 32, 33 */
                { {"L", indent + prVKrpLblStr}, {"T*", prVKrpValue}
                },    /* Index 34, 35 */
                { {"L", ""}, {"L", ""}
                },                                 /* Index 36, 37 */
            }
        );

        // add the OK and Cancel buttons
        QMD.format(AwtFrame.South, new String[][][]
            { { {"L", "       "},        /* Index  0 */
                    {"B", okLabelStr},      /* Index  1 */
                    {"L", "      "},        /* Index  2 */
                    {"B", cancelLabelStr},  /* Index  3 */
                    {"L", "      "}         /* Index  4 */
                }
            }
        );

        // Use the index numbers to locate the GUI components we need
        qmNameTF = (TextField) QMD.getObject(AwtFrame.Center, 5);
        baseDirTF = (TextField) QMD.getObject(AwtFrame.Center, 7);
        queueDirTF = (TextField) QMD.getObject(AwtFrame.Center, 9);
        regDirTF = (TextField) QMD.getObject(AwtFrame.Center, 11);
        regSepTF = (TextField) QMD.getObject(AwtFrame.Center, 13);
        regAdapterTF = (TextField) QMD.getObject(AwtFrame.Center, 15);
        clientCB = (Checkbox) QMD.getObject(AwtFrame.Center, 16);
        serverCB = (Checkbox) QMD.getObject(AwtFrame.Center, 18);
        listenPortLabel = (Label) QMD.getObject(AwtFrame.Center, 20);
        listenPortTF = (TextField) QMD.getObject(AwtFrame.Center, 21);

        privRegCB = (Checkbox) QMD.getObject(AwtFrame.Center, 26);
        prPinLabel = (Label) QMD.getObject(AwtFrame.Center, 28);
        prPinTF = (TextField) QMD.getObject(AwtFrame.Center, 29);
        prVPinLabel = (Label) QMD.getObject(AwtFrame.Center, 30);
        prVPinTF = (TextField) QMD.getObject(AwtFrame.Center, 31);
        prKrpLabel = (Label) QMD.getObject(AwtFrame.Center, 32);
        prKrpTF = (TextField) QMD.getObject(AwtFrame.Center, 33);
        prVKrpLabel = (Label) QMD.getObject(AwtFrame.Center, 34);
        prVKrpTF = (TextField) QMD.getObject(AwtFrame.Center, 35);

        // The buttons are in the South Panel
        okB = (Button) QMD.getObject(AwtFrame.South, 1);
        cancelB = (Button) QMD.getObject(AwtFrame.South, 3);

        // set the GUI options to the correct state
        setGUIoptions();

        return QMD;
    }

    /**
     * Check that the details the user entered are complete and consistent
     * If this method returns true, all the values we need have been extracted
     * from the GUI
     *
     * @return   'true' if the details are correct, 'false' if there is an error.
     **/
    private boolean checkDetails() {
        String errorMsg = null;

        // check the base values
        qmNameValue = qmNameTF.getText().trim();
        baseDirValue = baseDirTF.getText().trim();
        queueDirValue = queueDirTF.getText().trim();
        regDirValue = regDirTF.getText().trim();
        regSepValue = regSepTF.getText().trim();
        regAdapterValue = regAdapterTF.getText().trim();

        if (qmNameValue.length() == 0)
            errorMsg = noQMNameStr;
        else if (!checkQmgrName(qmNameValue))
            errorMsg = invQMNameStr;
        else if (baseDirValue.equals(""))
            errorMsg = noBaseDirStr;
        else if (queueDirValue.equals(""))
            errorMsg = noQueueDirStr;
        else if (regDirValue.equals(""))
            errorMsg = noRegDirStr;
        else if (regSepValue.length() != 1)
            errorMsg = regSep1Str;
        else if (regAdapterValue.equals("")) 
            errorMsg = noRegAdapterStr;
      
        // check the values related to Server configurations
        serverValue = serverCB.getState();
        if (errorMsg == null && serverValue) {
            listenPortValue = listenPortTF.getText().trim();
            if (listenPortValue.equals(""))
                errorMsg = noListPortStr;
            else if ((errorMsg = utils.checkPortNumber(listenPortValue)) != null)
                errorMsg = errorMsg + enterForListPortStr;
        }

        // check the values related to a Private Registry
        privRegValue = privRegCB.getState();
        if (errorMsg == null && privRegValue) {
            prPinValue = prPinTF.getText().trim();
            prVPinValue = prVPinTF.getText().trim();
            prKrpValue = prKrpTF.getText().trim();
            prVKrpValue = prVKrpTF.getText().trim();
 
            // Private registry PIN and confirmed value
            if (prPinValue.equals(""))
                errorMsg = noPRPinStr;
            else if (prVPinValue.equals(""))
                errorMsg = confirmPRPINStr;
            else if (!prPinValue.equals(prVPinValue))
                errorMsg = badPINconfirmStr;

            // Key Ring Password and confirmed value
            else if (prKrpValue.equals(""))
                errorMsg = noKrpStr;
            else if (prVKrpValue.equals(""))
                errorMsg = confirmKrpStr;
            else if (!prKrpValue.equals(prVKrpValue))
                errorMsg = badKRPconfirmStr;
        }

        // Check that the configuration file does not already exist
        if (errorMsg == null) {
            if (!baseDirValue.endsWith(File.separator))
                baseDirValue = baseDirValue + File.separator;

            configFileId = baseDirValue + qmNameValue + ".ini";
            File filename = new File(configFileId);

            if (filename.exists())
                errorMsg = configFileStr + " '" + configFileId + "' " + existsStr;
        }

        if (errorMsg == null) {
            // no errors, so set up remaining values
            if (!queueDirValue.endsWith(File.separator))
                queueDirValue = queueDirValue + File.separator;
            if (!regDirValue.endsWith(File.separator))
                regDirValue = regDirValue + File.separator;

            clientValue = clientCB.getState();

            return true;     // Indicate details are acceptable
        } else {
            // throw up a dialog box with the error
            AwtConfigUtils.messageDialog(titleStr + " - " + errorStr, errorMsg);

            // indicate an error by returning false
            return false;
        }
    }

    /**
     * confirmDetails - display the details and seek confirmation.
     *
     * @return  'true' if the user confirms, 'false' otherwise
     **/
    public boolean confirmDetails() {

        // construct the details in a String Buffer
        StringBuffer qmDetails = new StringBuffer();
        String NL = System.getProperty("line.separator");
        String colon = ":  ";

        qmDetails.append(qMgrNameStr).append(colon).append(qmNameValue).append(NL);
        qmDetails.append(configFileStr).append(colon).append(configFileId).append(NL);
        qmDetails.append(queueDirStr).append(colon).append(queueDirValue).append(NL);
        qmDetails.append(regDirStr).append(colon).append(regDirValue).append(NL);
        qmDetails.append(regAdapterStr).append(colon).append(regAdapterValue).append(NL);
        qmDetails.append(configStr).append(colon).append((clientValue ? clientStr : serverStr)).append(NL);

        if (serverValue) {
            qmDetails.append(listenPortStr).append(colon).append(listenPortValue).append(NL);
        }

        if (privRegValue) {
            qmDetails.append(privRegStr).append(colon).append(requiredStr);
            qmDetails.append(privRegWarnStr);
        } else
            qmDetails.append(privRegStr).append(colon).append(notRequiredStr);

        // Display the details, and seek confirmation
        return AwtConfigUtils.confirmDialog(confirmQMStr, qmDetails.toString());
    }

    /**
     * createQMgr - create a Queue Manager definition and then
     * create the queue manager from it.
     *
     * @return    'true' if successful or user quits, 'false' to
     *             continue after error
     **/
    public boolean createQMgr() {
        try {
            // build the Queue Manager parameter MQeFields object
            buildParams();

            // create the necessary file directories
            baseDirCreated = utils.makeDirectory(baseDirValue);
            regDirCreated = utils.makeDirectory(regDirValue);
            queueDirCreated = utils.makeDirectory(queueDirValue);

            // Generate the .ini file
            MQeQueueManagerUtils.saveConfigFile(configFileId, configFields);
            configFileCreated = true;

            // save a copy of the registry parameters and
            // go ahead and create the Queue Manager
            MQeFields savedRegFields = new MQeFields();

            savedRegFields.copy(regFields, true);

            defQMRegistry(configFields,
                aliasMsgLog[0] + ":" + queueDirValue,
                adminQ, adminReplyQ, defaultSysQ, deadLetterQ);

            // If it's a private registry, offer the option to
            // configure it now or later
            if (privRegValue) {
                AwtDialog doneDialog =
                    new AwtDialog(titleStr,
                        AwtDialog.Show_OK_Cancel,
                        new String[][][]
                        { { {"L", " "}
                            },
                            { {"L", "  " + qMgrStr + "  '" + qmNameValue + "'  " + createdStr + "  "}
                            },
                            { {"L", " "}
                            },
                            { {"L", "  " + getCredStr + "  "}
                            },
                            { {"L", "  " + nowLaterStr + "  "}
                            },
                            { {"L", " "}
                            }
                        }
                    );

                if (doneDialog.getActionIndex(doneDialog.South) == doneDialog.Button_OK) {
                    // don't exit the application yet
                    exitFlag = false;

                    // restore registry parameters and get credentials for the Private Registry
                    regFields.copy(savedRegFields, true);
                    new GetCredentials(configFields);
                }
            } else {
                // It's not a private registry, so simply confirm
                // that the Queue Manager definition has been created
                AwtConfigUtils.messageDialog(titleStr, qMgrStr + "  '" + qmNameValue + "'  " + createdStr);
            }

            // success
            return true;

        } catch (Exception e) {
            // There's been an error. so clean up anything we've created so far
            cleanUp();

            // Display the error to the user
            AwtConfigUtils.messageDialog(titleStr + " - " + errorStr,
                defineErrorStr + ": " + e.getMessage());

            return false;
        }
    }

    /**
     * cleanUp - clean up a definition in the event of an error.
     **/
    public void cleanUp() {
        // If a configuration file has been created, delete it
        if (configFileCreated) {
            File filename = new File(configFileId);

            filename.delete();
            configFileCreated = false;
        }

        // If a queue directory has been created, delete it
        if (queueDirCreated) {
            File dirname = new File(queueDirValue);

            dirname.delete();
            queueDirCreated = false;
        }

        // If a registry directory has been created, delete it
        if (regDirCreated) {
            File dirname = new File(regDirValue);

            dirname.delete();
            regDirCreated = false;
        }

        // If a base directory has been created, delete it
        if (baseDirCreated) {
            File dirname = new File(baseDirValue);

            dirname.delete();
            baseDirCreated = false;
        }
    }

    /**
     * buildParams - build the parameters for the Queue Manager
     **/
    public void buildParams() throws Exception {
        // Initialise the various field sections
        configFields = new MQeFields();
        regFields = new MQeFields();

        MQeFields channelFields = new MQeFields();
        MQeFields listenFields = new MQeFields();
        MQeFields aliasFields = new MQeFields();
        MQeFields qmFields = new MQeFields();

        // Supply standard alias definitions
    
        if (!regAdapterValue.equals(aliasRegAdapter[1])) {    
            // A non-default registry adapter has been selected.
            // Over-ride the alias.
            aliasFields.putAscii(aliasRegAdapter[0], regAdapterValue);
        }
    
        // Supply Queue Manager name
        qmFields.putAscii(MQeQueueManager.Name, qmNameValue);

        // Supply registry details
        regFields.putAscii(MQeRegistry.DirName, regDirValue);

        if (privRegValue) {
            regFields.putAscii(MQeRegistry.LocalRegType, aliasPrivReg[0]);
            regFields.putAscii(MQeRegistry.PIN, prPinValue);
            regFields.putAscii(MQeRegistry.KeyRingPassword, prKrpValue);
        } else  // Standard File Registry
            regFields.putAscii(MQeRegistry.LocalRegType, aliasFileReg[0]);

        regFields.putAscii(MQeRegistry.Adapter, aliasRegAdapter[0]);

        // only write the separator Character if it is non-default
        if (!regSepValue.equals(defRegSeparator))
            regFields.putAscii(MQeRegistry.Separator, regSepValue);

        // server configuration ?
        if (serverValue) { 
            // Supply defaulted Channel Manager Listener parameters
            channelFields.putInt("MaxChannels", 0);

            // Supply defaulted Channel Listener parameters
            listenFields.putAscii("Listen", "FastNetwork" + "::" + listenPortValue);
            listenFields.putAscii("Network", "FastNetwork" + ":");
            listenFields.putInt("TimeInterval", 300);
        }

        // Determine which local queues are required
        // - for now we define all of them
        adminQ = true;
        adminReplyQ = true;
        defaultSysQ = true;
        deadLetterQ = true;

        // Consolidate the configuration sections
        configFields.putFields(MQeQueueManagerUtils.Section_Alias, aliasFields);
        configFields.putFields(MQeQueueManager.QueueManager, qmFields);
        configFields.putFields(MQeQueueManager.Registry, regFields);

        if (serverValue) {
            configFields.putFields(MQeQueueManagerUtils.Section_ChannelManager, channelFields);
            configFields.putFields(MQeQueueManagerUtils.Section_Listener, listenFields);
        }
    }

    /**
     * Check the Queue Manager name.
     *
     * @param name   The Queue Manager name
     * @return       'true' if it is valid, else false
     **/
    public boolean checkQmgrName(String name) {
        boolean result = true;

        try {
            MQeQueueManagerAdminMsg adminMsg = new MQeQueueManagerAdminMsg();

            result = adminMsg.checkName(name);
        } catch (Exception e) {
            result = false;
        }

        return result;
    }

    /**
     * Enable or disable the options in the GUI so that they are consistent.
     **/
    private void setGUIoptions() {
        // listener port option depends on whether Server is selected,
        serverValue = serverCB.getState();
        listenPortLabel.setEnabled(serverValue);
        listenPortTF.setEnabled(serverValue);

        // Private Registry options depend on whether Private Registry is selected
        privRegValue = privRegCB.getState();
        prPinLabel.setEnabled(privRegValue);
        prPinTF.setEnabled(privRegValue);
        prVPinLabel.setEnabled(privRegValue);
        prVPinTF.setEnabled(privRegValue);
        prKrpLabel.setEnabled(privRegValue);
        prKrpTF.setEnabled(privRegValue);
        prVKrpLabel.setEnabled(privRegValue);
        prVKrpTF.setEnabled(privRegValue);
    }

    /**
     * Tidy up and exit.
     **/
    private void close() {
        // no tidying up to do, just exit
        QMD.dispose();
        if (nameF != null) {
            nameF.dispose();
        }
	
        if (exitFlag) {
            if (shutDownOnClose) {    	
                System.exit(0);
            }
        }
    }

    /**
     * Initialise string values using the resource bundle.
     **/
    void initStrings() {
        super.initStrings();

        ResourceBundle resources = utils.getResourceBundle();

        String confirm = resources.getString("confirm");

        badKRPconfirmStr = resources.getString("badKRPconfirm");
        badPINconfirmStr = resources.getString("badPINconfirm");
        baseDirLblStr = resources.getString("baseDirLbl");
        cancelLabelStr = resources.getString("cancelButton");
        clientLblStr = resources.getString("clientLbl");
        clientStr = resources.getString("client");
        configFileStr = resources.getString("configFile");
        configStr = resources.getString("config");
        confirmKrpStr = resources.getString("confirmKrp");
        confirmPRPINStr = resources.getString("confirmPRPIN");
        confirmQMStr = resources.getString("confirmQM");
        createdStr = resources.getString("created");
        defineErrorStr = resources.getString("defineError");
        enterForListPortStr = resources.getString("enterForListPort");
        enterQMdetStr = resources.getString("enterQMdet");
        errorStr = resources.getString("error");
        existsStr = resources.getString("exists");
        getCredStr = resources.getString("getCred");
        invQMNameStr = resources.getString("invQMName");
        listenPortLblStr = resources.getString("listenPortLbl");
        listenPortStr = listenPortLblStr;
        noBaseDirStr = resources.getString("noBaseDir");
        noKrpStr = resources.getString("noKrp");
        noListPortStr = resources.getString("noListPort");
        noPRPinStr = resources.getString("noPRPin");
        noQMNameStr = resources.getString("noQMName");
        noQueueDirStr = resources.getString("noQueueDir");
        noRegDirStr = resources.getString("noRegDir");
        notRequiredStr = resources.getString("notRequired");
        nowLaterStr = resources.getString("nowLater");
        okLabelStr = resources.getString("okButton");
        privRegLblStr = resources.getString("privRegLbl");
        privRegStr = privRegLblStr;
        privRegWarnStr = resources.getString("privRegWarn");
        prKrpLblStr = resources.getString("prKrpLbl");
        prPinLblStr = resources.getString("prPinLbl");
        prVKrpLblStr = confirm + prKrpLblStr;
        prVPinLblStr = confirm + prPinLblStr;
        qmNameLblStr = resources.getString("qMgrName");
        qMgrNameStr = qmNameLblStr;
        qMgrStr = resources.getString("qMgr");
        queueDirLblStr = resources.getString("queueDir");
        queueDirStr = queueDirLblStr;
        regDirLblStr = resources.getString("regDir");
        regDirStr = regDirLblStr;
        regSepLblStr = resources.getString("regSepLbl");
        regSep1Str = resources.getString("regSep1");
        requiredStr = resources.getString("required");
        serverLblStr = resources.getString("serverLbl");
        serverStr = resources.getString("server");
        titleStr = resources.getString("defineTitle");
        noRegAdapterStr = "No registry adapter specified.";
    }

    /**
     * Start the application.
     **/
    public static void main(java.lang.String[] args) {
        new DefineQueueManager(args.length == 0 ? null : args[0]);
    }

    /**********************************************************************
     * Inner Class to extend Awtframe, overriding the Action method
     **********************************************************************/
    class defineNameFrame extends AwtFrame {
        defineNameFrame(String title) {
            super(title);
        }

        /**
         * Overide the Action method to provide interaction between the
         * components of the frame
         **/
        public void action(Object e, int where, int index, String  choice, boolean state) {
            // use the name, if there is one, then build the main GUI frame
            if (e == okB) {
                // if no name was specified, use the default
                qmNameValue = qmNameTF.getText().trim();
                if (qmNameValue.length() == 0)
                    qmNameValue = defQMName;

                // remove this window
                dispose();

                // display the main Queue Manager Frame
                displayQMFrame();
            }
        }

    } // end of inner class defineNameFrame


    /**********************************************************************
     * Inner Class to extend Awtframe, overriding the Action method
     **********************************************************************/
    class defineQMFrame extends AwtFrame {
        defineQMFrame(String title) {
            super(title);
        }

        /**
         * Overide the Action method to provide interaction between the
         * components of the frame
         **/
        public void action(Object e, int where, int index, String  choice, boolean state) {
            // exit if cancel is clicked
            if (e == cancelB)
                close();

            // check the details and create the queue manager if OK is clicked
            if (e == okB) {
                if (checkDetails() && confirmDetails() && createQMgr())
                    close();      // completed everything, so exit
                else
                    return;       // error in details, or user does not confirm
            } else
            // if client or server configuration is
            // selected, toggle the other one
            if (e == clientCB)
                serverCB.setState(!clientCB.getState());
            else if (e == serverCB)
                clientCB.setState(!serverCB.getState());

            // Set the GUI components into a consistent state
            setGUIoptions();
        }

    } // end of inner class defineQMFrame

}

