package examples.midp.exampleapp.messageservice;


/*----------------------------------------------------------------------------*/

/*                  WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                            */

/* Licensed Materials - Property of IBM                                       */

/*                                                                            */

/* 5765-E63                                                                   */

/*                                                                            */

/* (C) Copyright IBM Corp. 1999                                               */

/*----------------------------------------------------------------------------*/

import com.ibm.mqe.MQe;


/**
 * MQeMessageServiceConstants provides an interface containing a set of
 * constants for all users of the service. For example,  message consumers. This includes
 * default values for such items as:
 * <pre>
 *  - aliases
 *  - network adapters, type, address and port
 *  - listener adapters and ports
 *  - security adapters
 * </pre>
 */
public interface MQeMessageServiceConstants {

    public static short  version[] = { 2, 0, 0, 10 };  // MQe version

    /*
     * A set of parameters that can be used to create a queue manager
     * if the values are not specified in other ways e.g. in an ini file.
     *
     * First a set of default aliases [Alias].
     */
    
    /** The default eventlog */
    public final static String DEFAULT_EVENTLOG = "examples.log.LogToDiskFile";

    /** The default queue manager */
    public final static String DEFAULT_QUEUEMANAGER = "com.ibm.mqe.MQeQueueManager";

    /** The default file registry */
    public final static String DEFAULT_FILEREGISTRY = "com.ibm.mqe.registry.MQeFileSession";

    /** The default private registry */
    public final static String DEFAULT_PRIVATEREGISTRY = "com.ibm.mqe.registry.MQePrivateSession";

    /** The default channel */
    public final static String DEFAULT_CHANNEL = "com.ibm.mqe.MQeChannel";

    /** The default transporter */
    public final static String DEFAULT_TRANSPORTER = "com.ibm.mqe.MQeTransporter";

    /** The default channel attribute rules */
    public final static String DEFAULT_CHANNELATTRRULES = "examples.rules.AttributeRule";

    /*
     * Some constants depend on whether the system being run on is CLDC or CDC
     * These are set below.
     */
    
    /** The default network adapter */
    public final static String DEFAULT_NETWORK =
        MQe.isCLDC() ? "com.ibm.mqe.adapters.MQeMidpHttpAdapter" : "com.ibm.mqe.adapters.MQeTcpipHttpAdapter";

    /** The defalut fast network adapter */
    public final static String DEFAULT_FASTNETWORK =
        MQe.isCLDC()
        ? "com.ibm.mqe.adapters.MQeMidpHttpAdapter"
        : "com.ibm.mqe.adapters.MQeTcpipHistoryAdapter";

    /** The default mesaage log adapter */
    public final static String DEFAULT_MSGLOG =
        MQe.isCLDC()
        ? "com.ibm.mqe.adapters.MQeMidpFieldsAdapter"
        : "com.ibm.mqe.adapters.MQeDiskFieldsAdapter";

    /** The default trace adapter */
    public final static String DEFAULT_TRACE =
        MQe.isCLDC() ? "com.ibm.mqe.trace.MQeTraceToBinaryMidp" : "com.ibm.mqe.adapters.MQeTraceToReadable";

    /**
     * Default base directory for queue managers. This is the root directory
     * from which a queue managers queues and registry will be stored.
     * Default to \MQe\QM\
     */
    public final static String DEFAULT_BASEDIRNAME =
        MQe.fileSeparator() + "MQe" + MQe.fileSeparator() + "QM" + MQe.fileSeparator();

    /**
     * The maximum number of allowable channels [ChannelManager].
     */
    public final static int DEFAULT_MAXCHANNELS = 0;

    /** The default listener port. */
    public final static int DEFAULT_LISTENERPORT = 8082;

    /** The default listener adapter. */
    public final static String DEFAULT_LISTENERADAPTER = "Network";

    /** The default channel timeout value.*/
    public final static int DEFAULT_TIMEINTERVAL = 300;

    /** The default cryptor. */
    public static final String DEFAULT_CRYPTOR = "com.ibm.mqe.attributes.MQeDESCryptor";

    /** The default compressor. */
    public static final String DEFAULT_COMPRESSOR = "com.ibm.mqe.attributes.MQeLZWCompressor";

    /** The default registry PIN for a private registry. */
    public static final String DEFAULT_PIN = "123456789";

}
