package examples.midp.exampleapp.messageservice;


/*----------------------------------------------------------------------------*/

/*                    MQSeries Everyplace for Multiplatforms                  */

/*                                                                            */

/* Licensed Materials - Property of IBM                                       */

/*                                                                            */

/* 5765-E63                                                                   */

/*                                                                            */

/* (C) Copyright IBM Corp. 1999                                               */

/*----------------------------------------------------------------------------*/

import com.ibm.mqe.MQeMsgObject;


/**
 * This class is notified when a messsage has arrived on a monitored queue. This
 * occurs by one of the 4 abstract procedures being called, depending on the type
 * of message that has arrived.
 *
 * <p>A message service has a single message consumer.
 *
 * <p>Any class wishing to act as a server utilising the message service should
 * implement this.
 */
public interface MessageConsumer {

    public static short  version[] = { 2, 0, 0, 10 };  // MQe version

    /**
     *     A datagram message has been received.
     *
     * @param message The message to display
     * @param qMgrName The queue manager the message is on
     * @param qName The queue the message is on
     * @return void
     */
    void processDataGramMsg(MQeMsgObject message, String qMgrName, String qName);

    /**
     *     A reply message has been received.
     *
     * @param message The message to display
     * @param qMgrName The queue manager the message is on
     * @param qName The queue the message is on
     * @return void
     */
    void processReplyMsg(MQeMsgObject message, String qMgrName, String qName);

    /**
     *     A new request message has been received.
     *     Note, the message still exists on the queue, it has been
     *     browsed so will stay on the queue until a get or delete operation.
     *
     * @param message The message to display.
     * @param qMgrName The queue manager the message is on
     * @param qName The queue the message is on
     * @return void
     */
    void processRequestMsg(MQeMsgObject message, String qMgrName, String qName);

    /**
     *     Display a status/error message. The implementaion of this method should
     *     display a status / error message in whatever form is appropriate for the
     *     application / device.
     *
     * @param statusMessage Status message to be displayed
     * @return void
     */
    void processStatus(String statusMessage);
}
