package examples.midp.exampleapp.messageservice;


/* -----------------------------------------------------------------------------*/

/*                    MQSeries Everyplace for Multiplatforms                    */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/* -----------------------------------------------------------------------------*/

import com.ibm.mqe.MQeQueueManager;
import com.ibm.mqe.MQeQueueManagerRule;


/**
 * Example queue manager rules class.
 *   <br>- starts a background thread to trigger transmission of messages at a specified interval.
 *   <br>- transmission can also be triggered by notifiying the monitor object triggerTransmit
 */

public class QueueManagerRules extends MQeQueueManagerRule implements Runnable {
    public static short version[] = { 2, 0, 0, 10 }; 

    // default interval between triggers is 30 seconds
    protected int triggerInterval = 5000;

    // background thread reference
    // - static to ensure there is only ever one instance
    protected static Thread th = null;

    // wait on this object for transmission to be triggered
    // (actually waits for this object to be notified or until the triger interval
    // expires)
    public static Object triggerTransmit = new Object();

    /**
     *     Called when the rule is activated.
     *
     * @param thisOwner The owner of this object
     * @return void
     */
    public void activate(Object thisOwner) {
        System.out.println("[QMRules] activate");
        super.activate(thisOwner);

        // If thread already running stop it and start a new one as only
        // one is allowed at a time.

        if (th != null) {
            stopTriggerThread();
        }

        // create and start the background thread which triggers transmission
        if (th == null) {
            th = new Thread(this);
            th.start();
        }
    }

    /**
     *     Called when a Queue manager Close is called.
     *
     * @return void
     * @exception java.lang.Exception
     */
    public void queueManagerClose() throws Exception {
        // As queue manager is closing stop the background thread.
        stopTriggerThread();

        super.queueManagerClose();
    }

    /**
     *     Background thread run method.
     *     Triggers transmission every interval until thread is stopped.
     *
     * @return void
     */
    public void run() {
        System.out.println("[QMRules] run");
        while (th != null) {
            try {
                if (((MQeQueueManager) owner).isQueueManagerActive()) {
                    ((MQeQueueManager) owner).triggerTransmission();
                }

                // wait until triggered again or the trigger time interval expires
                synchronized (triggerTransmit) {
                    triggerTransmit.wait(triggerInterval);
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    /**
     *     Stop the thread that is triggering transmission.
     *
     * @return void
     */
    public void stopTriggerThread() {
        if (th != null) {
            th = null;
            synchronized (triggerTransmit) {
                triggerTransmit.notify();
            }
        }
    }
}
