package examples.midp.exampleapp.msgpump;


/*----------------------------------------------------------------------------*/

/*                    MQSeries Everyplace for Multiplatforms                  */

/*                                                                            */

/* Licensed Materials - Property of IBM                                       */

/*                                                                            */

/* 5765-E63                                                                   */

/*                                                                            */

/* (C) Copyright IBM Corp. 1999                                               */

/*----------------------------------------------------------------------------*/

/**
 * This is the msgpump controller interface class.
 * All controllers of a message pump must implement this.
 *
 * <p>The aim of the controller is to act as both the user interface and the
 * control centre for the message pump. This means that if a decision needs
 * to be made, this is the class that does it.
 *
 * <p>Controllers will be dependant on whether they are being run on J2SE, MIDP
 * or other versions of java - it is not expected that a generic controller client
 * will be used to control all client models as the user interface will differ
 * between java platforms.
 */
public interface MsgPumpController {

    public static short  version[] = { 2, 0, 0, 10 };  // MQe version
  
    /**
     *   This function is used to process a message before it is displayed.
     *
     * @param msg The message to be displayed
     */
    abstract public void processMsg(String msg);

    /**
     *   Returns the pump model, creating a new one first if necessary.
     *
     * @return MsgPumpModel - the pump model
     */
    abstract public MsgPumpModel getModel();

    /**
     *   Purges the queue manager from the system.
     *
     * @return void
     */
    abstract public void deleteQueueManager();

    /**
     *   Displays a status report or other type of message.
     *
     * @param msg The message to display
     */
    abstract public void displayMsg(String msg);

    /**
     *   Returns the name of hte queue manager.
     *
     * @return String - the name of the queue manager
     */
    abstract public String getQMname();

    /**
     *   Called to start the pumping.
     *
     * @return void
     */
    abstract public void start() throws Exception;

    /**
     *   Performs any actions necessary to initialize the controller.
     *   This includes getting the QM name and initializing the model.
     *
     * @return void
     */
    abstract public void initialize() throws Exception;
}
