package examples.midp.exampleapp.msgpump;


/*----------------------------------------------------------------------------*/

/*                    MQSeries Everyplace for Multiplatforms                  */

/*                                                                            */

/* Licensed Materials - Property of IBM                                       */

/*                                                                            */

/* 5765-E63                                                                   */

/*                                                                            */

/* (C) Copyright IBM Corp. 1999                                               */

/*----------------------------------------------------------------------------*/

import com.ibm.mqe.MQe;
import com.ibm.mqe.MQeFields;
import com.ibm.mqe.MQeMsgObject;


/**
 * This is the server side of the message pump model.
 * The purpose of the server is to display messages it receives to the user.
 */

public class MsgPumpModelServer extends MsgPumpModel {

    public static short  version[] = { 2, 0, 0, 10 };  // MQe version
  
    private String requestQueue = DEFAULT_SERVER_Q_NAME;

    MsgPumpModelServer() {
        super();
    }

    /**
     * @see MsgPumpModel#run()
     */
    public void run() {
        getMsgService().monitorQueue(getLocalQMname(), requestQueue);
    }

    /**
     * @see MsgPumpModel#performInitialConfiguration()
     */
    protected void performInitialConfiguration() throws Exception {
        processStatus("[Server Model] Initial configuration...");
        try {

            /* Create QMs and Qs required for server */
            getMsgService().createQueueManager();
            processStatus("[Server Model] Opening...");
            getMsgService().open();
            processStatus("[Server Model] Creating local queue...");

            // If we're using queue based escurity, set the queue up with the appropriate
            // attributes
            if (isSecurity(QUEUE_SECURITY)) {
                getMsgService().createLocalQueue(getLocalQMname(), requestQueue, sync, compressor, cryptor);
            } else {
                getMsgService().createLocalQueue(getLocalQMname(), requestQueue, sync);
            }

            processStatus("[Server Model] Updating QM...");

            /* Update QM with rules file */
            MQeFields qmParms = new MQeFields();

            qmParms.putAscii("rules", getQMrules());
            getMsgService().updateQueueManager(getLocalQMname(), qmParms);

            processStatus("[Server Model] Creating Listener...");

            /* Create a new listener to listen for messages */
            getMsgService().createListener(getLocalQMname() + "_Listener");
        } catch (Exception e) {
            try {
                getController().deleteQueueManager();
            } catch (Exception ex) {}
            throw e;
        }
    }

    /**
     *     The server cannot be paused.
     * @see MsgPumpModel#pause()
     */
    public void pause() {}

    /**
     * @see MsgPumpModel#resume()
     *
     *     As the server cannot be paused, it cannot be resumed either
     */
    public void resume() {}

    /**
     * @see MsgPumpModel#stop()
     */
    public void stop() {
        setController(null);
        try {
            finish();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * @see MsgPumpModel#processDataGramMsg(MQeMsgObject, String, String)
     */
    public void processDataGramMsg(MQeMsgObject message, String qMgrName, String qName) {
        processMsg(qMgrName, qName, message);
    }

    /**
     * @see MsgPumpModel#processReplyMsg(MQeMsgObject, String, String)
     */
    public void processReplyMsg(MQeMsgObject message, String qMgrName, String qName) {
        processMsg(qMgrName, qName, message);
    }

    /**
     * @see MsgPumpModel#processRequestMsg(MQeMsgObject, String, String)
     */
    public void processRequestMsg(MQeMsgObject message, String qMgrName, String qName) {
        processMsg(qMgrName, qName, message);
    }

    /**
     *     A message of some form has been received, so display it and consume
     *     it ( remove it from the queue ).
     *
     * @param qMgrName The name of the queue manager
     * @param qName The name of the queue
     * @param msg The message to display.
     * @return void
     */
    protected void processMsg(String qMgrName, String qName, MQeMsgObject msg) {
        processStatus("[Server Model]");
        processStatus("New message received!");

        try {
            if (isSecurity(MESSAGE_SECURITY)) {
                msg = msg.unwrapMsgObject(getMessageAttribute());
            }

            // Is it a datagram, request or reply?
            if (msg.contains(MQe.Msg_Style)) {
                if (msg.getInt(MQe.Msg_Style) == MQe.Msg_Style_Request) {
                    processStatus("Type : Request");
                } else if (msg.getInt(MQe.Msg_Style) == MQe.Msg_Style_Reply) {
                    processStatus("Type : Reply");
                }
            }

            String msgS = msg.dumpToString("\n", "... nested fields [#0]", "(#0)#1 : \t#2");

            processStatus(msgS);

            /* Consume the message */
            getMsgService().getMessage(qMgrName, qName, msg.getMsgUIDFields());
        } catch (Exception ex) {
            System.out.println("Error parsing new msg: " + ex);
        }
    }

    /**
     *     Gets the request queue of the server - the queue messages are pumped to.
     *
     * @return String - the name of the request queue
     */
    public String getRequestQueue() {
        return requestQueue;
    }
}
