package examples.midp.exampleapp.msgpump;


/*----------------------------------------------------------------------------*/

/*                    MQSeries Everyplace for Multiplatforms                  */

/*                                                                            */

/* Licensed Materials - Property of IBM                                       */

/*                                                                            */

/* 5765-E63                                                                   */

/*                                                                            */

/* (C) Copyright IBM Corp. 1999                                               */

/*----------------------------------------------------------------------------*/

/**
 * The server controller is required to do very little.
 * Most of the work comes from responding to user input. This is done in processInput().
 */
public class NormalServer extends NormalClient {

    public static short  version[] = { 2, 0, 0, 10 };  // MQe version
  
    /** String used to prompt the user for input.*/
    public static final String prompttext = "Server:\\>";

    /**
     *     The function called when the class is run.
     *     This creates and starts a new controller.
     */
    public static void main(String[] args) {
        try {
            NormalServer controller = new NormalServer();

            controller.initialize();
            controller.start();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     *     Returns the default queue manager name.
     * @see MsgPumpController#getQMname()
     */
    public String getQMname() {
        return getModel().DEFAULT_SERVER_QM_NAME;
    }

    /**
     *     Returns a new inputthread.
     *
     * @return InputThread - a new inputthread
     */
    protected InputThread getNewInputThread() {
        return new InputThread(this, starttext, prompttext);
    }

    /**
     * @see NormalClient#processInput(String)
     */
    public void processInput(String input) {
        if (input.equals("help")) {
            displayMsg("The following commands are available:-");
            displayMsg("help:           Displays this screen");
            displayMsg("viewqueue:      View all messages on queue");
            displayMsg("clrqueue:       Clears any messages on the queue");
            displayMsg("status:         Displays information about the server");
            displayMsg("quit:           Quits the pump server");
        } else if (input.equals("viewqueue")) {
            getModel().getMsgService().processMessages(
                ((MsgPumpModelServer) getModel()).getLocalQMname(),
                ((MsgPumpModelServer) getModel()).getRequestQueue(),
                null);
        } else if (input.equals("clrqueue")) {
            try {
                getModel().getMsgService().emptyQueue(
                    ((MsgPumpModelServer) getModel()).getLocalQMname(),
                    ((MsgPumpModelServer) getModel()).getRequestQueue());
            } catch (Exception e) {}
        } else if (input.equals("status")) {
            displayMsg("");
            displayMsg("-----===== Status Report =====-----");
            displayMsg("Server QM: " + ((MsgPumpModelServer) getModel()).getLocalQMname());
            displayMsg("Server Q:  " + ((MsgPumpModelServer) getModel()).getRequestQueue());
            displayMsg("");
        } else if (input.equals("quit")) {
            getModel().stop();
        } else {
            displayMsg("Unknown command '" + input + "'");
        }
    }

    /**
     *     returns a pump server model.
     * @see NormalClient#getNewModel()
     */
    public MsgPumpModel getNewModel() {
        return new MsgPumpModelServer();
    }
}
