package examples.midp.exampleapp.textapp;



/*----------------------------------------------------------------------------*/

/*                    MQSeries Everyplace for Multiplatforms                  */

/*                                                                            */

/* Licensed Materials - Property of IBM                                       */

/*                                                                            */

/* 5765-E63                                                                   */

/*                                                                            */

/* (C) Copyright IBM Corp. 1999                                               */

/*----------------------------------------------------------------------------*/


import com.ibm.mqe.MQe;
import com.ibm.mqe.MQeMsgObject;
import com.ibm.mqe.mqemqmessage.MQeMQMsgObject;



/**
 * A simple layout for a server that the registration server and gateway can extend.
 * This class is abstract as it should not be used as a server model, since it does not
 * implement some abstract classes that are required and will differ between servers.
 *
 * <p>In general, a server will need to specify its listener port and define what to do
 * when it gets a message as well as how to display it.
 *
 * <p>The defaults for this are provided within this class, though they may be overridden
 * by classes that extend it. e.g. the registration server listens on port 8083 not the
 * default 8082 to allow it to be present on the same computer as the gateway server.
 *
 */
abstract public class AppModelServer extends AppModel {

    public static short  version[] = { 2, 0, 0, 10 };  // MQe version


    /**
     * @see examples.midp.exampleapp.textapp.AppModel#isServer
     */
    protected boolean isServer() {
        return true;
    }


    /**
     * If a datagram is received, simply display it.
     * @see examples.midp.exampleapp.textapp.AppModel#processDataGramMsg(MQeMsgObject, String, String)
     */
    public void processDataGramMsg(MQeMsgObject message, String qMgrName, String qName) {
        processMessage(message);
    }


    /**
     * Configures the model - servers need a listener.
     * @see examples.midp.exampleapp.textapp.AppModel#initialConfiguration
     */
    protected void initialConfiguration() throws Exception {
        super.initialConfiguration();
        createListener();
    }

    /**
     *   Formats an MQe or MQ message before displaying it.
     *
     * @param message The message to display
     * @return void
     */
    public void processMessage(MQeMsgObject message) {
        String stringHeader = "Datagram   : ";
        String sender = message.getOriginQMgr();


        try {
            if (message.contains(MQe.Msg_Style)) {
                if (message.getInt(MQe.Msg_Style) == MQe.Msg_Style_Request) {
                    stringHeader = sender + " >> : ";
                } else if (message.getInt(MQe.Msg_Style) == MQe.Msg_Style_Reply) {
                    stringHeader = "<< Reply   : ";
                }
            }


            if (message instanceof MQeMQMsgObject) {
                processStatus(stringHeader + MQe.byteToAscii(((MQeMQMsgObject) message).getData()));
            } else {
                processStatus(message.dumpToString(stringHeader + "#0\t#1\t= #2"));
            }
        } catch (Exception ex) {
            processStatus("Error parsing new msg: " + ex);
        }
    }


    /**
     * @see examples.midp.exampleapp.textapp.AppModel#getListenerPort
     */
    protected int getListenerPort() {
        return DEFAULT_LISTENER_PORT;
    }
}
