// version mqe_java/source/examples/migration/Migrator.java, MQeExamples, la200, la200-L030324.1 1.9

/* -----------------------------------------------------------------------------*/

/*                   WebSphere MQ Everyplace for Multiplatforms                 */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 2002                                                 */

/* -----------------------------------------------------------------------------*/
package examples.migration;


import com.ibm.mqe.validation.MQeDiskImageValidator;
import com.ibm.mqe.MQe;
import com.ibm.mqe.validation.MQeDiskImageValidationReporter;


/**
 * <p>
 * The Migrator class illustrates the implementation of a simple migration tool. The arguments
 * required to run this class are:
 * <br> 1st argument should be the queue manager name to be migrated
 * <br> 2nd argument should be the base directory of the registry for that queue manager. For
 * instance if you have a queue manager name of queueManager1 and you have used the default name
 * for the registry directory, the directory required will be queueManager1\Registry
 * </p>
 * 
 */

public class Migrator implements MQeDiskImageValidationReporter {

    public static short version[] = { 2, 0, 0, 10 }; 

    /**
     * Starts the Migrator application.
     * @param args an array of command-line arguments
     */
    public static void main(java.lang.String[] args) {
        // Insert code to start the application here.
        if (2 > args.length) {
            System.out.println("insufficient parameters. Please supply queue manager name and base directory");
        } else {

            // create an instance of the validator
            MQeDiskImageValidator validator = new MQeDiskImageValidator();
        
            // create an instance to capture warnings and errors, and pass it
            // to the validator
            Migrator migrator = new Migrator();

            validator.setReporter(migrator);

            // request upgrade to version 2.0.0.0
            long requiredVersion = MQe.shortsToLong((short) 2, (short) 0, (short) 0, (short) 0);

            System.out.println("**** Migration Starting ****");
            boolean success = validator.validateRegistry(args[0], args[1], requiredVersion);

            if (success) {
                System.out.println("**** Migration Successful ****");
            } else {
                System.out.println("**** Migration did not complete successfully ****");
            }
        }
    }

    /**
     * Method to report errors in a common format.
     * Implemented here to satisfy MQeRegistryValidationReporter
     * interface.
     * @param txt A String.
     * @return void
     */
    public void validationError(String txt) {
        System.out.println("ERROR:\t\t" + txt);
    }

    /**
     * Method to report information in a common format.
     * Implemented here to satisfy MQeRegistryValidationReporter
     * interface.
     * @param txt A String.
     * @return void
     */
    public void validationInformation(String txt) {
        System.out.println("INFORM:\t\t" + txt);
    }

    /**
     * Method to report warnings in a common format.
     * Implemented here to satisfy MQeRegistryValidationReporter
     * interface.
     * @param txt A String.
     * @return void
     */
    public void validationWarning(String txt) {
        System.out.println("WARNING:\t\t" + txt);
    }
}
