// Version mqe_java/source/examples/mqbridge/administration/commandline/SendTestMessage.java, MQe, la200, la200-L030324.1 1.7

/*------------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 2001                                                 */

/*                                                                              */

/*------------------------------------------------------------------------------*/
package examples.mqbridge.administration.commandline;


import com.ibm.mqe.*;
import com.ibm.mqe.administration.*;
import examples.administration.commandline.*;
import examples.mqbridge.queuemanager.*;
import examples.queuemanager.*;
import com.ibm.mqe.mqemqmessage.*; 
                            

/**
 * To send a test message from one queue manager to another, using a bridge-enabled server to do so.
 * 
 * <P><B>Syntax</B></P>
 * <P><TT>java examples.mqbridge.administration.commandline.SendTestMessage
 * &lt;queue_name&gt;
 * &lt;hosting_queue_manager&gt;
 * &lt;ini_file&gt;
 * </TT></P>
 * <P><B>Parameters</B></P>
 * <DL>
 * <DT>queue_name</DT>
 * <DD>is the name of the remote queue we are creating</DD>
 * <DT>hosting_queue_manager</DT>
 * <DD>is the name of the queue manager on which the queue actually exists</DD>
 * <DT>ini_file</DT>
 * <DD>Name of the ini file used to open a bridge-enabled server queue manager, to
 * send the message from.</DD>
 * </DL>
 */
public class SendTestMessage extends examples.administration.commandline.MQeAbstractCmdLineAdminTool { 

    public       static short version[] = { 2, 0, 0, 10 }; 

    /**
     * The number of seconds the program sleeps for after it's posted the message...
     * To give any asynchronous threads some chance of sending the message on to a 
     * different queue manager.
     */
    public static final long SLEEP_SECONDS = 1000 * 5;

    static final String syntax = 
        "Syntax:\n"
        + "SendTestMessage <queue_name> <hosting_queue_manager> <ini_file>\n"
        + "Parameters:\n"
        + "<queue_name>\n"
        + "     is the name of the queue we are sending a message to.\n"
        + "<hosting_queue_manager>\n"
        + "     is the name of the queue manager on which the queue actually exists.\n"
        + "<ini_file>\n"
        + "     Name of the ini file used to open a client queue manager, to\n"
        + "     send the messages from.\n";

    /**
     * Entry point from the command line.
     */
    public static void main(String args[]) {
        int rc = 0;
        SendTestMessage me = new SendTestMessage();

        try {
            me.activate(args);
        } catch (Exception e) {
            System.out.println("Error: activate() failed. " + e.toString());
            rc = 1;
        }
        System.exit(rc); // exit,killing the trace window by force if necessary.
    }

    /**
     * Does all the work.
     * @param args
     * @return void
     * @exception java.lang.Exception
     */
    public void activate(String args[]) throws Exception {

        String q = null;        // Name of the queue we're sending to
        String qmgr = null;     // Name of the queue manager we're sending to.
        String iniFile = null;      // Name of the ini file used to open a client queue manager, to 

        // send the admin messages from.
        if (args.length < 3) {
            throw new Exception("Not enough parameters !\n" + syntax);
        }

        q = args[0].trim();
        qmgr = args[1].trim();
        iniFile = args[2].trim();

        System.out.println("i: Attempting to send a message to queue " + q + " on queue manager " + qmgr);

        // Access the local MQe queue manager...
        MQeServer server = new MQeServer(iniFile, true // Supress any stdout information.
            );

        // Start up the server...
        server.activate(true);

        // Access the queue manager created in this JVM... the server QM
        MQeQueueManager myQMgr = MQeQueueManager.getDefaultQueueManager();

        // send the test message to the queue...
        sendTestMsg(q, qmgr, myQMgr);

        // Hold the queue manager open for long enough that the message stands a chance
        // of getting to the other end...
        java.lang.Thread.sleep(SLEEP_SECONDS);

        // Ask the server to shut down peacefully...
        server.activate(false);
    }  

    /**
     * Sends a test message.
     * @param q Qname
     * @param qmgr QMgrName
     * @param myQMgr MQeQueueManager object
     * @return void
     * @exception java.lang.Exception
     */
    protected void sendTestMsg(String q, String qmgr, MQeQueueManager myQMgr
    ) throws Exception {

        System.out.println("Building the message to send...");

        MQeMQMsgObject msg = new MQeMQMsgObject();              

        byte[] myData = new byte[4];

        myData[0] = (byte) 65;
        myData[1] = (byte) 66;
        myData[2] = (byte) 67;
        myData[3] = (byte) 68;

        msg.setData(myData);

        System.out.println("Built the message.");

        // Send the message.
        // Put the message to the queue...
        myQMgr.putMessage(qmgr      // Queue manager we're sending to.
            , q         // Queue we're sending to.
            , msg                  // Message we're sending.
            , null                 // Attributes of the message.
            , (long) 0              // We're not sending a confirm.
        );
        System.out.println("Sent the message ok.");
    }  
} 

