/*------------------------------------------------------------------------------*/

/*                    MQSeries Everyplace for Multiplatforms                    */ 

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/*                                                                              */

/*------------------------------------------------------------------------------*/ 
package examples.mqbridge.administration.console;


import com.ibm.mqe.*;
import examples.administration.console.*;
import com.ibm.mqe.mqbridge.*; 
import examples.awt.*;
import java.awt.*; 


/********************************************************************************
 *
 * Provides an example of how you might administer an MQ-bridge object
 * known as an 'MQ bridges list'.
 * This class provides an extra button on the west panel.
 * A set of action-buttons are provided in the east panel also.
 *
 *******************************************************************************/
public class AdminMQBridges extends AdminFrame {
    
    public        static short    version[] = { 2, 0, 0, 10 }; 

    /**
     * Default constructor
     */
    public AdminMQBridges() {
        super("MQ Bridge Administration");
    }

    /**
     * Main constructor.
     *
     * @param msg An admin message to contain the parameters for the action.
     * If it already contains any parameters then these are taken as defaults
     * @param action The action to be performed
     * @param adminModel The admin model which will send the message.
     * 
     */
    public AdminMQBridges(MQeAdminMsg msg, int action, AdminModel adminModel 
    ) throws Exception {
        super(msg, action, adminModel);
    }

    /**
     * AdminQueueManager constructor
     */
    public AdminMQBridges(String title) throws Exception {
        super(title);
    }

    /**
     * Add any aliases related to this resource
     */
    public void addAlias() throws Exception {
        MQe.alias("MQeMQBridgesAdminMsgGUI",
            "examples.mqbridge.administration.console.AdminMQBridges");
    }

    /**
     * Return an actions panel
     */
    public Panel getActionsPanel(AwtEvent eventHandler) {
        String[][][] actions = new String[][][]
            { { { "B", "Inquire"}
                },            // 0
                { { "B", "Start"}
                },               // 1
                { { "B", "Stop"}
                }                 // 2
            };

        // ..Queue actions
        AwtFormat actionF = new AwtFormat(eventHandler, East);

        return actionF.panel(new Panel(), actions);
    }

    /**     
     * Return the name of resource being managed
     * @return java.lang.String
     */
    public String getResourceTitle() {
        return "Bridges List";
    }

    /**
     * Process a queue manager action request
     */
    public void resourceAction(Object e, int Where, int Index, String  Choice, boolean State 
    ) throws Exception {
        int act = -1;       // Unknown action

        // Decide on which action the user selected
        switch (Index) {
        case 0:
            act = MQeMQBridgesAdminMsg.Action_InquireAll;
            break;              

        case 1:
            act = MQeMQBridgesAdminMsg.Action_Start;
            break;

        case 2:
            act = MQeMQBridgesAdminMsg.Action_Stop;
            break;
        }

        // Display the message in a window	
        activate(new MQeMQBridgesAdminMsg(((AdminBridgeModel) adminModel).affectChildren), act, adminModel 
        );    
    }

    /**
     * Set up the admin message with the action to be performed and the
     * parameters required by the action
     */
    public MQeAdminMsg setupAction(MQeFields parms) throws Exception {
        switch (new Integer(action).intValue()) {
        case MQeMQBridgesAdminMsg.Action_InquireAll:
            // Inquire 
            ((MQeMQBridgesAdminMsg) msg).inquireAll(parms);
            break;

        case MQeMQBridgesAdminMsg.Action_Start:
            // Start
            ((MQeMQBridgesAdminMsg) msg).start(parms);
            break;

        case MQeMQBridgesAdminMsg.Action_Stop:
            // Stop
            ((MQeMQBridgesAdminMsg) msg).stop(parms);
            break;
        }
        return (MQeAdminMsg) msg;
    }

    /**
     * Configure the set of actions
     */
    protected void setupActions() {
        super.setupActions();

        addAction(new String().valueOf(MQeMQBridgesAdminMsg.Action_InquireAll),    
            new String[][] {} 
        );
        addAction(new String().valueOf(MQeMQBridgesAdminMsg.Action_Start), 
            new String[][] {    
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_AFFECT_CHILDREN, "M"},
            } 
        );
        addAction(new String().valueOf(MQeMQBridgesAdminMsg.Action_Stop),  
            new String[][] {} 
        );
    }

    /**
     * Set up the valid set of characteristics
     * - the sequence is important as this is the sequence that the fields
     *   will be displayed
     */
    protected void setupFields() {
        super.setupFields();

        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_RUN_STATE, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_CHILDREN, "C", null);  // A checkbox
    }

    /**
     * Set up text labels.
     */
    protected void setupNLS() {
        super.setupNLS();

        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_RUN_STATE, "Run State");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_CHILDREN, "Bridges (Children)");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_AFFECT_CHILDREN, "Affect children");
        addNLSName((new String()).valueOf(MQeMQBridgeAdminMsg.Action_InquireAll), "Inquire");
        addNLSName((new String()).valueOf(MQeMQBridgeAdminMsg.Action_Start), "Start");
        addNLSName((new String()).valueOf(MQeMQBridgeAdminMsg.Action_Stop), "Stop");
        addNLSName("cancel", "Cancel");
    }

    /**
     * Returns a string that provides information about the current frame.
     * This is displayed in the south panel of the main admin gui when a frame is selected.
     * @return String documenting the current frame.
     */
    public String getMessageHelp() {
        return "The Bridges List maintains a list of all currently defined Bridge objects.";
    }
}
