/*------------------------------------------------------------------------------*/

/*                    MQSeries Everyplace for Multiplatforms                    */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/*                                                                              */

/*------------------------------------------------------------------------------*/ 
package examples.mqbridge.administration.console;


import com.ibm.mqe.*;
import examples.administration.console.*;
import com.ibm.mqe.mqbridge.*;
import examples.awt.*;
import java.awt.*;


/********************************************************************************
 *
 * Provides an example of how you might administer an MQ-bridge object
 * known as a 'client connection'.
 * This class provides an extra button on the west panel.
 * A set of action-buttons are provided in the east panel also.
 *
 ********************************************************************************/
public class AdminMQClientConnection extends AdminFrame {
    
    public        static short    version[] = { 2, 0, 0, 10 }; 

    /**
     * Default constructor
     */
    public AdminMQClientConnection() {
        super("MQ Bridge Administration");
    }

    /**
     * Main constructor.
     *
     * @param msg An admin message to contain the parameters for the action. If it already 
     *        contains any parameters then these are taken as defaults
     * @param action  The action to be performed
     * @param adminModel The admin model which will send the message.
     * 
     */
    public AdminMQClientConnection(MQeAdminMsg msg, int action, AdminModel adminModel) throws Exception {
        super(msg, action, adminModel);
    }

    /**
     * AdminQueueManager constructor
     */
    public AdminMQClientConnection(String title) throws Exception {
        super(title);
    }

    /**
     * Add any aliases related to this resource
     */
    public void addAlias() throws Exception {
        MQe.alias("MQeClientConnectionAdminMsgGUI",
            "examples.mqbridge.administration.console.AdminMQClientConnection");
    }

    /**
     * Return an actions panel
     */
    public Panel getActionsPanel(AwtEvent eventHandler) {
        String[][][] actions = new String[][][]

            { { { "B", "Inquire"}
                }, // 0
                { { "B", "Update"}
                },  // 1
                { { "B", "Start"}
                },   // 2
                { { "B", "Stop"}
                },    // 3
                { { "B", "Create"}
                },  // 4
                { { "B", "Delete"}
                },  // 5
            };
        // ..Queue actions
        AwtFormat actionF = new AwtFormat(eventHandler, East);

        return actionF.panel(new Panel(), actions);
    }

    /**     
     * Returns the name of resource being managed
     * @return java.lang.String
     */
    public String getResourceTitle() {
        return "MQ Client Connection";
    }

    /**
     * Process a queue manager action request
     */
    public void resourceAction(Object e, int Where, int Index, String  Choice, boolean State 
    ) throws Exception {
        int act = -1;       // Unknown action

        // Decide on which action the user selected
        switch (Index) {
        case 0:
            act = MQeClientConnectionAdminMsg.Action_InquireAll;
            break;              

        case 1:
            act = MQeClientConnectionAdminMsg.Action_Update;        
            break; 

        case 2:
            act = MQeClientConnectionAdminMsg.Action_Start;
            break;

        case 3:
            act = MQeClientConnectionAdminMsg.Action_Stop;
            break;

        case 4:
            act = MQeClientConnectionAdminMsg.Action_Create;
            break;

        case 5:
            act = MQeClientConnectionAdminMsg.Action_Delete;
            break;

        }

        // Display the message in a window	
        activate(new MQeClientConnectionAdminMsg(((AdminBridgeModel) adminModel).bridgeName, ((AdminBridgeModel) adminModel).proxyName, ((AdminBridgeModel) adminModel).clientConnectionName, ((AdminBridgeModel) adminModel).affectChildren
            ), act, adminModel 
        );    
    }

    /**
     * Set up the admin message with the action to be performed and the
     * parameters required by the action
     */
    public MQeAdminMsg setupAction(MQeFields parms) throws Exception {
        switch (new Integer(action).intValue()) {
        case MQeClientConnectionAdminMsg.Action_InquireAll:
            // Inquire 
            ((MQeClientConnectionAdminMsg) msg).inquireAll(parms);
            break;

        case MQeClientConnectionAdminMsg.Action_Update:
            // Update
            ((MQeClientConnectionAdminMsg) msg).update(parms);
            break;

        case MQeClientConnectionAdminMsg.Action_Start:
            // Start
            ((MQeClientConnectionAdminMsg) msg).start(parms);
            break;

        case MQeClientConnectionAdminMsg.Action_Stop:
            // Stop
            ((MQeClientConnectionAdminMsg) msg).stop(parms);
            break;

        case MQeClientConnectionAdminMsg.Action_Create:
            // Create
            ((MQeClientConnectionAdminMsg) msg).create(parms);
            break;

        case MQeClientConnectionAdminMsg.Action_Delete:
            // Delete
            ((MQeClientConnectionAdminMsg) msg).delete(parms);
            break;
        }
        return (MQeAdminMsg) msg;
    }

    /**
     * Configure the set of actions
     */
    protected void setupActions() {
        super.setupActions();

        addAction(new String().valueOf(MQeClientConnectionAdminMsg.Action_Update),
            new String[][] {    
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_PORT, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_USER_ID, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_PASSWORD, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_SECURITY_EXIT, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_RECEIVE_EXIT, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_SEND_EXIT, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_CCSID, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_NAME, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_PURGER_RULES_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_PURGE_INTERVAL, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MAX_CONNECTION_IDLE_TIME, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_BRIDGE_ADAPTER_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_ADMINISTERED_OBJECT_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_STARTUP_RULE_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, "O"},
            } 
        );

        addAction(new String().valueOf(MQeClientConnectionAdminMsg.Action_InquireAll), 
            new String[][] {    
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "M"},
            } 
        );
        addAction(new String().valueOf(MQeClientConnectionAdminMsg.Action_Start),  
            new String[][] {    
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_AFFECT_CHILDREN, "M"},
            } 
        );
        addAction(new String().valueOf(MQeClientConnectionAdminMsg.Action_Stop),   
            new String[][] {    
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "M"},
            } 
        );
        addAction(new String().valueOf(MQeClientConnectionAdminMsg.Action_Create), 
            new String[][] {    
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_PORT, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_USER_ID, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_PASSWORD, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_SECURITY_EXIT, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_RECEIVE_EXIT, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_SEND_EXIT, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_CCSID, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_NAME, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_PURGER_RULES_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_PURGE_INTERVAL, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MAX_CONNECTION_IDLE_TIME, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_BRIDGE_ADAPTER_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_ADMINISTERED_OBJECT_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_STARTUP_RULE_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, "O"},
            } 
        );
        addAction(new String().valueOf(MQeClientConnectionAdminMsg.Action_Delete), 
            new String[][] {    
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_AFFECT_CHILDREN, "M"},
            }
        );
    }

    /**
     * Set up the valid set of characteristics
     * - the sequence is important as this is the sequence that the fields
     *   will be displayed
     */
    protected void setupFields() {
        super.setupFields();

        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_PORT, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_USER_ID, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_PASSWORD, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_SECURITY_EXIT, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_RECEIVE_EXIT, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_SEND_EXIT, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_CCSID, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_NAME, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_PURGER_RULES_CLASS, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_PURGE_INTERVAL, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_MAX_CONNECTION_IDLE_TIME, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_BRIDGE_ADAPTER_CLASS, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_ADMINISTERED_OBJECT_CLASS, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_STARTUP_RULE_CLASS, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_RUN_STATE, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_CHILDREN, "C", null);  // A list field
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, "TF", null);
    }

    /**
     * Define some text labels
     */
    protected void setupNLS() {
        super.setupNLS();

        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "MQ Bridge Name *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "MQ Queue Manager Proxy Name");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "MQ Channel (=client connection name)");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_PORT, "Port (of MQ channel listener)");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_USER_ID, "User ID *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_PASSWORD, "Password *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_SECURITY_EXIT, "Security exit class *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_RECEIVE_EXIT, "Receive exit class *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_SEND_EXIT, "Send exit class *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_CCSID, "CCSID *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_BRIDGE_ADAPTER_CLASS, "MQ adapter class *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_NAME, "Sync Q (must exist on the MQ QMgr)");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_PURGER_RULES_CLASS, "Sync queue purger rule class *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_PURGE_INTERVAL, "Sync queue purge interval (minutes) *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_MAX_CONNECTION_IDLE_TIME, "Max MQ connection idle time (minutes) *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_ADMINISTERED_OBJECT_CLASS, "Client connection class *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_STARTUP_RULE_CLASS, "Startup rule class *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_RUN_STATE, "Run state");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_CHILDREN, "Listener children");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_AFFECT_CHILDREN, "Affect children *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, "Description *");

        addNLSName((new String()).valueOf(MQeClientConnectionAdminMsg.Action_InquireAll), "Inquire");
        addNLSName((new String()).valueOf(MQeClientConnectionAdminMsg.Action_Update), "Update");
        addNLSName((new String()).valueOf(MQeClientConnectionAdminMsg.Action_Start), "Start");
        addNLSName((new String()).valueOf(MQeClientConnectionAdminMsg.Action_Stop), "Stop");
        addNLSName((new String()).valueOf(MQeClientConnectionAdminMsg.Action_Create), "Create");
        addNLSName((new String()).valueOf(MQeClientConnectionAdminMsg.Action_Delete), "Delete");
        addNLSName("cancel", "Cancel");
    }

    /**
     * Returns a string that provides information about the current frame.
     * This is displayed in the south panel of the main admin gui when a frame is selected.
     * @return String documenting the current frame.
     */
    public String getMessageHelp() {
        return "MQ Client Connection objects define methods of connecting to existing MQ Queue Managers.";
    }
}
