/*------------------------------------------------------------------------------*/

/*                    MQSeries Everyplace for Multiplatforms                    */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/*                                                                              */

/*------------------------------------------------------------------------------*/ 
package examples.mqbridge.administration.console;


import examples.administration.console.*;
import com.ibm.mqe.*;
import com.ibm.mqe.mqbridge.*;
import examples.awt.*;
import java.awt.*; 


/********************************************************************************
 *
 * Provides an example of how you might administer an MQ-bridge object
 * known as an 'MQ transmission queue listener'.
 * This class provides an extra button on the west panel.
 * A set of action-buttons are provided in the east panel also.
 *
 ********************************************************************************/
public class AdminMQListener extends AdminFrame {

    public        static short    version[] = { 2, 0, 0, 10 }; 

    /**
     * Default constructor
     */
    public AdminMQListener() {
        super("MQ Bridge Administration");
    }

    /**
     * Main constructor.
     *
     * @param msg An admin message to contain the parameters for the action. If it already 
     *        contains any parameters then these are taken as defaults
     * @param action The action to be performed
     * @param adminModel The admin model which will send the message.
     * 
     */
    public AdminMQListener(MQeAdminMsg msg, int action, AdminModel adminModel) throws Exception {
        super(msg, action, adminModel);
    }

    /**
     * AdminQueueManager constructor
     */
    public AdminMQListener(String title) throws Exception {
        super(title);
    }

    /**
     * Add any aliases related to this resource
     */
    public void addAlias() throws Exception {
        MQe.alias("MQeListenerAdminMsgGUI",
            "examples.mqbridge.administration.console.AdminMQListener");
    }

    /**
     * Return an actions panel
     */
    public Panel getActionsPanel(AwtEvent eventHandler) {
        String[][][] actions = new String[][][]

            { { { "B", "Inquire"}
                }, // 0
                { { "B", "Update"}
                },  // 1
                { { "B", "Start"}
                },   // 2
                { { "B", "Stop"}
                },    // 3
                { { "B", "Create"}
                },  // 4
                { { "B", "Delete"}
                }   // 5
            };

        // ..Queue actions
        AwtFormat actionF = new AwtFormat(eventHandler, East);

        return actionF.panel(new Panel(), actions);
    }

    /**     
     * Return the name of resource being managed
     * @return java.lang.String
     */
    public String getResourceTitle() {
        return "MQ Xmit Queue Listener";
    }

    /**
     * Process a queue manager action request
     */
    public void resourceAction(Object e, int Where, int Index, String  Choice, boolean State 
    ) throws Exception {
        int act = -1;       // Unknown action

        // Decide on which action user selected ?
        switch (Index) {
        case 0:
            act = MQeListenerAdminMsg.Action_InquireAll;
            break;              

        case 1:
            act = MQeListenerAdminMsg.Action_Update;        
            break; 

        case 2:
            act = MQeListenerAdminMsg.Action_Start;
            break;

        case 3:
            act = MQeListenerAdminMsg.Action_Stop;
            break;

        case 4:
            act = MQeListenerAdminMsg.Action_Create;
            break;

        case 5:
            act = MQeListenerAdminMsg.Action_Delete;
            break;

        }

        // Display the message in a window	
        activate(new MQeListenerAdminMsg(((AdminBridgeModel) adminModel).bridgeName, ((AdminBridgeModel) adminModel).proxyName, ((AdminBridgeModel) adminModel).clientConnectionName, ((AdminBridgeModel) adminModel).listenerName, ((AdminBridgeModel) adminModel).affectChildren
            ), act, adminModel 
        );    
    }

    /**
     * Set up the admin message with the action to be performed and the
     * parameters required by the action
     */
    public MQeAdminMsg setupAction(MQeFields parms) throws Exception {
        switch (new Integer(action).intValue()) {
        case MQeListenerAdminMsg.Action_InquireAll:
            // Inquire 
            ((MQeListenerAdminMsg) msg).inquireAll(parms);
            break;

        case MQeListenerAdminMsg.Action_Update:
            // Update
            ((MQeListenerAdminMsg) msg).update(parms);
            break;

        case MQeListenerAdminMsg.Action_Start:
            // Start
            ((MQeListenerAdminMsg) msg).start(parms);
            break;

        case MQeListenerAdminMsg.Action_Stop:
            // Stop
            ((MQeListenerAdminMsg) msg).stop(parms);
            break;

        case MQeListenerAdminMsg.Action_Create:
            // Create
            ((MQeListenerAdminMsg) msg).create(parms);
            break;

        case MQeListenerAdminMsg.Action_Delete:
            // Delete
            ((MQeListenerAdminMsg) msg).delete(parms);
            break;
        }
        return (MQeAdminMsg) msg;
    }

    /**
     * Configure the set of actions
     */
    protected void setupActions() {
        super.setupActions();

        addAction(new String().valueOf(MQeClientConnectionAdminMsg.Action_Update), getUpdateFields()
        );

        addAction(new String().valueOf(MQeClientConnectionAdminMsg.Action_InquireAll), getInquireAllFields()
        );
        addAction(new String().valueOf(MQeClientConnectionAdminMsg.Action_Start), getStartFields()
        );
        addAction(new String().valueOf(MQeClientConnectionAdminMsg.Action_Stop), getStopFields()
        );

        addAction(new String().valueOf(MQeClientConnectionAdminMsg.Action_Create), getCreateFields()
        );

        addAction(new String().valueOf(MQeClientConnectionAdminMsg.Action_Delete), getDeleteFields()
        );

    }

    /**
     * Setup the valid set of characteristics
     * - the sequence is important as this is the sequence that the fields
     *   will be displayed
     */
    protected void setupFields() {
        super.setupFields();

        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_LISTENER_NAME, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_DEAD_LETTER_Q_NAME, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_LISTENER_STATE_STORE_ADAPTER, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_UNDELIVERED_MESSAGE_RULE_CLASS, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_SECONDS_WAIT_FOR_MSG, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_FLOWS_PER_COMMIT, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_ADMINISTERED_OBJECT_CLASS, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_STARTUP_RULE_CLASS, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_TRANSFORMER, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_RUN_STATE, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, "TF", null);
    }

    /**
     * Define the text labels.
     */
    protected void setupNLS() {
        super.setupNLS();

        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "MQ Bridge Name *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "MQ Queue Manager Proxy Name");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "MQ Client Connection Name");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_LISTENER_NAME, "MQ XmitQ Name (=listener name)");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_DEAD_LETTER_Q_NAME, "MQ Dead Letter Queue *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_LISTENER_STATE_STORE_ADAPTER, "State Store Adapter *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_UNDELIVERED_MESSAGE_RULE_CLASS, "Undelivered Message Rule Class *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_SECONDS_WAIT_FOR_MSG, "Seconds wait for MQ message *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_FLOWS_PER_COMMIT, "Flows per commit *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_AFFECT_CHILDREN, "Affect Children *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_ADMINISTERED_OBJECT_CLASS, "Listener Class *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_STARTUP_RULE_CLASS, "Startup Rule Class *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_TRANSFORMER, "Transformer Class *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, "Description *");

        // Following is commented-out, as listener objects don't have any children...
        // addNLSName( MQeCharacteristicLabels.MQE_FIELD_LABEL_CHILDREN, "Listener Children" );

        addNLSName((new String()).valueOf(MQeClientConnectionAdminMsg.Action_InquireAll), "Inquire");
        addNLSName((new String()).valueOf(MQeClientConnectionAdminMsg.Action_Update), "Update");
        addNLSName((new String()).valueOf(MQeClientConnectionAdminMsg.Action_Start), "Start");
        addNLSName((new String()).valueOf(MQeClientConnectionAdminMsg.Action_Stop), "Stop");
        addNLSName((new String()).valueOf(MQeClientConnectionAdminMsg.Action_Create), "Create");
        addNLSName((new String()).valueOf(MQeClientConnectionAdminMsg.Action_Delete), "Delete");
        addNLSName("cancel", "Cancel");
    }

    protected String[][] getUpdateFields() {
        String[][] result = new String[][] 
            {   
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_LISTENER_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_DEAD_LETTER_Q_NAME, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_LISTENER_STATE_STORE_ADAPTER, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_UNDELIVERED_MESSAGE_RULE_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_SECONDS_WAIT_FOR_MSG, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_FLOWS_PER_COMMIT, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_ADMINISTERED_OBJECT_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_STARTUP_RULE_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_TRANSFORMER, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, "O"},
            };

        return result;
    }

    protected String[][] getInquireAllFields() {
        String[][] results = new String[][] 
            {   
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_LISTENER_NAME, "M"},
            };

        return results;
    }

    protected String[][] getStartFields() {
        String[][] results = 
            new String[][] 
            {   
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_LISTENER_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_AFFECT_CHILDREN, "M"},
            };

        return results;
    }

    protected String[][] getStopFields() {
        String[][] results = 
            new String[][] 
            {   
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_LISTENER_NAME, "M"},
            };

        return results;
    }

    protected String[][] getCreateFields() {
        String[][] results =
            new String[][] 
            {   
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_LISTENER_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_DEAD_LETTER_Q_NAME, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_LISTENER_STATE_STORE_ADAPTER, "O"}, 
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_UNDELIVERED_MESSAGE_RULE_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_SECONDS_WAIT_FOR_MSG, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_FLOWS_PER_COMMIT, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_ADMINISTERED_OBJECT_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_STARTUP_RULE_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_TRANSFORMER, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, "O"},
            };

        return results;
    }

    protected String[][] getDeleteFields() {
        String[][] results = new String[][] 
            {   
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_CLIENT_CONNECTION_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_LISTENER_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_AFFECT_CHILDREN, "M"},
            };

        return results;
    }

    /**
     * Returns a string that provides information about the current frame.
     * This is displayed in the south panel of the main admin gui when a frame is selected.
     * @return String documenting the current frame.
     */
    public String getMessageHelp() {
        return "MQ XmitQ Listeners transfer messages from MQSeries Transmission Queues to MQe Queues.";
    }
}
