/*------------------------------------------------------------------------------*/

/*                    MQSeries Everyplace for Multiplatforms                    */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/*                                                                              */

/*------------------------------------------------------------------------------*/ 
package examples.mqbridge.administration.console;


import examples.administration.console.*;
import com.ibm.mqe.*;
import com.ibm.mqe.mqbridge.*;
import examples.awt.*;
import java.awt.*; 


/**
 * Provides an example of how you might administer an MQ-bridge object
 * known as an 'MQ queue manager proxy'.
 * This class provides an extra button on the west panel.
 * A set of action-buttons are provided in the east panel also.
 */
public class AdminMQQMgrProxy extends AdminFrame {

    public        static short    version[] = { 2, 0, 0, 10 }; 

    /**
     * Default constructor
     */
    public AdminMQQMgrProxy() {
        super("MQ Bridge Administration");
    }

    /**
     * Main constructor.
     *
     * @param msg An admin message to contain the parameters for the action. If it already 
     *        contains any parameters then these are taken as defaults
     * @param action The action to be performed
     * @param adminModel The admin model which will send the message.
     * 
     */
    public AdminMQQMgrProxy(MQeAdminMsg msg, int action, AdminModel adminModel) throws Exception {
        super(msg, action, adminModel);
    }

    /**
     * AdminQueueManager constructor
     */
    public AdminMQQMgrProxy(String title) throws Exception {
        super(title);
    }

    /**
     * Add any aliases related to this resource
     */
    public void addAlias() throws Exception {
        MQe.alias("MQeMQQMgrProxyAdminMsgGUI",
            "examples.mqbridge.administration.console.AdminMQQMgrProxy");
    }

    /**
     * Return an actions panel
     */
    public Panel getActionsPanel(AwtEvent eventHandler) {
        String[][][] actions = new String[][][]
            { { { "B", "Inquire"}
                },     // 0
                { { "B", "Update"}
                },      // 1
                { { "B", "Start"}
                },       // 2
                { { "B", "Stop"}
                },        // 3
                { { "B", "Create"}
                },      // 4 
                { { "B", "Delete"}
                }       // 5
            };
        // ..Queue actions
        AwtFormat actionF = new AwtFormat(eventHandler, East);

        return actionF.panel(new Panel(), actions);
    }

    /**     
     * Return the name of resource being managed
     * @return java.lang.String
     */
    public String getResourceTitle() {
        return "MQ Queue Manager Proxy";
    }

    /**
     * Process a queue manager action request
     */
    public void resourceAction(Object e, int Where, int Index, String  Choice, boolean State 
    ) throws Exception {
        int act = -1;       // Unknown action

        // Decide on which action the user selected
        switch (Index) {
        case 0:
            act = MQeMQQMgrProxyAdminMsg.Action_InquireAll;
            break;              

        case 1:
            act = MQeMQQMgrProxyAdminMsg.Action_Update;     
            break;

        case 2:
            act = MQeMQQMgrProxyAdminMsg.Action_Start;
            break;

        case 3:
            act = MQeMQQMgrProxyAdminMsg.Action_Stop;
            break;

        case 4:
            act = MQeMQQMgrProxyAdminMsg.Action_Create;
            break;

        case 5:
            act = MQeMQQMgrProxyAdminMsg.Action_Delete;
            break;
        }

        // Display the message in a window	
        activate(new MQeMQQMgrProxyAdminMsg(((AdminBridgeModel) adminModel).bridgeName, ((AdminBridgeModel) adminModel).proxyName, ((AdminBridgeModel) adminModel).affectChildren
            ), act, adminModel 
        );    
    }

    /**
     * Set up the admin message with the action to be performed and the
     * parameters required by the action
     */
    public MQeAdminMsg setupAction(MQeFields parms) throws Exception {
        switch (new Integer(action).intValue()) {
        case MQeMQQMgrProxyAdminMsg.Action_InquireAll:
            // Inquire 
            ((MQeMQQMgrProxyAdminMsg) msg).inquireAll(parms);
            break;

        case MQeMQQMgrProxyAdminMsg.Action_Update:
            // Update
            ((MQeMQQMgrProxyAdminMsg) msg).update(parms);
            break;

        case MQeMQQMgrProxyAdminMsg.Action_Start:
            // Start
            ((MQeMQQMgrProxyAdminMsg) msg).start(parms);
            break;

        case MQeMQQMgrProxyAdminMsg.Action_Stop:
            // Stop
            ((MQeMQQMgrProxyAdminMsg) msg).stop(parms);
            break;

        case MQeMQQMgrProxyAdminMsg.Action_Create:
            // Create
            ((MQeMQQMgrProxyAdminMsg) msg).create(parms);
            break;

        case MQeMQQMgrProxyAdminMsg.Action_Delete:
            // Delete
            ((MQeMQQMgrProxyAdminMsg) msg).delete(parms);
            break;
        }
        return (MQeAdminMsg) msg;
    }

    /**
     * Configure the set of actions
     */
    protected void setupActions() {
        super.setupActions();

        addAction(new String().valueOf(MQeMQQMgrProxyAdminMsg.Action_Update),
            new String[][] {    
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_HOST_NAME, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_ADMINISTERED_OBJECT_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_STARTUP_RULE_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, "O"},
            } 
        );

        addAction(new String().valueOf(MQeMQQMgrProxyAdminMsg.Action_InquireAll),  
            new String[][] {    
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
            } 
        );
        addAction(new String().valueOf(MQeMQQMgrProxyAdminMsg.Action_Start),   
            new String[][] {    
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_AFFECT_CHILDREN, "M"},
            } 
        );
        addAction(new String().valueOf(MQeMQQMgrProxyAdminMsg.Action_Stop),    
            new String[][] {    
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
            } 
        );
        addAction(new String().valueOf(MQeMQQMgrProxyAdminMsg.Action_Create),  
            new String[][] {    
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_HOST_NAME, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_ADMINISTERED_OBJECT_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_STARTUP_RULE_CLASS, "O"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, "O"},
            } 
        );
        addAction(new String().valueOf(MQeMQQMgrProxyAdminMsg.Action_Delete),  
            new String[][] {    
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "M"},
                { MQeCharacteristicLabels.MQE_FIELD_LABEL_AFFECT_CHILDREN, "M"},
            }
        );
    }

    /**
     * Setup the valid set of characteristics
     * - the sequence is important as this is the sequence that the fields
     *   will displayed
     */
    protected void setupFields() {
        super.setupFields();

        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_HOST_NAME, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_ADMINISTERED_OBJECT_CLASS, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_STARTUP_RULE_CLASS, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_RUN_STATE, "TF", null);
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_CHILDREN, "C", null);  // A list field
        addCharacteristic(MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, "TF", null);
    }

    /**
     * Set up text labels.
     */
    protected void setupNLS() {
        super.setupNLS();

        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_BRIDGE_NAME, "MQ Bridge Name *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_MQ_Q_MGR_PROXY_NAME, "MQ QMgr Name (=proxy name)");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_HOST_NAME, "IP address/Hostname of MQ QMgr");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_RUN_STATE, "Run State");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_CHILDREN, "Client Connection Children");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_AFFECT_CHILDREN, "Affect Children *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_ADMINISTERED_OBJECT_CLASS, "MQ Queue Manager Proxy Class *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_STARTUP_RULE_CLASS, "Startup Rule Class *");
        addNLSName(MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, "Description *");

        addNLSName("cancel", "Cancel");

        addNLSName((new String()).valueOf(MQeMQQMgrProxyAdminMsg.Action_InquireAll), "Inquire");
        addNLSName((new String()).valueOf(MQeMQQMgrProxyAdminMsg.Action_Update), "Update");
        addNLSName((new String()).valueOf(MQeMQQMgrProxyAdminMsg.Action_Start), "Start");
        addNLSName((new String()).valueOf(MQeMQQMgrProxyAdminMsg.Action_Stop), "Stop");
        addNLSName((new String()).valueOf(MQeMQQMgrProxyAdminMsg.Action_Create), "Create");
        addNLSName((new String()).valueOf(MQeMQQMgrProxyAdminMsg.Action_Delete), "Delete");
    }

    /**
     * Returns a string that provides information about the current frame.
     * This is displayed in the south panel of the main admin gui when a frame is selected.
     * @return String documenting the current frame.
     */
    public String getMessageHelp() {
        return "MQ Queue Manager Proxies define references to MQSeries Queue Managers.";
    }
}
