// Version 1.2 mqe_java/source/examples/mqbridge/administration/programming/AdminHelperBridgeQueue.java, MQeExamples, la200, la200-L030324.1

/*------------------------------------------------------------------------------*
 *                    WebSphere MQ Everyplace for Multiplatforms                *
 *                                                                              *
 * Licensed Materials - Property of IBM                                         *
 *                                                                              *
 * 5765-E63                                                                     *
 *                                                                              *
 * (C) Copyright IBM Corp. 2002                                                 *
 *------------------------------------------------------------------------------*/
package examples.mqbridge.administration.programming;


import java.util.*;
import com.ibm.mqe.*;
import com.ibm.mqe.mqbridge.*;
import com.ibm.mqe.administration.*;


/**
 * Actions which manipulate bridge queues.
 */
public class AdminHelperBridgeQueue {
    public static short[] version = { 2, 0, 0, 10 }; 	
    Reporter reporter;
    AdminMessageDispatcher dispatcher;
	
    /**
     * Builds an object able to administer bridge queue resource.
     * 
     * @param reporter The object to which debug and error information is sent.
     * @param dispatcher An object used to dispatch administration messages.
     */
    public AdminHelperBridgeQueue(Reporter reporter, AdminMessageDispatcher dispatcher
    ) {
        this.reporter = reporter;
        this.dispatcher = dispatcher;
    }
		
    /**
     * Finds out if the bridge queue exists already
     */
    public boolean doesExist(String mqeQueueManagerName, String queueQMgrName, String queueQueueName 
    ) throws Exception {
			
        boolean doesExist = true;					  	
        AdminHelperQueueManager	helper = new AdminHelperQueueManager(reporter, dispatcher);

        doesExist = helper.doesQueueExist(mqeQueueManagerName, queueQMgrName, queueQueueName);				
        return doesExist;							  	
    }
	
    public void create(String mqeQueueManagerName, String queueQMgrName, String queueQName, String bridgeName, String proxyName, String clientConnectionName
    ) throws Exception {
					   	
        try {
            MQeMQBridgeQueueAdminMsg msg = new MQeMQBridgeQueueAdminMsg(bridgeName, proxyName, clientConnectionName, 3
                ); 
            
            // Create a fields object in which we can pre-initialise the object...
            MQeFields params = new MQeFields();

            params.putByte(MQeQueueAdminMsg.Queue_Mode, MQeQueueAdminMsg.Queue_Synchronous);
	
            // Set the command in the admin msg to "create".
            msg.create(params);
	
            // Set the name of the queue into the admin msg...
            msg.setName(queueQMgrName, queueQName);
	
            System.out.println("Built the admin message.");

            // Send the message.
            MQeFields results = dispatcher.sendWaitMessage(reporter, mqeQueueManagerName, msg);
	        
        } catch (Exception e) {
            reporter.error(e);
        }
    }
}
