// Version 1.3 mqe_java/source/examples/mqbridge/administration/programming/AdminHelperMQ.java, MQeExamples, la200, la200-L030324.1

/*------------------------------------------------------------------------------*
 *                    WebSphere MQ Everyplace for Multiplatforms                *
 *                                                                              *
 * Licensed Materials - Property of IBM                                         *
 *                                                                              *
 * 5765-E63                                                                     *
 *                                                                              *
 * (C) Copyright IBM Corp. 2002                                                 *
 *------------------------------------------------------------------------------*/

package examples.mqbridge.administration.programming;


import examples.administration.commandline.*;
import examples.mqbridge.administration.commandline.*;

import com.ibm.mqe.*;
import com.ibm.mqe.mqbridge.MQeMQBridgeQueueAdminMsg;
import com.ibm.mqe.administration.*;
import java.util.*;


/**
 * Demonstrates how to programmatically manipulate MQe bridge resources.
 */
public class AdminHelperMQ implements AdminHelperMQInterface {
    public static short[] version = { 2, 0, 0, 10 }; 	
    Reporter reporter;
    AdminMessageDispatcher dispatcher;
	
    public AdminHelperMQ() {
        super();
    }
	
    /**
     * Activates the MQ helper 
     * 
     * @param reporter The object to which debug and error information is sent.
     * @param dispatcher An object used to dispatch administration messages.
     */
    public void activate(Reporter reporter, AdminMessageDispatcher dispatcher
    ) {
        this.reporter = reporter;
        this.dispatcher = dispatcher;
    } 
	 
    /** 
     * The default port on which Websphere MQ server listens for incoming message traffic.  
     */
    public static final int DEFAULT_MQ_LISTENING_PORT = 1414;
	
    /**
     * Connects the default MQ queue manager on this machine to the MQe queue manager which 
     * is currently running.
     */
    public void connectMQeAndMQ() {
        String results;

        try {
			
            MQeQueueManager mqeQueueManager = MQeQueueManager.getDefaultQueueManager();
			
            MQAgent mqAgent = new MQAgent(reporter);
            String mqeQueueManagerName = mqeQueueManager.getName();
            String bridgeName = mqeQueueManagerName + ".MQBridgeV100";			
            String clientConnectionName = "FOR." + mqeQueueManagerName;
            String transmitQueueListenerName = "TO." + mqeQueueManagerName;
            String mqSyncQueueName = mqeQueueManagerName + ".SYNC.QUEUE";
            String mqResourceDescription = "auto-created on " + MQeClock.getReadableTimeStamp();
            String mqDeadLetterQueueName = "SYSTEM.DEAD.LETTER.QUEUE";
            String testQueueName = mqeQueueManagerName + ".TEST.QUEUE";

            connectMQeToMQQueueManager(mqeQueueManagerName, bridgeName, clientConnectionName, transmitQueueListenerName, mqSyncQueueName, mqAgent, mqResourceDescription, mqDeadLetterQueueName, testQueueName
            );								  
        } catch (Exception e) {
            reporter.exception(e);
        }									 
    }
	
    /**
     * Connects the specified WMQe queue manager to the specified WMQ queue manager.
     * 
     * @param mqeQueueManagerName The name of the MQe queue manager to be connected
     * @param bridgeName The name of the bridge resource to create.
     * @param clientConnectionName The name of the client connection to create.
     * @param mqSyncQueueName The name of the sync queue to create on the Websphere MQ queue manager
     * in which Websphere MQ Everyplace will store state information. 
     * @param mqeQMgr A reference to an active Websphere MQ Everyplace queue manager
     * @param mqAgent A reference to a connected agent capable of manipulating the Websphere MQ system.
     * @param mqResourceDescription The 
     */
    public void connectMQeToMQQueueManager(String mqeQueueManagerName, String bridgeName, String clientConnectionName, String transmitQueueListenerName, String mqSyncQueueName, MQAgent mqAgent, String resourceDescription, String mqDeadLetterQueueName, String testQueueName												   									   														   
    ) throws Exception {
												
        boolean isOk = true;
	
        reporter.comment("... started to connect MQe queue manager to the default MQ queue manager");												   														   	
								
        // get the name of the MQ queue manager.	
        String mqQueueManagerName = mqAgent.getDefaultMQQMgrName();

        if (mqQueueManagerName == null) {
            reporter.error("failed to get the name of the default MQSeries queue manager!");				
            isOk = false;
        } else {
            reporter.comment("starting an attempt to connect MQe queue manager " + mqeQueueManagerName + " to MQ queue manager " + mqQueueManagerName);
				
            isOk = makeSureBridgeExists(mqeQueueManagerName, bridgeName, resourceDescription 
                    );
            if (isOk) {
                isOk = makeSureMQProxyExists(mqeQueueManagerName, bridgeName, resourceDescription, mqAgent 
                        );
                if (isOk) {
                    isOk = makeSureClientConnectionExists(mqeQueueManagerName, bridgeName, clientConnectionName, resourceDescription, mqSyncQueueName, mqAgent 
                            );
                    if (isOk) {
                        isOk = makeSureTransmitQueueListenerExists(mqeQueueManagerName, bridgeName, clientConnectionName, transmitQueueListenerName, resourceDescription, mqDeadLetterQueueName, mqAgent  
                                );
                        if (isOk) {
                            isOk = defineConnectionFromMQeToMQ(mqeQueueManagerName, mqAgent.getMQQueueManagerName());
                            if (isOk) {
                                isOk = makeSureTestQueueExists(mqeQueueManagerName, bridgeName, clientConnectionName, testQueueName, resourceDescription, mqAgent
                                        );
                                if (isOk) {
                                    // Send a test message to the test queue
                                    AdminHelperTestMessage helper = new AdminHelperTestMessage(reporter, dispatcher);

                                    isOk = helper.send(mqAgent.getMQQueueManagerName(), testQueueName, "This is a test message" 
                                            );
                                    if (isOk) {
                                        // Get a test message from the test queue
                                        MQeMsgObject msg = helper.get(mqAgent.getMQQueueManagerName(), testQueueName);

                                        if (msg != null) {										
                                            reporter.comment("all work done ok.");
                                        }
                                    }
                                }															  
                            }
                        }														  																  
                    } 					
                }
            } 		
        } 
    }	
	
    public boolean defineConnectionFromMQeToMQ(String mqeQueueManagerName, String mqQueueManagerName
    ) {
        boolean isOk = true;
		
        try {		

            AdminHelperConnection helper = new AdminHelperConnection(reporter, dispatcher);
			
            boolean doesExist = helper.doesExist(mqeQueueManagerName, mqQueueManagerName); 

            if (doesExist) {
                reporter.comment("Connection to MQ queue manager already exists.");
            } else {
                reporter.comment("Connection to MQ queue manager does not exist. Need to create it.");
                helper.createConnectionToMQQMgr(mqeQueueManagerName, mqQueueManagerName);
                reporter.comment("Created connection to MQ queue manager ok.");
            }
        } catch (Exception e) {
            reporter.exception(e);
            isOk = false;
        }        
		
        return isOk;
    }													
	
    /**
     * Make sure a test queue exists on MQe and MQSeries
     * 
     * @return boolean 
     */
    public boolean makeSureTestQueueExists(String mqeQueueManagerName, String bridgeName, String clientConnectionName, String testQueueName, String resourceDescription, MQAgent mqAgent											
    ) {
        boolean isOk = true;

        try {														
            String mqQueueManagerName = mqAgent.getMQQueueManagerName();														

            reporter.comment("Creating the test queue " + testQueueName + " on " + mqQueueManagerName);
		
            AdminHelperBridgeQueue helper = new AdminHelperBridgeQueue(reporter, dispatcher);
		
            boolean doesExist = helper.doesExist(mqeQueueManagerName, mqQueueManagerName, testQueueName 
                );

            if (doesExist) {
                reporter.comment("bridge queue " + testQueueName + " already exists");
            } else {
                reporter.comment("bridge queue does not exist. Needs creating.");
                helper.create(mqeQueueManagerName, mqQueueManagerName, testQueueName, bridgeName, mqQueueManagerName, clientConnectionName
                );
                reporter.comment("bridge queue created ok.");							 
            }												 
			
        } catch (Exception e) {
            reporter.error(e);
            isOk = false;
        }
		
        if (isOk) {
            reporter.comment("The bridge queue on MQe exists. Create the MQ queue definition now.");
            try {
                isOk = mqAgent.createMQQueueLocal(testQueueName, resourceDescription, MQAgent.NOT_TRANSMIT_QUEUE, MQAgent.REPLACE, MQAgent.PERSIST 
                        );
            } catch (Exception e) {
                reporter.exception(e);
                isOk = false;
            }												 
        }											 
		
        return isOk;
    }					
	
    /**
     * Method makeSureTransmitQueueListenerExists.
     * 
     * @return boolean true if the transmission queue listener exists now, false otherwise.
     */
    private boolean makeSureTransmitQueueListenerExists(
        String mqeQueueManagerName,
        String bridgeName,
        String clientConnectionName,
        String transmitQueueListenerName,
        String resourceDescription,
        String mqDeadLetterQueueName,
        MQAgent mqAgent) throws Exception {
		
        boolean isOk = true;
		
        String mqQMgrProxyName = mqAgent.getMQQueueManagerName();
		
        reporter.comment("Attempting to make sure that a transmit queue listener " + transmitQueueListenerName + " exists."
            + "\n\tmqe queue manager name=" + mqeQueueManagerName
            + "\n\tbridge name=" + bridgeName
            + "\n\tproxy name=" + mqQMgrProxyName
            + "\n\tclient connection name=" + clientConnectionName
            + "\n\ttransmit queue listener name=" + transmitQueueListenerName
            + "\n"
        );
		
        AdminHelperMQTransmitQueueListener helper = new AdminHelperMQTransmitQueueListener(reporter, dispatcher);
		
        boolean doesExist = helper.doesExist(mqeQueueManagerName, bridgeName, mqQMgrProxyName, clientConnectionName, transmitQueueListenerName 
            );

        if (doesExist) {
            reporter.comment("Found that transmit queue listener " + transmitQueueListenerName + " exists already.");
        } else {
            reporter.comment("Transmit queue listener " + transmitQueueListenerName + " does not exist. Creating it.");
            try {
                helper.create(mqeQueueManagerName, bridgeName, mqQMgrProxyName, clientConnectionName, transmitQueueListenerName, resourceDescription, mqDeadLetterQueueName
                );
            } catch (Exception e) {
                reporter.exception(e);
                isOk = false;
            }
        }
        if (isOk) {
            reporter.comment("The MQe transmit queue listener exists. Making sure the MQ transmit queue exists too.");
            isOk = mqAgent.createMQQueueLocal(transmitQueueListenerName, resourceDescription, MQAgent.TRANSMIT_QUEUE, MQAgent.REPLACE, MQAgent.PERSIST
                    );
            if (isOk) {
                reporter.comment("MQ Transmit queue " + transmitQueueListenerName + " exists");
                reporter.comment("Continuing to create a remote queue manager alias to route traffic to the MQe queue manager");
                isOk = mqAgent.createMQQueueRemote(mqeQueueManagerName, resourceDescription, transmitQueueListenerName, MQAgent.REPLACE, MQAgent.PERSIST, MQAgent.NO_REMOTE_Q_NAME_SET, mqeQueueManagerName
                        );
                if (isOk) {
                    reporter.comment("Created remote queue manager alias for MQe queue manager " + mqeQueueManagerName + " ok.");
                }												  
            }									         
        }
		
        if (isOk) {
            reporter.comment("Transmit queue + listener objects exist, checking to see if it is running already.");
            boolean isRunning = helper.isRunning(mqeQueueManagerName, bridgeName, mqQMgrProxyName, clientConnectionName, transmitQueueListenerName
                );

            if (!isRunning) {												 
                reporter.comment("Tansmit queue listener is not running. Starting it.");	
                helper.start(mqeQueueManagerName, bridgeName, mqQMgrProxyName, clientConnectionName, transmitQueueListenerName, false  
                );
            }
        }
        return isOk;
    }
	
    /**
     * Makes sure a proxy object exists, creating it if necessary.
     * @return boolean true if the proxy exists, false otherwise.
     */
    private boolean makeSureMQProxyExists(
        String mqeQueueManagerName,
        String bridgeName,
        String resourceDescription,
        MQAgent mqAgent) throws Exception {
			
        boolean isOk = true;
		
        AdminHelperMQQMgrProxy helper = new AdminHelperMQQMgrProxy(reporter, dispatcher);
        String mqQMgrProxyName = mqAgent.getMQQueueManagerName();
        boolean doesExist = helper.doesExist(mqeQueueManagerName, bridgeName, mqQMgrProxyName);

        if (doesExist) {
            reporter.comment("Found that proxy " + mqQMgrProxyName + " exists already.");
        } else {
            reporter.comment("Proxy " + mqQMgrProxyName + " does not exist. Creating it.");
            try {
                helper.create(mqeQueueManagerName, bridgeName, mqQMgrProxyName, resourceDescription, mqAgent.getMQQueueManagerHostName() 
                );
            } catch (Exception e) {
                reporter.exception(e);
                isOk = false;
            }
        }
		
        if (isOk) {
            reporter.comment("Proxy objects exist, checking to see if it is running already.");
            boolean isRunning = helper.isRunning(mqeQueueManagerName, bridgeName, mqQMgrProxyName
                );

            if (!isRunning) {												 
                reporter.comment("Proxy is not running. Starting it.");	
                helper.start(mqeQueueManagerName, bridgeName, mqQMgrProxyName, false  
                );
            }
        }		
        return isOk;
    }
	
    /**
     * Makes sure a proxy object exists, creating it if necessary, and creating 
     * necessary resources on MQSeries as needed.
     * 
     * @return boolean true if the proxy exists, false otherwise.
     */
    private boolean makeSureClientConnectionExists(
        String mqeQueueManagerName,
        String bridgeName,
        String clientConnectionName,
        String resourceDescription,
        String syncQueueName,
        MQAgent mqAgent) throws Exception {
			
        boolean isOk = true;
		
        AdminHelperMQClientConnection helper = new AdminHelperMQClientConnection(reporter, dispatcher);
        String mqQMgrProxyName = mqAgent.getMQQueueManagerName();
        boolean doesExist = helper.doesExist(mqeQueueManagerName, bridgeName, mqQMgrProxyName, clientConnectionName);

        if (doesExist) {
            reporter.comment("Found that proxy " + mqQMgrProxyName + " exists already on the MQe queue manager.");
        } else {
            reporter.comment("Proxy " + mqQMgrProxyName + " does not exist on the MQe queue manaer. Creating it.");
            try {
                int portListeningOn = mqAgent.getPortMQListensOn();

                helper.create(mqeQueueManagerName, bridgeName, mqQMgrProxyName, clientConnectionName, resourceDescription, syncQueueName, portListeningOn
                );
            } catch (Exception e) {
                reporter.exception(e);
                isOk = false;
            }
        }
		
        if (isOk) {
            reporter.comment("The proxy exists. Creating the MQ sync queue.");
			
            isOk = mqAgent.createMQQueueLocal(syncQueueName, resourceDescription, MQAgent.NOT_TRANSMIT_QUEUE, MQAgent.REPLACE, MQAgent.PERSIST 
                    );
            if (isOk) {
                reporter.comment("The sync queue on MQSeries exists too.");
            }
        }		
		
        if (isOk) {
            reporter.comment("The client connection needs a server connection channel to connect to.");
            reporter.comment("Creating a server connection channel on the MQ system");
            isOk = mqAgent.createMQServerConnectionChannel(clientConnectionName, resourceDescription, MQAgent.REPLACE 
                    );
            if (isOk) {
                reporter.comment("Created the server connection channel ok.");
            } else {
                reporter.comment("Failed to create a server connection channel.");
            }														  
        }
		
        if (isOk) {
            reporter.comment("client connection object exists, checking to see if it is running already.");
            boolean isRunning = helper.isRunning(mqeQueueManagerName, bridgeName, mqQMgrProxyName, clientConnectionName
                );

            if (!isRunning) {												 
                reporter.comment("Client connection is not running. Starting it.");	
                helper.start(mqeQueueManagerName, bridgeName, mqQMgrProxyName, clientConnectionName, false  
                );
            } else {
                reporter.comment("Client connection was already running.");
            }
        }		        
		
        return isOk;
    }
	
    /**
     * Make sure a bridge exists on the specified queue manager.
     * 
     * <p>If it doesn't already exist, then create one with default values.
     * 
     * @param mqeQueueManagerName The name of the MQe queue manager on which the bridge should exist.
     * @param bridgeName The name of the bridge to check for, and create if its' not there already.
     * @param mqResourceDescription The text description of the bridge resource to create.
     * @return boolean true if the bridge does exist. False if there is an error.
     */
    public boolean makeSureBridgeExists(String mqeQueueManagerName, String bridgeName, String mqResourceDescription 
    ) throws Exception {
        boolean isOk = true;
        AdminHelperBridge helper = new AdminHelperBridge(reporter, dispatcher);
        boolean doesExist = helper.doesExist(mqeQueueManagerName, bridgeName);

        if (doesExist) {
            reporter.comment("Found that the bridge " + bridgeName + " already exists on MQe queue manager "
                + mqeQueueManagerName + " so there is no need to create one.");
        } else {
            reporter.comment("Bridge " + bridgeName + " does not exist on MQe queue manager " + mqeQueueManagerName + " so attempting to create one.");
            try {
                helper.create(mqeQueueManagerName, bridgeName, mqResourceDescription);
            } catch (Exception e) {
                reporter.error(e);
                isOk = false;
            }
        }
		
        if (isOk) {
            reporter.comment("Bridge object exists, checking to see if it is running already.");
            boolean isRunning = helper.isRunning(mqeQueueManagerName, bridgeName 
                );

            if (!isRunning) {												 
                reporter.comment("bridge is not running. Starting it.");	
                helper.start(mqeQueueManagerName, bridgeName, false  
                );
            } else {
                reporter.comment("bridge was already running.");
            }
        }			
        return isOk;
    }		
	
    /**
     * Work through the entire bridge tree to display what bridge resources are available.
     */
    public void reportBridgeTree(String mqeQueueManagerName) {
        AdminHelperBridges bridgesHelper = new AdminHelperBridges(reporter, dispatcher);
        AdminHelperBridge  bridgeHelper = new AdminHelperBridge(reporter, dispatcher);
        AdminHelperMQQMgrProxy proxyHelper = new AdminHelperMQQMgrProxy(reporter, dispatcher);
        AdminHelperMQClientConnection clientConnectionHelper = new  AdminHelperMQClientConnection(reporter, dispatcher);

        try {
            StringBuffer results = new StringBuffer();

            results.append(mqeQueueManagerName);
            results.append("\n");
				
            Hashtable bridgeList = bridgesHelper.listChildren(mqeQueueManagerName);
            Enumeration bridgeListWalker = bridgeList.elements();

            while (bridgeListWalker.hasMoreElements()) {
                String bridgeName = (String) bridgeListWalker.nextElement();

                results.append("\t");
                results.append(bridgeName);
                results.append("\n");
				
                Hashtable proxyList = bridgeHelper.listChildren(mqeQueueManagerName, bridgeName 
                    );
                Enumeration proxyListWalker = proxyList.elements();

                while (proxyListWalker.hasMoreElements()) {
                    String proxyName = (String) proxyListWalker.nextElement();

                    results.append("\t\t");
                    results.append(proxyName);
                    results.append("\n");
					
                    Hashtable conList = proxyHelper.listChildren(mqeQueueManagerName, bridgeName, proxyName
                        );
					
                    Enumeration conListWalker = conList.elements();

                    while (conListWalker.hasMoreElements()) {
                        String conName = (String) conListWalker.nextElement();

                        results.append("\t\t\t");
                        results.append(conName);
                        results.append("\n");
					
                        Hashtable listenerList = clientConnectionHelper.listChildren(mqeQueueManagerName, bridgeName, proxyName, conName
                            );
                        Enumeration listenerListWalker = listenerList.elements();

                        while (listenerListWalker.hasMoreElements()) {
                            String listenerName = (String) listenerListWalker.nextElement();

                            results.append("\t\t\t\t");
                            results.append(listenerName);
                            results.append("\n");
                        }
                    }
                }
            }
            reporter.comment(results.toString());																																																					
        } catch (Exception e) {
            reporter.exception(e);
        }
    }
}

