// Version 1.2 mqe_java/source/examples/mqbridge/administration/programming/AdminHelperMQClientConnection.java, MQeExamples, la200, la200-L030324.1

/*------------------------------------------------------------------------------*
 *                    WebSphere MQ Everyplace for Multiplatforms                *
 *                                                                              *
 * Licensed Materials - Property of IBM                                         *
 *                                                                              *
 * 5765-E63                                                                     *
 *                                                                              *
 * (C) Copyright IBM Corp. 2002                                                 *
 *------------------------------------------------------------------------------*/

package examples.mqbridge.administration.programming;


import java.util.*;
import com.ibm.mqe.*;
import com.ibm.mqe.mqbridge.*;


/**
 * Provides code to manipulate an MQ bridge client connection resource.
 */
public class AdminHelperMQClientConnection {
    public static short[] version = { 2, 0, 0, 10 }; 	
    Reporter reporter;
    AdminMessageDispatcher dispatcher;
	
    /**
     * Builds an object able to administer a resources.
     * 
     * @param reporter The object to which debug and error information is sent.
     * @param dispatcher An object used to dispatch administration messages.
     */
    public AdminHelperMQClientConnection(Reporter reporter, AdminMessageDispatcher dispatcher
    ) {
        this.reporter = reporter;
        this.dispatcher = dispatcher;
    }
	
    /**
     * Queries all facets of the client connection object
     */
    public MQeFields queryAll(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName, String clientConnectionName
    ) throws Exception {
        MQeClientConnectionAdminMsg msg = new MQeClientConnectionAdminMsg();

        msg.setName(bridgeName, mqQMgrProxyName, clientConnectionName);
        msg.inquireAll(new MQeFields());
        MQeFields queryResults = dispatcher.sendWaitMessage(reporter, targetMQeQueueManagerName, msg);

        return queryResults;												  													  	
    }	
	
    /**
     * Starts the resource running.
     */
    public void start(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName, String clientConnectionName, boolean affectsChildren
    ) throws Exception {
        MQeClientConnectionAdminMsg msg = new MQeClientConnectionAdminMsg();

        msg.setName(bridgeName, mqQMgrProxyName, clientConnectionName);
        msg.start(affectsChildren);
        MQeFields results = dispatcher.sendWaitMessage(reporter, targetMQeQueueManagerName, msg);										
    }	
	
    /**
     * Provides a list of child resources controlled by the specified resource.
     * <p>Each member of the list returned is an MQ transmit queue listener resource name.
     */
    public Hashtable listChildren(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName, String clientConnectionName
    ) throws Exception {
        Hashtable results = new Hashtable();
        MQeFields queryResults = queryAll(targetMQeQueueManagerName, bridgeName, mqQMgrProxyName, clientConnectionName 
            );		
        MQeFields[] children = queryResults.getFieldsArray(MQeCharacteristicLabels.MQE_FIELD_LABEL_CHILDREN);

        for (int childIndex = 0; childIndex < children.length; childIndex += 1) {	
            String resourceName = children[childIndex].getUnicode(MQeCharacteristicLabels.MQE_FIELD_LABEL_CHILD);

            results.put(resourceName, resourceName);	
        }
        return results;											     	
    }
	
    /**
     * Stops the resource from running.
     */
    public void stop(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName, String clientConnectionName
    ) throws Exception {
        MQeClientConnectionAdminMsg msg = new MQeClientConnectionAdminMsg();

        msg.setName(bridgeName, mqQMgrProxyName, clientConnectionName);
        msg.stop();
        MQeFields results = dispatcher.sendWaitMessage(reporter, targetMQeQueueManagerName, msg);										
    }			
	
    /**
     * Checks to see if the proxy object is running or not.
     */
    public boolean isRunning(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName, String clientConnectionName
    ) throws Exception {
        boolean isRunning = false;
        MQeFields queryResults = queryAll(targetMQeQueueManagerName, bridgeName, mqQMgrProxyName, clientConnectionName
            );
        int runState = queryResults.getInt(MQeCharacteristicLabels.MQE_FIELD_LABEL_RUN_STATE);

        if (runState == MQeRunState.RUN_STATE_RUNNING) {
            isRunning = true;
        } else {
            isRunning = false;
        }		   												
        return isRunning;												  	
    }
		
    /**
     * Checks to see if the resource exists of not.
     */
    public boolean doesExist(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName, String clientConnectionName
    ) throws Exception {
        boolean doesExist = false;

        AdminHelperMQQMgrProxy proxyHelper = new AdminHelperMQQMgrProxy(reporter, dispatcher);										  	
        Hashtable childList = proxyHelper.listChildren(targetMQeQueueManagerName, bridgeName, mqQMgrProxyName);

        if (childList.get(clientConnectionName) == null) {
            doesExist = false;
        } else {
            doesExist = true;
        }			

        return doesExist;																
    }	
	
    /**
     * A simplified method creating a client connection with the most commonly used parameters.
     */
    public void create(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName, String clientConnectionName, String resourceDescription, String syncQueueName, int portMQListeningOn
    ) throws Exception {
        reporter.debug("Building the simple admin message to create an client connection resource "
            + " queue manager effected=" + targetMQeQueueManagerName
            + " bridge name=" + bridgeName
            + " queue manager proxy name=" + mqQMgrProxyName
            + " client connection name=" + clientConnectionName
            + " resource description=" + resourceDescription
            + " sync queue name=" + syncQueueName
            + " port MQ listens on=" + portMQListeningOn
        );
            	        
        MQeClientConnectionAdminMsg msg = new MQeClientConnectionAdminMsg();

        // Create a fields object in which we can pre-initialise the bridge...
        MQeFields params = new MQeFields();

        // When we create the bridge, set the default transformer.
        params.putUnicode(MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, resourceDescription);
        params.putUnicode(MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_NAME, syncQueueName);		
        params.putInt(MQeCharacteristicLabels.MQE_FIELD_LABEL_PORT, portMQListeningOn);	
       
        // Set the command in the admin msg to "create".
        msg.create(params);
        
        // Set the name of the bridge we wish to create into the admin msg...
        msg.setName(bridgeName, mqQMgrProxyName, clientConnectionName);

        reporter.debug("Built the admin message.");

        // Send the message.
        MQeFields results = dispatcher.sendWaitMessage(reporter, targetMQeQueueManagerName, msg);	  							  			  	 
    }
						  			  						  			  	
    /**
     * Creates a client connection resource.
     * 
     * @param targetMQeQueueManagerName The name of the queue manager which will process the admin message.
     * @param bridgeName The name of the bridge which will own the client connection
     * @param mqQMgrProxyName The name of the MQ queue manager proxy resource for which the new client connection
     * resource will be a child.
     * @param clientConnectionName The name of the client connection resource to create.
     * @param resourceDescription See {@link MQeCharacteristicLabels#MQE_FIELD_LABEL_DESCRIPTION}
     * @param userID See {@link MQeCharacteristicLabels#MQE_FIELD_LABEL_USER_ID}
     * @param password See {@link MQeCharacteristicLabels#MQE_FIELD_LABEL_PASSWORD}
     * @param sendExitClassName See {@link MQeCharacteristicLabels#MQE_FIELD_LABEL_SEND_EXIT} 
     * @param receiveExitClassName See {@link MQeCharacteristicLabels#MQE_FIELD_LABEL_RECEIVE_EXIT}
     * @param securityExitClassName See {@link MQeCharacteristicLabels#MQE_FIELD_LABEL_SECURITY_EXIT}
     * @param syncQueueName See {@link MQeCharacteristicLabels#MQE_FIELD_LABEL_SYNC_Q_NAME}
     * @param syncQueuePurgerRulesClassName See {@link MQeCharacteristicLabels#MQE_FIELD_LABEL_SYNC_Q_PURGER_RULES_CLASS}
     * @param ccsid See {@link MQeCharacteristicLabels#MQE_FIELD_LABEL_CCSID}
     * @param portMQListeningOn See {@link MQeCharacteristicLabels#MQE_FIELD_LABEL_PORT}
     * @param maxConnectionIdleTimeMinutes See {@link MQeCharacteristicLabels#MQE_FIELD_LABEL_MAX_CONNECTION_IDLE_TIME}
     * @param syncQueuePurgeInterval See {@link MQeCharacteristicLabels#MQE_FIELD_LABEL_SYNC_Q_PURGE_INTERVAL}
     * @throws Exception If something goes wrong.
     */
    public void create(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName, String clientConnectionName, String resourceDescription, String userID, String password, String sendExitClassName, String receiveExitClassName, String securityExitClassName, String syncQueueName, String syncQueuePurgerRulesClassName, int ccsid, int portMQListeningOn, int maxConnectionIdleTimeMinutes, int syncQueuePurgeInterval
    ) throws Exception {
        reporter.debug("Building the admin message to create an client connection resource "
            + " queue manager effected=" + targetMQeQueueManagerName
            + " bridge name=" + bridgeName
            + " queue manager proxy name=" + mqQMgrProxyName
            + " client connection name=" + clientConnectionName
            + " resource description=" + resourceDescription
            + " user id=" + userID
            + " password=" + password
            + " send exit class name=" + sendExitClassName
            + " receive exit class name=" + receiveExitClassName
            + " security exit class name=" + securityExitClassName
            + " sync queue name=" + syncQueueName
            + " sync queue purger rules class name=" + syncQueuePurgerRulesClassName
            + " ccsid=" + ccsid
            + " port MQ listens on=" + portMQListeningOn
            + " max connection idle time=" + maxConnectionIdleTimeMinutes + " minutes"
            + " sync queue purge interval=" + syncQueuePurgeInterval + " minutes"
        );
            	        
        MQeClientConnectionAdminMsg msg = new MQeClientConnectionAdminMsg();

        // Create a fields object in which we can pre-initialise the bridge...
        MQeFields params = new MQeFields();

        // When we create the bridge, set the default transformer.
        params.putUnicode(MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, resourceDescription);
        params.putUnicode(MQeCharacteristicLabels.MQE_FIELD_LABEL_USER_ID, userID);		
        params.putUnicode(MQeCharacteristicLabels.MQE_FIELD_LABEL_PASSWORD, password);
        params.putUnicode(MQeCharacteristicLabels.MQE_FIELD_LABEL_SEND_EXIT, sendExitClassName);
        params.putUnicode(MQeCharacteristicLabels.MQE_FIELD_LABEL_RECEIVE_EXIT, receiveExitClassName);		
        params.putUnicode(MQeCharacteristicLabels.MQE_FIELD_LABEL_SECURITY_EXIT, securityExitClassName);		
        params.putUnicode(MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_NAME, syncQueueName);		
        params.putUnicode(MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_PURGER_RULES_CLASS, syncQueuePurgerRulesClassName);

        params.putInt(MQeCharacteristicLabels.MQE_FIELD_LABEL_CCSID, ccsid);		
        params.putInt(MQeCharacteristicLabels.MQE_FIELD_LABEL_PORT, portMQListeningOn);	
        params.putInt(MQeCharacteristicLabels.MQE_FIELD_LABEL_MAX_CONNECTION_IDLE_TIME, maxConnectionIdleTimeMinutes);
        params.putInt(MQeCharacteristicLabels.MQE_FIELD_LABEL_SYNC_Q_PURGE_INTERVAL, syncQueuePurgeInterval);
       
        // Set the command in the admin msg to "create".
        msg.create(params);
        
        // Set the name of the bridge we wish to create into the admin msg...
        msg.setName(bridgeName, mqQMgrProxyName, clientConnectionName);

        reporter.debug("Built the admin message.");

        // Send the message.
        MQeFields results = dispatcher.sendWaitMessage(reporter, targetMQeQueueManagerName, msg);	  									 	
    }					  									 	
	
    /**
     * Deletes a resource from a specified queue manager.
     */
    public void delete(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName, String clientConnectionName
    ) throws Exception {

        reporter.debug("Building the admin message to delete a client connection resource "
            + "queue manager effected=" + targetMQeQueueManagerName
            + "bridge name=" + bridgeName
            + " queue manager proxy name=" + mqQMgrProxyName
            + " client connection name=" + clientConnectionName
        );
        MQeClientConnectionAdminMsg msg = new MQeClientConnectionAdminMsg();
        MQeFields params = new MQeFields();

        msg.delete(params);
        msg.setName(bridgeName, mqQMgrProxyName, clientConnectionName);
        reporter.debug("built the admin message.");
        MQeFields results = dispatcher.sendWaitMessage(reporter, targetMQeQueueManagerName, msg);	  									 																		
    }	
}
