// Version 1.2 mqe_java/source/examples/mqbridge/administration/programming/AdminHelperMQQMgrProxy.java, MQeExamples, la200, la200-L030324.1

/*------------------------------------------------------------------------------*
 *                    WebSphere MQ Everyplace for Multiplatforms                *
 *                                                                              *
 * Licensed Materials - Property of IBM                                         *
 *                                                                              *
 * 5765-E63                                                                     *
 *                                                                              *
 * (C) Copyright IBM Corp. 2002                                                 *
 *------------------------------------------------------------------------------*/

package examples.mqbridge.administration.programming;


import java.util.*;
import com.ibm.mqe.*;
import com.ibm.mqe.mqbridge.*;


/**
 * Provides utility methods to manipulate an MQ queue manager proxy resource.
 */
public class AdminHelperMQQMgrProxy {
    public static short[] version = { 2, 0, 0, 10 }; 	
    Reporter reporter;
    AdminMessageDispatcher dispatcher;
	
    /**
     * Builds an object able to administer procxy resources.
     * 
     * @param reporter The object to which debug and error information is sent.
     * @param dispatcher An object used to dispatch administration messages.
     */
    public AdminHelperMQQMgrProxy(Reporter reporter, AdminMessageDispatcher dispatcher
    ) {
        this.reporter = reporter;
        this.dispatcher = dispatcher;
    }

    /**
     * Queries all facets of the proxy object
     */
    public MQeFields queryAll(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName
    ) throws Exception {
        MQeMQQMgrProxyAdminMsg msg = new MQeMQQMgrProxyAdminMsg();

        msg.setName(bridgeName, mqQMgrProxyName);
        msg.inquireAll(new MQeFields());
        MQeFields queryResults = dispatcher.sendWaitMessage(reporter, targetMQeQueueManagerName, msg);

        return queryResults;												  													  	
    }	
	
    /**
     * Starts the proxy object running.
     */
    public void start(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName, boolean affectsChildren
    ) throws Exception {
        MQeMQQMgrProxyAdminMsg msg = new MQeMQQMgrProxyAdminMsg();

        msg.setName(bridgeName, mqQMgrProxyName);
        msg.start(affectsChildren);
        MQeFields results = dispatcher.sendWaitMessage(reporter, targetMQeQueueManagerName, msg);										
    }	
	
    /**
     * Provides a list of child resources controlled by the specified resource.
     * <p>Each member of the list returned is an MQ client connection resource name.
     */
    public Hashtable listChildren(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName
    ) throws Exception {
        Hashtable results = new Hashtable();
        MQeFields queryResults = queryAll(targetMQeQueueManagerName, bridgeName, mqQMgrProxyName);		
        MQeFields[] children = queryResults.getFieldsArray(MQeCharacteristicLabels.MQE_FIELD_LABEL_CHILDREN);

        for (int childIndex = 0; childIndex < children.length; childIndex += 1) {	
            String resourceName = children[childIndex].getUnicode(MQeCharacteristicLabels.MQE_FIELD_LABEL_CHILD);

            results.put(resourceName, resourceName);	
        }
        return results;											     	
    }
	
    /**
     * Stops the proxy object from running.
     */
    public void stop(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName
    ) throws Exception {
        MQeMQQMgrProxyAdminMsg msg = new MQeMQQMgrProxyAdminMsg();

        msg.setName(bridgeName, mqQMgrProxyName);
        msg.stop();
        MQeFields results = dispatcher.sendWaitMessage(reporter, targetMQeQueueManagerName, msg);										
    }			
	
    /**
     * Checks to see if the proxy object is running or not.
     */
    public boolean isRunning(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName
    ) throws Exception {
        boolean isRunning = false;
        MQeFields queryResults = queryAll(targetMQeQueueManagerName, bridgeName, mqQMgrProxyName
            );
        int runState = queryResults.getInt(MQeCharacteristicLabels.MQE_FIELD_LABEL_RUN_STATE);

        if (runState == MQeRunState.RUN_STATE_RUNNING) {
            isRunning = true;
        } else {
            isRunning = false;
        }		   												
        return isRunning;												  	
    }
		
    /**
     * Checks to see if the proxy exists of not.
     */
    public boolean doesExist(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName
    ) throws Exception {
        boolean doesExist = false;

        AdminHelperBridge bridgeHelper = new AdminHelperBridge(reporter, dispatcher);												  	
        Hashtable childList = bridgeHelper.listChildren(targetMQeQueueManagerName, bridgeName);

        if (childList.get(mqQMgrProxyName) == null) {
            doesExist = false;
        } else {
            doesExist = true;
        }		

        return doesExist;																
    }	
	
    /**
     * Creates a proxy resource on the specified queue manager.
     * 
     */
    public void create(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName, String resourceDescription, String hostName
    ) throws Exception {
        reporter.debug("Building the admin message to create an MQ queue manager proxy "
            + " queue manager effected=" + targetMQeQueueManagerName
            + " bridge name=" + bridgeName
            + " queue manager proxy name=" + mqQMgrProxyName
            + " resource descrition=" + resourceDescription
            + " host name=" + hostName
        );
            	        
        MQeMQQMgrProxyAdminMsg msg = new MQeMQQMgrProxyAdminMsg();

        // Create a fields object in which we can pre-initialise the bridge...
        MQeFields params = new MQeFields();

        // When we create the bridge, set the default transformer.
        params.putUnicode(MQeCharacteristicLabels.MQE_FIELD_LABEL_HOST_NAME, hostName);
        params.putUnicode(MQeCharacteristicLabels.MQE_FIELD_LABEL_DESCRIPTION, resourceDescription);
       
        // Set the command in the admin msg to "create".
        msg.create(params);
        
        // Set the name of the bridge we wish to create into the admin msg...
        msg.setName(bridgeName, mqQMgrProxyName);

        reporter.debug("Built the admin message.");

        // Send the message.
        MQeFields results = dispatcher.sendWaitMessage(reporter, targetMQeQueueManagerName, msg);	  									 	
    }					  									 	
	
    /**
     * Deletes a proxy resource from a specified queue manager.
     */
    public void delete(String targetMQeQueueManagerName, String bridgeName, String mqQMgrProxyName
    ) throws Exception {

        reporter.debug("Building the admin message to delete a proxy resource "
            + "queue manager effected=" + targetMQeQueueManagerName
            + "bridge name=" + bridgeName
            + " queue manager proxy name=" + mqQMgrProxyName
        );
        MQeMQQMgrProxyAdminMsg msg = new MQeMQQMgrProxyAdminMsg();
        MQeFields params = new MQeFields();

        msg.delete(params);
        msg.setName(bridgeName, mqQMgrProxyName);
        reporter.debug("built the admin message.");
        MQeFields results = dispatcher.sendWaitMessage(reporter, targetMQeQueueManagerName, msg);	  									 																		
    }		
}
