// Version 1.3 mqe_java/source/examples/mqbridge/administration/programming/AdminHelperTestMessage.java, MQeExamples, la200, la200-L030324.1

/*------------------------------------------------------------------------------*
 *                    WebSphere MQ Everyplace for Multiplatforms                *
 *                                                                              *
 * Licensed Materials - Property of IBM                                         *
 *                                                                              *
 * 5765-E63                                                                     *
 *                                                                              *
 * (C) Copyright IBM Corp. 2002                                                 *
 *------------------------------------------------------------------------------*/
package examples.mqbridge.administration.programming;


import java.io.*;
import java.util.*;
import com.ibm.mqe.*;
import com.ibm.mqe.mqbridge.*;
import com.ibm.mqe.mqemqmessage.*;


/**
 * Puts and gets a test message.
 */
public class AdminHelperTestMessage {
    public static short[] version = { 2, 0, 0, 10 }; 	
    Reporter reporter;
    AdminMessageDispatcher dispatcher;
	
    /**
     * Builds an object able to administer bridge resources.
     * 
     * @param reporter The object to which debug and error information is sent.
     * @param dispatcher An object used to dispatch administration messages.
     */
    public AdminHelperTestMessage(Reporter reporter, AdminMessageDispatcher dispatcher
    ) {
        this.reporter = reporter;
        this.dispatcher = dispatcher;
    }
	
    /**
     * Send a test message to the specified queue.
     */
    public boolean send(String targetQueueManager, String targetQueue, String text) {
        boolean isOk = true;

        reporter.enter("Sending a test message to queue " + targetQueue + " on queue manager " + targetQueueManager);
        try {
            // In this example, we send an MQeMQMsgObject so that the default transformer passes our
            // test text string into the MQSeries message un-changed.
            MQeMQMsgObject msg = new MQeMQMsgObject();
            ByteArrayOutputStream temp = new ByteArrayOutputStream();
            PrintStream tempWriter = new PrintStream(temp);

            tempWriter.println(text);					
            byte[] messageAsByteArray = temp.toByteArray();

            msg.setData(messageAsByteArray);
            isOk = dispatcher.send(reporter, targetQueueManager, targetQueue, msg);
        } catch (Exception e) {
            reporter.error(e);
            isOk = false;
        } finally {
            reporter.exit("Finished the attempt to send a test message.");
        }
        return isOk;
    }
	
    /**
     * Gets a message from a specified queue.
     * 
     * @param targetQueueManager
     * @param targetQueue
     * @return MQeMsgObject Null if there was a problem, or no message existed, or the message got if that worked.
     */
    public MQeMsgObject get(String targetQueueManager, String targetQueue) {
        MQeMsgObject msg = null;

        try {
            reporter.enter("Getting the top message from queue " + targetQueue + " on queue manager " + targetQueueManager);
            msg = dispatcher.get(reporter, targetQueueManager, targetQueue);
        } catch (Exception e) {
            reporter.error(e);
        } finally { 
            reporter.exit("finished attempt to get the message.");
        }
        return msg;		
    }	
}
