// Version 1.2 mqe_java/source/examples/mqbridge/administration/programming/AwtAdminHelperConnectToMQ.java, MQeExamples, la200, la200-L030324.1

/*------------------------------------------------------------------------------*
 *                    WebSphere MQ Everyplace for Multiplatforms                *
 *                                                                              *
 * Licensed Materials - Property of IBM                                         *
 *                                                                              *
 * 5765-E63                                                                     *
 *                                                                              *
 * (C) Copyright IBM Corp. 2002                                                 *
 *------------------------------------------------------------------------------*/
package examples.mqbridge.administration.programming;


import com.ibm.mqe.*;
import com.ibm.mq.*;
import examples.awt.*;
import java.awt.*;
import java.io.ByteArrayOutputStream;
import java.io.PrintStream;


/**
 * An Awt which uses other admin helper classes to connect 
 * the current MQe queue manager with the default MQ queue manager
 * on this system, providing all software pre-requisites are installed.
 */
public class AwtAdminHelperConnectToMQ {

    public static short[] version = { 2, 0, 0, 10 }; 
    public static final void ConnectToMQ() {

        boolean isOk = true;
		
        isOk = awtQuestion("Continue?", "This action will cause the following list of operations to\n" +
                    "be performed. Please review the list, and use the OK button\n" +
                    "to continue, or the Cancel button to cancel these operations.\n" +
                    "\n" +
                    "attempt to do the following:\n" +
                    "- Make sure a bridge object exists, creating one as required.\n" +
                    "- Query properties from the default Websphere MQ queue manager.\n" +
                    "- Attempt to connect that queue manager to the currently running\n" +
                    "  Websphere MQ Everyplace queue manager\n" +
                    "- Make sure a proxy object representing the default WMQ\n" +
                    "  queue manager exists, creating one if necessary.\n" +
                    "- Make sure an WMQe client connection exists, and that a \n" +
                    "  corresponding WMQ server connection channel exists also,\n" +
                    "  creating these resources if necessary.\n" +
                    "- Make sure a 'sync queue' exists on the WMQ queue manager.\n" +
                    "- Make sure a transmit queue on WMQ exists, and create\n" +
                    "  if necessary\n" +
                    "- Make sure a matching MQ transmit queue listener exists in the\n" +
                    "  configuration of the current WMQe queue manager, creating one\n" +
                    "  if necessary.\n" +
                    "- Make sure all the bridge resources are started.\n" +
                    "- Make sure a test queue on the WMQ queue manager exists, creating\n" +
                    "  one if necessary.\n" +
                    "- Make sure a matching WMQe bridge queue exists which refers to that\n" +
                    "  test queue.\n"
                );

        if (isOk) {						  	
			
            isOk = checkMQAvailable();
            if (isOk) {			
                isOk = checkPCFAvailable();
                if (isOk) {
                    AdminHelperReporter reporter = new AdminHelperReporter();

                    try {
                        // Dynamically load the class and invoke using an interface in case
                        // the PCF or MQ classes are not available.
                        // If they are not available and we statically referenced classes which 
                        // rely on those classes, then we would fail to load this class too.
                        // Using dynamic loading avoids this issue.
                        AdminHelperMQInterface helper = (AdminHelperMQInterface)	 
                            MQe.loadObject("examples.mqbridge.administration.programming.AdminHelperMQ");
                        AdminHelperDispatcher dispatcher = new AdminHelperDispatcher(MQeQueueManager.getDefaultQueueManager());

                        helper.activate(reporter, dispatcher);
                        helper.connectMQeAndMQ();
                        awtMessage("Ok", "Operations worked ok.\n\n\nBreakdown of the work performed follows:\n" + reporter.getCollectedOutput());																	
                    } catch (Exception e) {
                        ByteArrayOutputStream collectedByteStream = new ByteArrayOutputStream();
                        PrintStream collectedPrintStream = new PrintStream(collectedByteStream);					

                        e.printStackTrace(collectedPrintStream);
                        String text = "Error:\n"
                            + collectedByteStream.toString()
                            + "\n\n\n"
                            + "Information leading to the error follows:\n"
                            + reporter.getCollectedOutput();;
									
                        awtMessage("Error", text);
                    }
                }
            }	
        }
    }
	
    /**
     * To check whether the Programmable
     * @return boolean
     */	
    private static boolean checkPCFAvailable() {
        boolean isAvailable = false;

        try {		
            // Load a PCF class.
            MQe.loadClass("com.ibm.mq.pcf.PCFAgent", true);
            isAvailable = true;
        } catch (Exception e) {
            isAvailable = false;
            awtMessage("PCF not available", "Failure:\n"
                + "Class com.ibm.mqe.pcf.PCFAgent cannot be loaded.\n"
                + "This class is required if a Websphere MQ Everyplace queue manager\n" 
                + "is going to be configured programmatically.\n"
                + "It is supplied in the 'MS0B: MQSeries Java classes for PCF' supportpac.\n"
                + "This is a free download from the Websphere MQ download site at\n"
                + "http://www.ibm.com/software/ts/mqseries/txppacs\n"
                + "Download and install it, and put the com.ibm.mq.pcf.jar file on your\n" +
                "CLASSPATH environment variable.\n"
                + "Then re-try this operation.\n"
            );
        }
        return isAvailable;
    }
	
    private static boolean checkMQAvailable() {
        boolean isAvailable = false;

        try {
            // Load a PCF class.
            MQe.loadClass("com.ibm.mq.MQException", true);
			
            isAvailable = true;
        } catch (Exception e) {
            isAvailable = false;
            awtMessage("MQ java classes not found", "Failure:\n"
                + "Class com.ibm.mq.MQException cannot be loaded.\n"
                + "This is one of the MQSeries classes required if a\n"
                + "Websphere MQ Everyplace queue manager\n" 
                + "is going to be configured programmatically.\n"
                + "It is supplied in the base Websphere MQ product, though may\n"
                + "not have been installed yet.\n"
                + "It is also available as a free download from the Websphere MQ download\n"
                + "site at http://www.ibm.com/software/ts/mqseries/txppacs\n"
                + "Install it, following the installation instructions in\n"
                + "the accompanying documentation.\n"
                + "Then re-try this operation.\n"
            );
        }
        return isAvailable;
    }		
	
    /**
     * Put a simple text message up on the screen in a separate small window.
     * 
     * @param title Title of the window.
     * @param text The text inside the window to be displayed.
     */
    private static void awtMessage(String title, String text) {
        AwtDialog errorMsg = new AwtDialog(title, AwtDialog.Show_OK, new String[][][] { { { "AP", text }
                    }
                }
            );
    }
	
    /**
     * Puts up a dialog window with OK and Cancel buttons.
     * 
     * @param title
     * @param text
     * @return boolean True if the user hit ok, false if they hit cancel.
     */
    private static boolean awtQuestion(String title, String text) {
        boolean answer = false;
        AwtDialog questionDialog = new AwtDialog(title, AwtDialog.Show_OK_Cancel, new String[][][] { { {"AP", text}
                    }
                } 
            );

        if (questionDialog.getActionIndex(questionDialog.South) == questionDialog.Button_OK) {
            // User hit ok, rather than cancel.
            answer = true;
        }																
        return answer;
    }
}
