// Version 1.2 mqe_java/source/examples/mqbridge/administration/programming/PrimedTriggerListener.java, MQeExamples, la200, la200-L030324.1

/*------------------------------------------------------------------------------*
 *                    WebSphere MQ Everyplace for Multiplatforms                *
 *                                                                              *
 * Licensed Materials - Property of IBM                                         *
 *                                                                              *
 * 5765-E63                                                                     *
 *                                                                              *
 * (C) Copyright IBM Corp. 2002                                                 *
 *------------------------------------------------------------------------------*/
package examples.mqbridge.administration.programming;


import com.ibm.mqe.*;


/**
 * A message listener to which MQe can send notifications that messages have arrived.
 * <p>Use the listener by "priming" it with the prime() method.
 * <p>Then wait for messages using the waitForTrigger() method.
 * <P>If messages arrive on the MQe queue between the primt() and waitForTrigger() there
 * is no timing window in which message events can be lost.
 * (or at least that's the plan anyway).
 */
public class PrimedTriggerListener implements MQeMessageListenerInterface {
    volatile boolean fired = false;

    public static short[] version = { 2, 0, 0, 10 }; 
    	
    /**
     * Sets the listener up to capture trigger events after the listener has been primed.
     * <p>If events occur after the prime method is called, the waitForTrigger() method will
     * return immediately.
     */
    public void prime() {
        synchronized (this) {
            fired = false;
        }
    }
	
    /**
     * Entry point called by MQe when a message arrives on the queue.
     */
    public void messageArrived(MQeMessageEvent msgEvent) {
        synchronized (this) {
            fired = true;
            this.notifyAll();
        }
    }
	
    /**
     * Waits for a trigger, or times out if trigger doesn't arrive in a specified time.
     * <p>If the event has already triggered, since the prime() method was used, then 
     * the waitForTrigger will return immediately.
     * @param millisecsToWait The number of milliseconds to wait for a trigger.
     * After this time, a false is returned.
     * @return true if the event triggered. False otherwise.
     */
    public boolean waitForTrigger(long millisecsToWait) {
        boolean triggered = false;

        synchronized (this) {
            if (fired) {
                // The primed listener has already fired.
                triggered = true;
            } else {
                try {
                    this.wait(millisecsToWait);
                } catch (InterruptedException iex) {
                    MQeTrace.trace(
                        null,
                        (short) 0,
                        MQeTrace.GROUP_WARNING | MQeTrace.GROUP_EXCEPTION,
                        "Got an interrupted exception! Exception=#",
                        iex);
                }
            }
            if (fired) {
                triggered = true;
            }
        }
        return triggered;
    }
}

