/*------------------------------------------------------------------------------*/

/*                    MQSeries Everyplace for Multiplatforms                    */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/*                                                                              */

/*------------------------------------------------------------------------------*/
package examples.mqbridge.rules;


import examples.rules.*;


/******************************************************************************
 *
 * This is an example rules class which dictates what action an MQ XmitQ Listener 
 * should take if a message is undelivered. In this situation,
 * the permit() method will be loaded and queried dynamically.
 *
 * This example class either returns any undelivered message to the MQ
 * series Dead Letter Queue or (if the message has MQRO_DISCARD set)
 * discards it.
 *
 ******************************************************************************/
public class UndeliveredMQMessageToDLQRule extends com.ibm.mqe.MQeRule {

    public        static short    version[] = { 2, 0, 0, 10 }; 

    /*************************************************************************
     *
     * To find out what behaviour should occur in the listener when 
     * a message cannot be delivered, but may benefit from a retry
     * at a later date.
     *
     * <p>The listener has a number of conditions under which a message
     * cannot be delivered to the MQe network.</p>
     *
     * <p>Whenever an MQ Message cannot be put to MQe a rule class like this
     * can decide on which course of action to take.</p>
     *
     * @param failureCodes int[] with the following two elements:
     * <ul>
     * <li>failureCodes[0] - Failure Reason. The reason why the message cannot 
     * currently be delivered to the target queue. This is one of the 
     * MQe.Except_* reasons from the list above.
     * <li>failureCodes[1] - Consecutive Failures. The number of failures to 
     * deliver that have occurred in a row. Each time this rule class has
     * been consulted to find out the required behaviour. Each time the
     * rule class has specified a timeout. This parameter holds the number of 
     * times the loop has occurred.
     * This parameter may be useful if you wish to specify a different
     * timeout for each retry, which increases with the number of retries
     * attempted, until a certain point at which the listener stops...etc.
     * </ul>
     *
     * @param targetNames String[] with the following two elements:
     * <ul>
     * <li>targetNames[0] = The name of the MQe QMgr that rejected the put.
     * <li>targetNames[1] = The name of the MQe queue that rejected the put.
     * </ul>
     *
     * @param failedMQeMessage A reference to the MQe Message that could
     * not be delivered to the target MQe queue manager. This may be null
     * if the MQe message had not yet been transformed (if an error occurred
     * during the transformation, for example).
     *
     * @return The required behaviour. An Integer.
     * The behaviour the listener should exibit following the undelivered
     * message condition can be specified by returning a different value
     * from this rule class as follows:
     * <dl>
     * <li>MQeUndeliveredMessageRule.STOP_LISTENER
     * <p>The listener should stop as a result of this message being 
     * undeliverable.
     * <li>MQeUndeliveredMessageRule.USE_MQ_REPORT_OPTIONS
     * <p>The message should either be discarded or moved to the MQ dead
     * letter queue, depending on the value of the original 'report' field
     * of the original MQ Message.
     * <li>>0 
     * <p>The number of seconds which the listener should wait before
     * retrying the MQ-to-MQe transfer operation.
     * </ul>
     * <p>If a value not in the list above is specified, or if the rule
     * throws an exception, then the listener will assume the STOP_LISTENER
     * result was returned.
     *
     * @exception Fails if the rule has some problem with it's logic. 
     * This will have the same result as returning the STOP_LISTENER value
     * in terms of how the listener will react.
     *
     *************************************************************************/
    public Object permit(Object failureCodesO          // int[]
        , Object targetNames            // String[]
        , Object failedMQeMessageO      // MQeMsgObject or null
    ) throws Exception {

        // Whatever the reason was we'll tell the listener to use the
        // report options.
        return new Integer(
                com.ibm.mqe.mqbridge.MQeUndeliveredMessageRule.USE_MQ_REPORT_OPTIONS);

    }
}
