/*------------------------------------------------------------------------------*/
/*                    WebSphere MQ Everyplace for Multiplatforms                */
/*                                                                              */
/* Licensed Materials - Property of IBM                                         */
/*                                                                              */
/* 5765-E63                                                                     */
/*                                                                              */
/* (C) Copyright IBM Corp. 2002                                                 */
/*------------------------------------------------------------------------------*/
/********************************************************************************
*                                                                              *
* Native methods for NT Authentication (see Native.JavaNT class)               *
* Sun JDK Version using JNI                                                    *
*                                                                              *
*******************************************************************************/

#include <jni.h>
#include <windows.h>

#include "examples_nativecode_JavaNT.h"

/*******************************************************************************
* Logon a userid and return the Logon Handle                                   *
*******************************************************************************/
JNIEXPORT jint JNICALL Java_examples_nativecode_JavaNT_logonUser
  (JNIEnv *env, jobject obj, jstring jDomain,
                 jstring jUserID,
                 jstring jPassword,
                 jint    jLogonType)
   {
   HANDLE token;

   /* convert the Java string arguments to C strings                          */
   LPSTR domain = (LPSTR)(*env)->GetStringUTFChars(env, jDomain, NULL);
   LPSTR userid = (LPSTR)(*env)->GetStringUTFChars(env, jUserID, NULL);
   LPSTR passwd = (LPSTR)(*env)->GetStringUTFChars(env, jPassword, NULL);

   if (!LogonUser(userid,                     /* Logon this user              */
                  domain,                     /* to this domain               */
                  passwd,                     /* with this password           */
                  jLogonType,                 /* and this logon type          */
                  LOGON32_PROVIDER_DEFAULT,   /* generic                      */
                  &token))                    /* returned logon token         */
      token = 0;                              /* not logged on                */
   /* free up the C strings we allocated                                      */
   (*env)->ReleaseStringUTFChars(env, jDomain, domain);
   (*env)->ReleaseStringUTFChars(env, jUserID, userid);
   (*env)->ReleaseStringUTFChars(env, jPassword, passwd);
   return (jint)token;                        /* return the logon token       */
   }

/*******************************************************************************
* Logoff (Revert) and close the Logon Handle                                   *
*******************************************************************************/
JNIEXPORT void JNICALL Java_examples_nativecode_JavaNT_logoffUser
  (JNIEnv *env, jobject obj, jint jLogonHandle)
   {
   RevertToSelf();                            /* stop the impersonation       */
   CloseHandle((HANDLE)jLogonHandle);         /* finish with the token        */
   }

/*******************************************************************************
* Impersonate a Logged on User                                                 *
*******************************************************************************/
JNIEXPORT jboolean JNICALL Java_examples_nativecode_JavaNT_impersonateLoggedOnUser
  (JNIEnv *env, jobject obj, jint jLogonHandle)
   {
   return (jboolean)ImpersonateLoggedOnUser((HANDLE)jLogonHandle); /* impersonate */
   }

/*******************************************************************************
* RegisterEventSource                                                          *
*******************************************************************************/
JNIEXPORT jint JNICALL Java_examples_nativecode_JavaNT_registerEventSource
  (JNIEnv *env, jobject obj, jstring jSourceName)
   {
   HANDLE handle;
   LPSTR  source;

   if (jSourceName == NULL)
      handle = RegisterEventSource(NULL, "JavaNT");
   else
      {
      source = (LPSTR)(*env)->GetStringUTFChars(env, jSourceName, NULL);
      handle = RegisterEventSource(NULL, source); /* register the source      */
      (*env)->ReleaseStringUTFChars(env, jSourceName, source);
      }
   return (jint)handle;
   }

/*******************************************************************************
* AddEventSource                                                               *
*                                                                              *
* Note: The parameter jEventType is passed to this function as a jint type     *
* which represents a signed 32 bit number, however, the NT ReportEvent API     *
* expects the event type to be an unsigned 16 bit type. Users of this code     *
* should be aware that using an event type outside the range 0 - 65535 may     *
* produce unexpected results.                                                  *
*                                                                              *
* In this example, the variable jEventType has been type cast to a 16 bit type *
* to remove compiler warnings.                                                 *
/******************************************************************************/
JNIEXPORT jboolean JNICALL Java_examples_nativecode_JavaNT_reportEvent
  (JNIEnv *env, jobject obj, jint    jHandle,
                             jint    jEventType,
                             jint    jEventID,
                             jstring jData,
                             jbyteArray jBytes)
   {
   LPSTR stringdata;
   jbyte *jb;
   WORD   numInserts;
   DWORD  numBytes;
   LPCSTR insertPtr;
   LPVOID bytePtr;
   BOOL rc;

   if (jData == NULL)                         /* any string insert ?          */
      {
      numInserts = 0;                         /* no strings                   */
      insertPtr  = NULL;                      /* clear pointer                */
      }
   else                                       /* ... yes                      */
      {
      stringdata = (LPSTR)(*env)->GetStringUTFChars(env, jData, NULL);
      numInserts = 1;                         /* one insert                   */
      insertPtr  = stringdata;                /* point to it                  */
      }
   if (jBytes == NULL)                        /* any byte data                */
      {
      numBytes = 0;                           /* no data                      */
      bytePtr  = NULL;                        /* clear pointer                */
      }
   else                                       /* ... yes                      */
      {
      jb = (*env)->GetByteArrayElements(env, jBytes, NULL);
      numBytes = (*env)->GetArrayLength(env, jBytes); /* number of bytes      */
      bytePtr  = jb;                          /* address of bytes             */
      }
   rc = ReportEvent((HANDLE)jHandle,          /*                              */
                     (WORD)jEventType,        /* event type to log            */
                     0,                       /* event category               */
                     jEventID,                /* event identifier             */
                     NULL,                    /* user security identifier     */
                     numInserts,              /* number of strings            */
                     numBytes,                /* size of binary data, in bytes*/
                     &insertPtr,              /* string pointer               */
                     bytePtr);                /* address binary data          */

   if (jData != NULL)                         /* if we allocated a C string   */
      (*env)->ReleaseStringUTFChars(env, jData,stringdata); /* we must free it*/
   if (jBytes != NULL)                        /* if we allocated a C array    */
      (*env)->ReleaseByteArrayElements(env, jBytes, jb, JNI_ABORT); /* free it*/

   return (jboolean)rc;
   }

/*******************************************************************************
* DeregisterEventSource                                                        *
*******************************************************************************/
JNIEXPORT jboolean JNICALL Java_examples_nativecode_JavaNT_deregisterEventSource
  (JNIEnv *env, jobject obj, jint jHandle)
   {
   return (jboolean)DeregisterEventSource((HANDLE)jHandle); /* finished wih log*/
   }


