package examples.nativecode;


// Version mqe_java/source/examples/nativecode/JavaUnix.java, MQeExamples, la200, la200-L030324.1 1.5
/*------------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 2002                                                 */

/*------------------------------------------------------------------------------*/

/*
 * JavaUnix  - Native method interface.
 **/
public class JavaUnix {   /* start Unix Native class                                                */
    public static short  version[] = { 2, 0, 0, 10 }; 

    /*----------------------------------------------------------------------------*/
    
    /* Event log types                                                            */
    
    /*----------------------------------------------------------------------------*/
    public final static int  EVENTLOG_SUCCESS_TYPE = 0x0006; // LOG_INFO
    public final static int  EVENTLOG_ERROR_TYPE = 0x0003; // LOG_ERR
    public final static int  EVENTLOG_WARNING_TYPE = 0x0004; // LOG_WARNING

    protected boolean registeredEventSource = false;

    /*
     * Logon a user and return success.
     * @param UserId User ID String
     * @param password  Authentication password
     * @return True for successful logon. False, if unsuccessful.
     **/
    public native boolean     logonUser(String userID,
        String password);

    /*
     * Logoff  user.
     * @return void
     **/
    public native void    logoffUser();

    /*
     * Register an Unix event source.
     * @param sourceName Name of the source to be registered
     * @return void
     **/
    public native void    registerEventSource(String sourceName);

    /*
     * Add an Unix event source.
     * @param sourceName Name of the event source to be added.
     * @return void
     **/
    public native void    addEventSource(String  sourceName);

    /*
     * Report an Unix event.
     * @param  eventType a Byte indicating the type of the event to be reported.
     * @param  eventID An integer value, the eventID
     * @param stringData
     * @param bytes[]
     * @return boolean value
     **/
    public native boolean reportEvent(int     eventType,
        int     eventID,
        Object  stringData,
        byte    bytes[]);

    /*
     * De-register an Unix event source.
     * @return a boolean
     **/
    public native boolean deregisterEventSource();

    /*
     * Load the system library for MQeJavaUnix.
     * @exception java.lang.Exception
     **/
    public JavaUnix() throws Exception {                                           /*                              */
        System.loadLibrary("MQeJavaUnix");
    }                                           /*                              */

    /*
     * Register an Unix event source.
     * @param sourceName Name of the source to be registered.
     * @exception java.lang.Exception
     **/
    public JavaUnix(String SourceName) throws Exception {                                           /*                              */
        System.loadLibrary("MQeJavaUnix");
        if (!registeredEventSource) {          /* registered allready ?        */
            registerEventSource(SourceName);      /* register */
            registeredEventSource = true;
        }
    }                                           /*                              */

    /*
     * Report an Unix event.
     * @param  eventType a Byte indicating the type of the event to be reported.
     * @param  eventID An integer value, the eventID
     * @param stringData
     * @param bytes[]
     * @return boolean value
     **/
    public boolean record(int     eventType,
        int     eventID,
        Object  stringData,
        byte    bytes[]) {                                           /*                              */
        if (registeredEventSource)              /* register allready ?          */
            return (reportEvent(eventType, eventID, stringData, bytes));
        else                                      /* ... no                       */
            return (false);                        /* didn't work                  */
    }                                           /*                              */

    /*
     * De-register an Unix event source.
     * @return void
     */
    public void close() {                                           /*                              */
        if (registeredEventSource)              /* registered ?                 */
            deregisterEventSource();               /* ... yes, release it          */
        registeredEventSource = false;            /* clear registered             */
    }                                           /*                              */

    /*
     * De-register an Unix event source.
     * @return void
     */
    protected void finalize() {                                           /*                              */
        close();                                  /* finish with event log        */
    }                                           /*                              */

}   /* end Unix Native class                                                    */

