
// Version 1.2 mqe_java/source/examples/os4690/OS4690ConfigInfo.java, MQeExamples, la200, la200-L030324.1

/*-----------------------------------------------------------------------------*
 *                    WebSphere MQ Everyplace for Multiplatforms               *
 *                                                                             *
 * Licensed Materials - Property of IBM                                        *
 *                                                                             *
 * 5765-E63                                                                    *
 *                                                                             *
 * (C) Copyright IBM Corp. 2002                                                *
 *-----------------------------------------------------------------------------*/
 
package examples.os4690;


import com.ibm.mqe.*;
import com.ibm.mqe.registry.*;
import com.ibm.mqe.adapters.*;


/**
 * Holds configuration information about the OS4690-resident queue manager centrally so that 
 * the configure, run and unconfigure classes all use the same names for things.
 * 
 * <p>Use the activate method first, then getters.
 */
public class OS4690ConfigInfo {
    public static short[] version = { 2, 0, 0, 10 }; 
	
    /**
     * The name of the queue manager the examples in this package use.
     */
    private String queueManagerName;
	
    /**
     * The name of the base directory that the examples in this package use.
     */	            
    private String baseDirectoryName;
    
    /**
     * The base name of the storage location string which queues use to store their
     * message data. 
     */
    private String storageLocation;
    
    /**
     * The name of the test queue to which a test message is put by programs in this package.
     */	
    private String testQueueLongName;
    
    /**
     * The name of the 8.3 format directory name to which the test queue will store its' messages.
     */
    private String testQueueShortName;

    /**
     * An MQeFields structure which will describe the parameters required to start the WMQe queue manager.
     */
    private MQeFields config = null;
	
    public String getQueueManagerName() {
        return queueManagerName;
    }

    public String getBaseDirectoryName() {
        return baseDirectoryName;
    }

    public String getStorageLocation() {
        return storageLocation;
    }

    public String getTestQueueLongName() {
        return testQueueLongName;
    }

    public String getTestQueueShortName() {
        return testQueueShortName;
    }

    public MQeFields getConfigFields() {
        return config;
    } 
    
    /**
     * Change this flag if your want to gather as much debugging information as possible from the 
     * MQeMappingAdapter
     */
    private static final boolean DEBUG_MAPPING_ADAPTER = false;
    
    public void activate() throws Exception {
        // Using a short queue manager name helps keep a message files' fully
        // qualified name short.
        queueManagerName = "AReallyLongQueueManagerName"; 
        testQueueLongName = "MyTestQueueWithAVeryLongName";
        testQueueShortName = "TQ1";
   		
        String fileSeparator = MQe.fileSeparator();   	
    	
        System.out.println("Using a queue manager name of " + queueManagerName);
        // Set the base directory in which queues will deposit their messages.
        baseDirectoryName = "C:" + fileSeparator + "QM1";
        storageLocation = "com.ibm.mqe.messagestore.MQe4690ShortFilenameMessageStore" + ":com.ibm.mqe.adapters.MQeCaseInsensitiveDiskAdapter" + ":" + baseDirectoryName;
		
        // Create all the configuration information needed to construct the 
        // queue manager in memory.
        config = new MQeFields();
		
        // Construct the queue manager section parameters.
        MQeFields queueManagerSection = new MQeFields();

        queueManagerSection.putAscii(MQeQueueManager.Name, queueManagerName);
        config.putFields(MQeQueueManager.QueueManager, queueManagerSection);

        // Construct the registry section parameters.
        // In this examples, we use a public registry.
        MQeFields registrySection = new MQeFields();

        // Make sure the registry sits on the mapping adapter, then it will only use 8.3 filenames.
        registrySection.putAscii(MQeRegistry.Adapter, "com.ibm.mqe.adapters.MQeMappingAdapter");
        registrySection.putAscii(MQeRegistry.DirName, baseDirectoryName);
        config.putFields("Registry", registrySection);
        
        // Set the system java properties which control the mapping adapter explicitly...
        // So we get our registry configuration information in the exact place we want...
                     
        // Tell the adapter to use the disk fields adapter to store the logical->physical mapping data.
        // Use the prefix of a specific path, and a specific filename.
        System.setProperty(MQeMappingAdapter.PRIVATE_NAME_KEY, "com.ibm.mqe.adapters.MQeDiskFieldsAdapter");
        System.setProperty(MQeMappingAdapter.PRIVATE_NAME_DESC_KEY, baseDirectoryName + fileSeparator + "MAP" + fileSeparator);
        System.setProperty(MQeMappingAdapter.PRIVATE_NAME_TABLE_KEY, "TRANSTBL.MQE");

        // Tell the mapping adapters' delegate adapter to be the disk fields adapter,
        // Get the mapping adpater to always pass a specific path to it, using 8.3 filenames
        // and make sure all filenames are upper case for good measure.   
        System.setProperty(MQeMappingAdapter.DELEGATE_NAME_KEY, "com.ibm.mqe.adapters.MQeDiskFieldsAdapter");
        System.setProperty(MQeMappingAdapter.DELEGATE_NAME_DESC_KEY, baseDirectoryName + fileSeparator + "CFG" + fileSeparator);
        System.setProperty(MQeMappingAdapter.DELEGATE_NAME_PRE_KEY, "");
        System.setProperty(MQeMappingAdapter.DELEGATE_NAME_LEN_KEY, "8");
        System.setProperty(MQeMappingAdapter.DELEGATE_NAME_EXT_KEY, ".MQE");
        System.setProperty(MQeMappingAdapter.DELEGATE_NAME_CASE_KEY, "no");   		
   		
        // Tell the mapping adapter to produce as much debug output as possible.
        if (DEBUG_MAPPING_ADAPTER) {
            System.setProperty(MQeMappingAdapter.DEBUG_KEY, "true");
            System.setProperty(MQeMappingAdapter.VERBOSE_KEY, "true");
        }
   		
    }
}
