// Version 1.3 mqe_java/source/examples/os4690/Run.java, MQeExamples, la200, la200-L030324.1

/*-----------------------------------------------------------------------------*
 *                    WebSphere MQ Everyplace for Multiplatforms               *
 *                                                                             *
 * Licensed Materials - Property of IBM                                        *
 *                                                                             *
 * 5765-E63                                                                    *
 *                                                                             *
 * (C) Copyright IBM Corp. 2002                                                *
 *-----------------------------------------------------------------------------*/
package examples.os4690;


import com.ibm.mqe.*;
import com.ibm.mqe.adapters.*;
import com.ibm.mqe.registry.*;
import com.ibm.mqe.trace.MQeTraceToReadable;
import java.util.*;
import examples.mqbridge.administration.programming.*;


/**
 * Uses the configured queue manager previously defined by the {@link examples.os4690.Configure} program.
 * 
 * <p>A message is put to the test queue, and got from the test queue.
 * 
 * <p>The resultant queue manager can then be unconfigured using the 
 * {@link examples.os4690.UnConfigure} program.
 * 
 * <p>Most solutions separate the configuration of their disk-resident queue managers
 * from the use of those queue managers. The hello world java example does this also.
 */
public class Run {
	
    public static short[] version = { 2, 0, 0, 10 }; 

    /**
     * A definition of my queue manager.
     */
    private MQeQueueManager myQueueManager = null;

    /**
     * How long to wait for the queue manager to close cleanly, before it is closed by force ?
     * <p>Using 1 second for this example.
     */
    private static final long QUIESCE_TIME = (long) 1000;

    /**
     * The name ofthe local queue manager.
     */
    private String queueManagerName;
	
    /**
     * Indicates whether this program puts MQe trace to stdout or not.
     */
    private static final boolean MQE_TRACE = false;

    /**
     * Entry point from the command line.
     * 
     * <p>This method will perform the following operations:
     * <ul>
     * <li>Create an instance of the MQeMemoryQM class.
     * <li>Define the queue manager in memory.
     * <li>Start the queue manager.
     * <li>Put a simple message to a queue on the queue manager.
     * <li>Get the message off the queue.
     * <li>Stop the queue manager
     * <li>Remove the queue manager definition from memory.
     * <li>Optionally trace using a MQe trace handler to stdout, depending on whether a constant is set or not.
     * </ul>
     */
    public static void main(String[] args) {		
        try {			
            Run me = new Run();

            TraceController traceHelper = new TraceController();

            if (MQE_TRACE) {
                traceHelper.traceOn();
            }

            me.start();
            try {
                me.put();
                me.get();
            } finally {
                me.stop();
            }            
            
            if (MQE_TRACE) {
                traceHelper.traceOff();
            }
 			
        } catch (Exception error) {
            System.err.println("Error: " + error.toString());
            error.printStackTrace();
        }
    }
	
    /**
     * Starts the queue manager.
     */	
    public void start() throws Exception {
    	
        System.out.println("Starting the queue manager.");
        
        OS4690ConfigInfo config = new OS4690ConfigInfo();

        config.activate();
        
        MQeFields configFields = config.getConfigFields();

        queueManagerName = config.getQueueManagerName();
    	
        System.out.println("Starting the queue manager"); 
        myQueueManager = new MQeQueueManager();
        myQueueManager.activate(configFields);
        System.out.println("Queue manager started.");
    }
	
    /**
     * Puts a simple message to the system default local queue.
     */
    public void put() throws Exception {
        System.out.println("Putting the test message");
        
        OS4690ConfigInfo config = new OS4690ConfigInfo();

        config.activate();
        String testQueueName = config.getTestQueueLongName();
		
        MQeMsgObject msg = new MQeMsgObject();

        // Add my hello world text to the message.
        msg.putUnicode("myFieldName", "Hello World!");
        
        myQueueManager.putMessage(queueManagerName, testQueueName, msg, null, 0L);
        System.out.println("Put the test message");
    }
	
    /**
     * Gets a simple message from the system default local queue.
     */
    public void get() throws Exception {
        System.out.println("Getting the test message.");

        OS4690ConfigInfo config = new OS4690ConfigInfo();

        config.activate();
        String testQueueName = config.getTestQueueLongName();        
        
        MQeMsgObject msg = myQueueManager.getMessage(queueManagerName, testQueueName, null, null, 0L);

        if (msg != null) {
            System.out.println("Got the test message.");
            
            if (msg.contains("myFieldName")) {
                String textGot = msg.getUnicode("myFieldName");

                System.out.println("Message contained the text '" + textGot + "'");
            }
        }
    }
	
    /**
     * Stops the queue manager.
     */
    public void stop() throws Exception {
        System.out.println("Stopping the queue manager.");
        myQueueManager.closeQuiesce(QUIESCE_TIME);
        myQueueManager = null;
        System.out.println("Queue manager stopped.");
    }
	
}
