// Version 1.2 mqe_java/source/examples/os4690/UnConfigure.java, MQeExamples, la200, la200-L030324.1

/*-----------------------------------------------------------------------------*
 *                    WebSphere MQ Everyplace for Multiplatforms               *
 *                                                                             *
 * Licensed Materials - Property of IBM                                        *
 *                                                                             *
 * 5765-E63                                                                    *
 *                                                                             *
 * (C) Copyright IBM Corp. 2002                                                *
 *-----------------------------------------------------------------------------*/
package examples.os4690;


import com.ibm.mqe.*;
import examples.mqbridge.administration.programming.*;


/**
 * Removes a queue manager created using the {@link examples.os4690.Configure} program.
 */
public class UnConfigure {

    /**
     * Indicates whether this program puts MQe trace to stdout or not.
     */
    private static final boolean MQE_TRACE = false;
	
    public static short[] version = { 2, 0, 0, 10 }; 
	
    public static void main(String[] args) {
        try {
            TraceController traceHelper = new TraceController();    

            if (MQE_TRACE) {    	        	
                traceHelper.traceOn();
            }
    		
            UnConfigure me = new UnConfigure();

            me.deleteTestQueue();
            me.undefine();
        	
            if (MQE_TRACE) {
                traceHelper.traceOff();
            }
        } catch (Exception e) {
            System.out.println("Failure: " + e.toString());
            e.printStackTrace();
        }	
    }
	
    /**
     * Removes any definitions on the queue manager which were previously defined.
     */
    public void undefine() throws Exception {		    	
		
        // Create all the configuration information needed to construct the 
        // queue manager
        OS4690ConfigInfo info = new OS4690ConfigInfo();

        info.activate();
        
        MQeFields configFields = info.getConfigFields(); 
        String queueManagerName = info.getQueueManagerName();
        String storageLocation = info.getStorageLocation();
         
        System.out.println("Queue manager " + queueManagerName + " will now be deleted.");
		
        MQeQueueManagerConfigure configurator = new MQeQueueManagerConfigure();

        configurator.activate(configFields, storageLocation);
		
        // Remove the configured entries for the queues we defined.
        configurator.deleteSystemQueueDefinition();
        configurator.deleteDeadLetterQueueDefinition();
        configurator.deleteAdminReplyQueueDefinition();
        configurator.deleteAdminQueueDefinition();
		
        // Remove the queue manager itself.
        configurator.deleteQueueManagerDefinition();
		
        configurator.close();
		
        System.out.println("Queue manager is now deleted.");
    }  
    
    /**
     * Delete a test queue using administration messages, so we can put a test message to it.
     * 
     * <p>We could have used the system default local queue, but here we are showing an example
     * of how one might create a queue which has a long filename itself, but stores messages
     * on an 8.3 file sysyem. 
     * 
     * @throws Exception if there is a failure.
     */
    public void deleteTestQueue() throws Exception {
        System.out.println("Deleting a test queue");
    	
        OS4690ConfigInfo configInfo = new OS4690ConfigInfo();

        configInfo.activate();
		
        MQeFields configFields = configInfo.getConfigFields();
        String storageLocation = configInfo.getStorageLocation();
        String queueManagerName = configInfo.getQueueManagerName();
        String fileSeparator = MQe.fileSeparator();
        String testQueueName = configInfo.getTestQueueLongName();
    	
        // Now fire-up the queue manager so we can adminster it using adminstration messages...
        MQeQueueManager myQueueManager = new MQeQueueManager();

        myQueueManager.activate(configFields);
        
        // Construct a test queue explicitly which stores 8.3 message fies in a short filename directory.
        Reporter reporter = (Reporter) new AdminHelperReporter();
        AdminMessageDispatcher dispatcher = (AdminMessageDispatcher) new AdminHelperDispatcher(myQueueManager);
        AdminHelperLocalQueue helper = new AdminHelperLocalQueue(reporter, dispatcher);
		  
        try {
            // Drain all the messages out of the test queue before we remove it.
            boolean drained = false;        	

            while (!drained) {
                MQeMsgObject msg = dispatcher.get(reporter, queueManagerName, testQueueName);

                if (msg == null) {
                    drained = true;
                }
            }
        	
            System.out.println("Test queue now drained.");
        	
            // Now that the test queue is empty, remove it.
            helper.delete(queueManagerName, testQueueName);
        } catch (Exception e) {
            reporter.error("Failed to create the test queue.");        	
            reporter.error(e);
        } finally {
            // Even if we failed, make sure the queue manager is closed down within 5 seconds.
            myQueueManager.closeQuiesce(5000L);
        }		
    }	     
}

