package examples.osgi.client;


// Version 1.3 mqe_java/source/examples/osgi/client/MQeClientBundleActivator.java, MQeOSGi, la200, la200-L030324.1
/*-----------------------------------------------------------------------------*
 *                    WebSphere MQ Everyplace for Multiplatforms               *
 *                                                                             *
 * Licensed Materials - Property of IBM                                        *
 *                                                                             *
 * 5765-E63                                                                    *
 *                                                                             *
 * (C) Copyright IBM Corp. 2002                                                *
 *-----------------------------------------------------------------------------*/
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import java.lang.InterruptedException;


/***
 *  Example Bundle Activator. Shows how to start an MQe
 *  Application within the OSGI framework
 *
 *  Example shows how to:
 * <pre>
 *  . start and configure the MQeClientApp
 *  . stop the MQeClientApp
 * </pre>
 *
 **/

public class MQeClientBundleActivator implements BundleActivator {

    public static short[] version = { 2, 0, 0, 10 }; 
    MQeClientApp dem;

    /**
     * Called by the framework when this bundle is started.
     * 
     * 
     * It takes the value stored in the java properties:
     * <pre>
     *  . examples.osgi.server.port 
     *  . examples.osgi.server.address 
     *   	
     * </pre>
     *  
     * 
     * and passes these to the application. 
     * Under the covers this is the port and address that is used to configure the
     * MQe connection definition to the servers queue manager.  It should be the 
     * same port number that the server is configured with. These properties should
     * be setup before the bundle is started. If not set then the default values are
     * port 8085 and address 127.0.0.1
     * 
     *
     * @param context org.osgi.framework.BundleContext, BundleContext.
     */

    public void start(BundleContext context) throws Exception {
		
        String targetQMPort = System.getProperty("examples.osgi.server.port");
	
        String targetQMIPAddress = System.getProperty("examples.osgi.server.address");
		
        System.out.println("MQeClientApp - starting in 2 seconds...");
        Thread.sleep(2000);		
        dem = new MQeClientApp("MyQM", "c:\\MQeClient");
        dem.setServerAddressAndPort(targetQMIPAddress, targetQMPort);
        dem.setupMQeClient();
        dem.runTest();
		
        System.out.println("MQeClientApp has been started");	
    }

    /**
     * Called by the framework when this bundle is stopped.
     * 
     * 
     * It shutsdown the underlying MQeQueueManager if one was started
     * in the start method.
     * 
     * @param context org.osgi.framework.BundleContext, BundleContext.
     * 
     */

    public void stop(BundleContext context) throws Exception {
        dem.shutdownMQeClient();
        System.out.println("MQeClientApp has been stopped");	
		
    }

}
