package examples.queuemanager;


// Version mqe_java/source/examples/queuemanager/MQeClient.java, MQeExamples, la200, la200-L030626 1.11
/* -----------------------------------------------------------------------------*/

/*                    WebSphere MQ Everyplace for Multiplatforms                */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 1999                                                 */

/* -----------------------------------------------------------------------------*/

import com.ibm.mqe.MQe;
import com.ibm.mqe.MQeFields;
import com.ibm.mqe.MQeQueueManager;


/**
 *  <p>To provide a simple example MQe client.
 *
 * <p>Components configured on a client at startup are :
 * <pre>
 *      ... Aliases
 *      ... Registry
 *      ... QueueManager
 * </pre>
 * <p><b>Note:</b>Only one client per JVM can be started at a time.
 * <p> This extends the {@link com.ibm.mqe.MQe} class.
 * <p>------------------------------------------------------------------------------
 * <pre>
 * Example configuration data fields :
 *
 *
 *   [QueueManager]
 *      (ascii)Name=ClientQMgr
 *
 *   [Registry]
 *      (ascii)LocalRegType=FileRegistry
 *      (ascii)DirName=.\ClientQMgr\Registry\
 *      (ascii)Adapter=com.ibm.mqe.adapters.MQeDiskFieldsAdapter
 * </pre>
 */
public class MQeClient extends MQe {
    public static short version[] = { 2, 0, 0, 10 };  

    public static MQeQueueManager queueManager;
    public static MQeFields sections;

    /**
     * If you want to start MQe tracing, then set this flag to true.
     */
    private static final boolean START_MQE_TRACE = false;

    public MQeClient() {
        super();
    }

    /**
     * Constructor with configuration parameter.
     * 
     * @param thisConfig Configuration options.
     * @exception java.lang.Exception
     */
    public MQeClient(MQeFields thisConfig) throws Exception {
        super();
        init(thisConfig);
    }

    /**
     * Starts an MQeClient.
     *
     * @param iniFileName A String containing the ini file name containing startup parms.
     * @exception java.lang.Exception
     */
    public MQeClient(String iniFileName) throws Exception {
        this(iniFileName, false);
    }

    /**
     * <p>Start the client, but allow the caller to indicate whether
     * output the .ini file contents to the stdout is required or not.
     * 
     * @param iniFileName A String containing the ini file name containing startup parms.
     * @param supressStdout A Boolean. if True, the ini file contents are not displayed on the
     * Std Output. Displayed, if a value of False is passed in this parameter.
     * @exception java.lang.Exception
     */
    public MQeClient(String iniFileName, boolean supressStdout) throws Exception {
        super();
        // Load the ini file
        init(MQeQueueManagerUtils.loadConfigFile(iniFileName), supressStdout);
    }

    /**
     * Stops an MQeClient.
     * 
     * @return void
     * @exception java.lang.Exception
     */
    public void close() throws Exception {
        // Stop the queue manager if we have one.
        if (queueManager != null) {
            queueManager.close();
        }

        // Free the queue manager up for garbage collection.
        queueManager = null;

        if (START_MQE_TRACE) {
            MQeQueueManagerUtils.traceOff();
        }
    }

    /**
     * First stage setup.
     * 
     * @param parms MQeFields object.
     * @return void
     * @exception java.lang.Exception
     */
    public void init(MQeFields parms) throws Exception {
        init(parms, false);
    }

    /**
     * First stage setup.
     * 
     * @param parms MQeFields object.
     * @param supressStdout A Boolean. if True, the ini file contents are not displayed on the
     * Std Output. Displayed, if a value of False is passed in this parameter.
     * @exception java.lang.Exception
     */
    public void init(MQeFields parms, boolean supressStdout) throws Exception {

        if (queueManager != null)
            throw new Exception("Client already running");
        // Remember startup parms
        sections = parms;
        // Set any alias names
        MQeQueueManagerUtils.processAlias(sections);
        
        // Set any java system properties which have been specified in the .ini file.
        MQeQueueManagerUtils.processSystemProperties(sections);

        if (START_MQE_TRACE) {
            MQeQueueManagerUtils.traceOn();
        }

        // Display the startup parameters
        if (!supressStdout) {
            System.out.println(sections.dumpToString("#1\t=\t#2\r\n"));
        }

        // Start the queue manager
        queueManager = MQeQueueManagerUtils.processQueueManager(sections);
    }
}
