package examples.trace;


/* -----------------------------------------------------------------------------*/

/*                    MQSeries Everyplace for Multiplatforms                    */

/*                                                                              */

/* Licensed Materials - Property of IBM                                         */

/*                                                                              */

/* 5765-E63                                                                     */

/*                                                                              */

/* (C) Copyright IBM Corp. 2002                                                 */

/* -----------------------------------------------------------------------------*/

import java.io.ByteArrayInputStream;
import java.io.DataInputStream;
import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.ServletInputStream;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ibm.mqe.trace.MQeTraceFromBinary;
import com.ibm.mqe.trace.MQeTraceRenderer;


/**
 * A simple servlet that receives binary trace data from an application,
 * translates it into readable english and displays it.
 * This is designed to be used with MQeTraceToBinaryMidp.
 *
 * It requires MQeTraceFromBinary and MQeTraceRenderer in the com.ibm.mqe.trace
 * package to translate the binary data to a readable form.
 *
 * Any trace data received is translated into english and dumped to the screen.
 *
 * This is the default servlet that MQeTraceToBinaryMidp sends data to.
 */
public class MQeTraceServlet extends HttpServlet {

    public static short  version[] = { 2, 0, 0, 10 };  // MQe version

    public void doPost(HttpServletRequest request, HttpServletResponse response)
        throws IOException, ServletException {

        byte[] rawdata = null;

        // Read the incoming message, if any...
        int len = request.getContentLength();

        if (len > 0) {
            System.out.println("\nData received!");
            ServletInputStream in = request.getInputStream();
            DataInputStream din = new DataInputStream(in);

            // get the data
            rawdata = new byte[len];
            din.readFully(rawdata);
            din.close();

            // deal with raw data
            MQeTraceFromBinary.decodeBinary(new ByteArrayInputStream(rawdata), System.out, new MQeTraceRenderer());
        } else {
            System.out.println("Null data received");
        }
    }
}
